<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Plate Girder Sections Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Plate Girder Elevations Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Plate Girder Sections Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Plate Girder Section Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="BridgeCenterLine">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th class="underline" lang="en" valign="bottom">Length</th>
                                                <th class="underline" lang="en" valign="bottom">Top<br/>Cover</th>
                                                <th class="underline" lang="en" valign="bottom">Top<br/>Flange</th>
                                                <th class="underline" lang="en" valign="bottom">Web</th>
                                                <th class="underline" lang="en" valign="bottom">Bottom<br/>Flange</th>
                                                <th class="underline" lang="en" valign="bottom">Bottom<br/>Cover</th>
                                                <th class="underline" lang="en" valign="bottom">Haunch</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="Girders/Girder/PlateGirder">
                                                <tr>
                                                    <xsl:if test="../@stopSpan = ../@startSpan">
                                                        <th align="left" colspan="7">
                                                            Span <xsl:value-of select="../@startSpan"/>
                                                            Girder <xsl:value-of select="position()"/> (<xsl:value-of select="../@name"/>)
                                                        </th>
                                                    </xsl:if>
                                                    <xsl:if test="../@stopSpan != ../@startSpan">
                                                        <th align="left" colspan="7">
                                                            Span <xsl:value-of select="../@startSpan"/> - <xsl:value-of select="../@stopSpan"/>
                                                            Girder <xsl:value-of select="position()"/> (<xsl:value-of select="../@name"/>)
                                                        </th>
                                                    </xsl:if>
                                                </tr>
                                                <xsl:for-each select="Sections/Section">
                                                    <tr>
                                                        <td align="right" class="sidepad">
                                                            <xsl:value-of select="inr:distanceFormat(number(@sectionLength), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td class="sidepad"><xsl:value-of select="@topCoverDescription"/></td>
                                                        <td class="sidepad"><xsl:value-of select="@topFlangeDescription"/></td>
                                                        <td class="sidepad"><xsl:value-of select="@webDescription"/></td>
                                                        <td class="sidepad"><xsl:value-of select="@bottomFlangeDescription"/></td>
                                                        <td class="sidepad"><xsl:value-of select="@bottomCoverDescription"/></td>
                                                        <td class="sidepad"><xsl:value-of select="@haunchType"/></td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr><td>&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia, 
                abutments/piers, bearing lines, girders and verticals for the bridge.
            </p>
            <p class="normal1" lang="en">
                You must also select the <em>Bridge &gt; Bridge Reports</em> command to get results from 
                this report.
            </p>
            <p class="normal1" lang="en">This report is only suitable for Plate Girders.</p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
