<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Replace the value of the select attribute below with your choice of
         "'tangential'" or "'radial'" -->
    <xsl:variable name="preferredSkewMethod" select="'radial'"/>
    <!-- Transverse Line List Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Transverse Line List Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Transverse Line List Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Abutment and Bearing Line Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="BridgeCenterLine">
                                        <thead>
                                            <tr>
                                                <th class="underline" colspan="2">&#xa0;</th>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Northing</th>
                                                <th class="underline" lang="en">Easting</th>
                                                <th class="underline" lang="en">Direction</th>
                                                <xsl:if test="$preferredSkewMethod = 'tangential'">
                                                    <th class="underline" lang="en">Tangential<br/>Skew Angle</th>
                                                </xsl:if>
                                                <xsl:if test="$preferredSkewMethod = 'radial'">
                                                    <th class="underline" lang="en">Radial<br/>Skew Angle</th>
                                                </xsl:if>
                                            </tr>
                                        </thead>
                                        <xsl:for-each select="TransverseLines/TransverseLine[not(@name = preceding-sibling::TransverseLine/@name)]">
                                            <tbody>
                                                <tr>
                                                    <td>&#xa0;</td>
                                                    <td><xsl:value-of select="@name"/></td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:stationFormat(number(centerLinePoint/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(centerLinePoint/station/@externalStationName))"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(centerLinePoint/@northing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(centerLinePoint/@easting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:if test="$preferredSkewMethod = 'tangential'">
                                                            <xsl:value-of select="inr:angularFormat(number(@tangentialSkewAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                        </xsl:if>
                                                        <xsl:if test="$preferredSkewMethod = 'radial'">
                                                            <xsl:value-of select="inr:angularFormat(number(@radialSkewAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia and 
                abutments/piers for the bridge.&#xa0; A complete report also requires bearing lines.
            </p>
            <p class="normal1" lang="en">
                You must also select the <em>Bridge &gt; Bridge Reports</em> command to get results from 
                this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
