<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Project Quantity Takeoffs Report -->
    <xsl:key name="qtoByStyle" match="Feature" use="@style"/>
    <xsl:variable name="uniqueStyles" select="//Features/Feature[not(@style = preceding-sibling::Feature/@style)]/@style"/>
    <xsl:variable name="uniqueStylesByLength" select="//Features/Feature[not(@style = preceding-sibling::Feature/@style) and @length > 0.0]/@style"/>
    <xsl:variable name="uniqueStylesByArea" select="//Features/Feature[not(@style = preceding-sibling::Feature/@style) and @area > 0.0]/@style"/>
    <xsl:variable name="uniqueStylesByPoints" select="//Features/Feature[not(@style = preceding-sibling::Feature/@style) and @type = 'random']/@style"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Project Quantity Takeoffs Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Miscellaneous Estimates</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <span style="font-size:smaller">
                                Input Grid Factor:&#xa0; <xsl:value-of select="@inputGridScaleFactor" />
                            </span>
                            <xsl:for-each select="Surfaces">
                                <table cellpadding="4">
                                    <thead>
                                        <tr>
                                            <th class="underline" lang="en">Job Number</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <tr>
                                            <xsl:for-each select="Surface">
                                                <td align="center"><xsl:value-of select="@name"/></td>
                                            </xsl:for-each>
                                        </tr>
                                        <xsl:for-each select="$uniqueStylesByLength">
                                            <tr>
                                                <!-- Feature Linear Data -->
                                                <td align="right"><xsl:call-template name="totalLength"/></td>
                                                <td align="left">
                                                    <xsl:if test="//@linearUnits = 'Imperial'">ft</xsl:if>
                                                    <xsl:if test="//@linearUnits = 'Metric'">m</xsl:if>
                                                </td>
                                                <td align="left"><xsl:value-of select="."/></td>
                                            </tr>
                                        </xsl:for-each>
                                        <xsl:for-each select="$uniqueStylesByArea">
                                            <tr>
                                                <!-- Feature Area Data -->
                                                <td align="right"><xsl:call-template name="totalArea"/></td>
                                                <td align="left">
                                                    <xsl:if test="//@linearUnits = 'Imperial'">ft2</xsl:if>
                                                    <xsl:if test="//@linearUnits = 'Metric'">m2</xsl:if>
                                                </td>
                                                <td align="left"><xsl:value-of select="."/></td>
                                            </tr>
                                        </xsl:for-each>
                                        <xsl:for-each select="$uniqueStylesByPoints">
                                            <tr>
                                                <!-- Feature Point Data -->
                                                <td align="right"><xsl:call-template name="totalPoints"/></td>
                                                <td align="left">ea</td>
                                                <td align="left"><xsl:value-of select="."/></td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Calculate total length by style -->
    <xsl:template name="totalLength">
        <xsl:value-of select="inr:distanceFormat(number(sum(key('qtoByStyle',string(.))/@length)),$xslDistancePrecision)"/>
    </xsl:template>
    <!-- Calculate total area by style -->
    <xsl:template name="totalArea">
        <xsl:value-of select="inr:distanceFormat(number(sum(key('qtoByStyle',string(.))/@area)),$xslDistancePrecision)"/>
    </xsl:template>
    <!-- Calculate total points by style -->
    <xsl:template name="totalPoints">
        <xsl:value-of select="sum(key('qtoByStyle',string(.))/@numberPoints)"/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one feature in the <em>Features</em> list on the <em>Tools &gt; 
                XML Reports &gt; Surfaces</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report sums the areas of closed features, the lengths of linear features and the 
                number of points of random features based on feature style.&#xa0; If you wish to sum random 
                features, you must toggle on the <em>Include Feature Points</em> option.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
