<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique cross section surfaces -->
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <!-- SDDOT Cross Section Slope Stake Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">SDDOT Cross Section Slope Stake Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">SDDOT Cross Section Slope Stake Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en" nowrap="nowrap">Set Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" nowrap="nowrap">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" nowrap="nowrap" style="font-size: 80%" valign="top">
                                                Input Grid Factor:&#xa0; 
                                            </th>
                                            <td align="left" style="font-size: 80%" valign="top">
                                                <xsl:value-of select="../@inputGridScaleFactor"/>
                                            </td>
                                            <td class="sidepad" align="left" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Cross Section Point Data -->
                                <table class="margin" width="80%">
                                    <colgroup span="11">
                                        <col width="10%"/>
                                        <col width="5%"/>
                                        <col width="4%"/>
                                        <col width="5%"/>
                                        <col width="4%"/>
                                        <col width="5%"/>
                                        <col width="4%"/>
                                        <col width="5%"/>
                                        <col width="4%"/>
                                        <col width="5%"/>
                                        <col width="4%"/>
                                    </colgroup>
                                    <xsl:for-each select="$uniqueSurfaceName[../@type = 1]">
                                        <tr>
                                            <th align="left" lang="en">Surface:&#xa0; </th>
                                            <td align="left" colspan="10"><xsl:value-of select="."/></td>
                                        </tr>
                                        <xsl:for-each select="//CrossSectionSurface[@name = current()]">
                                            <xsl:for-each select="CrossSectionPoints">
                                                <!-- Station | Left Shoulder Elevation | Left Penultimate Point 
                                                     Elevation | Design Centerline Elevation | Right Penultimate 
                                                     Point Elevation | Right Shoulder Elevation -->
                                                <tr>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:stationFormat(number(../../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../../Station/@externalStationName))"/>
                                                    </td>
                                                    <td>&#xa0;</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@type = 'LeftShoulder']/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td>&#xa0;</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[position() = 2]/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td>&#xa0;</td>
                                                    <xsl:choose>
                                                        <xsl:when test="CrossSectionPoint[@offset = 0]">
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@offset = 0]/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <td>&#xa0;</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[position() = last() - 1]/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td>&#xa0;</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@type = 'RightShoulder']/@elevation), $xslElevationPrecision)"/>
                                                    </td>
                                                </tr>
                                                <!-- Blank | Left Shoulder Elevation - Left Slope Stake Point 
                                                     Elevation | Left Final Segment Height | Design Centerline 
                                                     Offset | Right Final Segment Height | Right Shoulder Elevation 
                                                     - Right Slope Stake Elevation -->
                                                <tr>
                                                    <td>&#xa0;</td>
                                                    <xsl:choose>
                                                        <xsl:when test="(CrossSectionPoint[@type = 'LeftShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'LeftSlopeStake']/@elevation) &gt; 0">
                                                            <td align="right">F</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@type = 'LeftShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'LeftSlopeStake']/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="(CrossSectionPoint[@type = 'LeftShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'LeftSlopeStake']/@elevation) &lt; 0">
                                                            <td align="right">C</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(-1 * ((CrossSectionPoint[@type = 'LeftShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'LeftSlopeStake']/@elevation))), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@type = 'LeftShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'LeftSlopeStake']/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <xsl:choose>
                                                        <xsl:when test="CrossSectionPoint[position() = 1]/CrossSectionSegment/@height &gt; 0">
                                                            <td align="right">C</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[position() = 1]/CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="CrossSectionPoint[position() = 1]/CrossSectionSegment/@height &lt; 0">
                                                            <td align="right">F</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionPoint[position() = 1]/CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[position() = 1]/CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <td>&#xa0;</td>
                                                    <xsl:choose>
                                                        <xsl:when test="CrossSectionPoint[@offset = 0]">
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:distanceFormat(number(CrossSectionPoint[@offset = 0]/@offset), $xslDistancePrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <xsl:choose>
                                                        <xsl:when test="CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@height &gt; 0">
                                                            <td align="right">C</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@height &lt; 0">
                                                            <td align="right">F</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@height), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <xsl:choose>
                                                        <xsl:when test="(CrossSectionPoint[@type = 'RightShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'RightSlopeStake']/@elevation) &gt; 0">
                                                            <td align="right">F</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@type = 'RightShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'RightSlopeStake']/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="(CrossSectionPoint[@type = 'RightShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'RightSlopeStake']/@elevation) &lt; 0">
                                                            <td align="right">C</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(-1 * ((CrossSectionPoint[@type = 'RightShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'RightSlopeStake']/@elevation))), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@type = 'RightShoulder']/@elevation) - (../..//CrossSectionPoint[@type = 'RightSlopeStake']/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </tr>
                                                <!-- Blank | Left Slope Stake Point Offset | Left Catchpoint Offset 
                                                     | Design Centerline Elevation - Existing Centerline Elevation 
                                                     | Right Catchpoint Offset | Right Slope Stake Offset -->
                                                <tr>
                                                    <td>&#xa0;</td>
                                                    <td align="right">@</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(-1 * (../..//CrossSectionPoint[@type = 'LeftSlopeStake']/@offset)), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="right">@</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(-1 * (CrossSectionPoint[position() = 1]/@offset)), $xslDistancePrecision)"/>
                                                    </td>
                                                    <xsl:choose>
                                                        <xsl:when test="(CrossSectionPoint[@offset = 0]/@cutFillHeight) &gt; 0">
                                                            <td align="right">F</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@offset = 0]/@elevation - ../..//CrossSectionPoint[@type = 'ExistingCenterline']/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="(CrossSectionPoint[@offset = 0]/@cutFillHeight) &lt; 0">
                                                            <td align="right">C</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(-1 * CrossSectionPoint[@offset = 0]/@cutFillHeight), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td>&#xa0;</td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:elevationFormat(number(CrossSectionPoint[@offset = 0]/@elevation - ../..//CrossSectionPoint[@type = 'ExistingCenterline']/@elevation), $xslElevationPrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <td align="right">@</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(CrossSectionPoint[position() = last()]/@offset), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="right">@</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(../..//CrossSectionPoint[@type = 'RightSlopeStake']/@offset), $xslDistancePrecision)"/>
                                                    </td>
                                                </tr>
                                                <!-- Blank | Blank | Left Penultimate Point Offset | Left Final 
                                                     Segment Slope | Right Penultimate Point Offset | Right Final 
                                                     Segment Slope -->
                                                <tr>
                                                    <td colspan="3">&#xa0;</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(-1 * (CrossSectionPoint[position() = 2]/@offset)), $xslDistancePrecision)"/>+
                                                    </td>
                                                    <xsl:choose>
                                                        <xsl:when test="CrossSectionPoint[position() = 1]/CrossSectionSegment/@slope &gt; 0">
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionPoint[position() = 1]/CrossSectionSegment/@slope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="CrossSectionPoint[position() = 1]/CrossSectionSegment/@slope &lt; 0">
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:alternateGradeFormat(number(-1 * (CrossSectionPoint[position() = 1]/CrossSectionSegment/@slope)), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionPoint[position() = 1]/CrossSectionSegment/@slope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <td colspan="2">&#xa0;</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(CrossSectionPoint[position() = last() - 1]/@offset), $xslDistancePrecision)"/>+
                                                    </td>
                                                    <xsl:choose>
                                                        <xsl:when test="CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@slope &gt; 0">
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@slope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:when test="CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@slope &lt; 0">
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:alternateGradeFormat(number(-1 * (CrossSectionPoint[position() = last() - 1]/CrossSectionSegment/@slope)), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                            </td>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:value-of select="inr:alternateGradeFormat(number(CrossSectionPoint[position() = last() - 1]/@segmentSlope), $xslGradeFormat, $xslGradePrecision, $xslIfSlopeExceeds, $xslAlternateSlopeFormat, $xslAlternateSlopePrecision)"/>
                                                            </td>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <td colspan="2">&#xa0;</td>
                                                </tr>
                                                <tr><td colspan="11">&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                To use this report, you must have left and right shoulder staking points defined.&#xa0;  
                To do this, select <em>Tools &gt; Application Add-Ins</em> and toggle on the <em>Variable 
                Manager Add-In</em>.&#xa0; Next, select <em>Tools &gt; Variable Manager</em> and toggle on 
                the <em>Enable Left and Right Shoulder Slope Staking</em> registry variable.
            </p>
            <p class="normal1" lang="en">
                You must create data for this report by selecting the <em>Evaluation &gt; Cross Section 
                &gt; Cross Section Report</em> command.
            </p>
            <p class="normal1" lang="en">
                You must also toggle on the <em>Generate Slope Stake Points</em> option on the <em>Slope 
                Staking</em> tab and define the <em>Slope Stake Points</em> and the <em>Shoulders
                </em>.&#xa0; All specified features must be displayed on the cross section set.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
