<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Alignment to ASCII Import Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY HORIZONTAL ALIGNMENT TO ASCII&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//@inputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:text>{ TYPE STATION RADIUS X_CRD Y_CRD DIRECTION SPI_CONST&#xd;</xsl:text>
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Aligment Linear Data -->
    <xsl:template match="HorizontalLine">
        <!-- Format direction -->
        <xsl:variable name="fmtDirection" select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text>LIN</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnFormat($fmtDirection, 22)"/>
        <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 16)"/>
            <xsl:value-of select="inr:columnFormat($fmtDirection, 22)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Alignment Circular Data -->
    <xsl:template match="HorizontalCircle">
        <!-- Format direction -->
        <xsl:variable name="fmtDirection" select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text>CIR</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @radius), $xslDistancePrecision, 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 16)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnFormat($fmtDirection, 22)"/>
        <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 16)"/>
            <xsl:value-of select="inr:columnFormat($fmtDirection, 22)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Horizontal Alignment Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <!-- Format direction -->
        <xsl:variable name="fmtDirection" select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:choose>
            <xsl:when test="@type = 'Clothoid'"><xsl:text>SPI</xsl:text></xsl:when>
            <xsl:when test="@type = 'Cubic'"><xsl:text>CUB</xsl:text></xsl:when>
            <xsl:when test="@type = 'Biquadratic'"><xsl:text>BIQ</xsl:text></xsl:when>
            <xsl:when test="@type = 'Bloss'"><xsl:text>BLS</xsl:text></xsl:when>
            <xsl:when test="@type = 'Sinusoid'"><xsl:text>SIN</xsl:text></xsl:when>
            <xsl:when test="@type = 'Cosine'"><xsl:text>COS</xsl:text></xsl:when>
            <xsl:when test="@type = 'Viennese'"><xsl:text>VIE</xsl:text></xsl:when>
            <xsl:otherwise><xsl:text>UNK</xsl:text></xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnFormat($fmtDirection, 22)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@aConstant), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@easting), $xslEastingPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(End/@northing), $xslNorthingPrecision, 16)"/>
            <xsl:value-of select="inr:columnFormat($fmtDirection, 22)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(@aConstant), $xslDistancePrecision, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
