<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Horizontal Elements - SDR33 FormatUS SUrvey Foot-->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>00NMSDR33  V04-04.xx                    132211&#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:text>28KI</xsl:text>
                        <xsl:choose>
                            <xsl:when test="string-length(@name) &gt; 16">
                                <xsl:value-of select="substring(@name, 1, 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length(@name) &lt; 16">
                                <xsl:value-of select="@name"/>
                                <xsl:value-of select="substring('&#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; &#xa0; ', 1, 16 - string-length(@name))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@name"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>1&#xd;</xsl:text>
                        <xsl:text>06NM1.00000000000000&#xd;</xsl:text>
                        <xsl:text>13NM</xsl:text>
                        <xsl:value-of select="inr:date()"/>
                        <xsl:text> Horizontal Alignment Listing for SDR33&#xd;</xsl:text>
                        <xsl:text>13NMProject Name: </xsl:text>
                        <xsl:value-of select="../@name"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>13NMAlignment Name: </xsl:text>
                        <xsl:value-of select="@name"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>13NMAlignment Description: </xsl:text>
                        <xsl:value-of select="@description"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>13NMAlignment Style: </xsl:text>
                        <xsl:value-of select="@style"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>13TS</xsl:text>
                        <xsl:value-of select="inr:SDRdate()"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:apply-templates/>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Alignment Linear Data -->
    <xsl:template match="HorizontalLine">
        <!-- Format direction to mode North Azimuth, precision 8, format Decimal, angular mode Decimal -->
        <xsl:variable name="azimuth" select="inr:directionFormat(number(@direction), 2, 8, 3, 1)"/>
        <!-- Strip off trailing degrees symbol -->
        <xsl:variable name="decAzimuth" select="substring-before($azimuth, '&#xb0;')"/>
        <xsl:choose>
            <xsl:when test="position() = 1">
                <xsl:text>29NM</xsl:text>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/station/@internalStation), 8, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number($decAzimuth), 8, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/@northing), 8, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(Start/@easting), 8, 16)"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:text>31NM</xsl:text>
                <xsl:value-of select="inr:columnDoubleFormat(number($decAzimuth), 8, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(@length), 8, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>31NM</xsl:text>
                <xsl:value-of select="inr:columnDoubleFormat(number($decAzimuth), 8, 16)"/>
                <xsl:value-of select="inr:columnDoubleFormat(number(@length), 8, 16)"/>
                <xsl:text>&#xd;</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Alignment Circular Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:text>32NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), 8, 16)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @radius), 8, 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="inr:columnDoubleFormat(number(@radius), 8, 16)"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Alignment Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:text>33NM</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), 8, 16)"/>
        <xsl:choose>
            <xsl:when test="@startRadius != 0.0">
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @startRadius ), 8, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(@startRadius ), 8, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:columnDoubleFormat(number(-1 * @endRadius ), 8, 16)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:columnDoubleFormat(number(@endRadius ), 8, 16)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt; Geometry&#xd;</xsl:text>
        <xsl:text>    command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function gets the current date and formats it for SDR Timestamp.
            function SDRdate()
            {
                var today = new Date();
                var monthName = new Array ("JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC");
                var dayOfMonth = today.getDate();
                var year = today.getFullYear();
                var minutes = today.getMinutes();
                if (dayOfMonth < 10)
                {
                    dayOfMonth = "0" + dayOfMonth;
                }
                return dayOfMonth + "-" + monthName[today.getMonth()] + "-" + year;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
