<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">17</xsl:when>
            <xsl:otherwise>16</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Coordinate List - Leica 16 Format -->
    <xsl:output method="text" media-type="text/plain" encoding="is0-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="//HorizontalElements | //CogoPoints">
                    <xsl:text/>
                    <xsl:apply-templates/>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Element Point Data -->
    <xsl:template match="Start | HorizontalLine/PI | HorizontalSpiral/PI | Center | End[@pointType = 'POE'] | CogoPoints/GeometryPoint">
        <!-- Find absolute value -->
        <xsl:variable name="absNorthing">
            <xsl:choose>
                <xsl:when test="@northing &lt; 0"><xsl:value-of select="number(-1 * @northing)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(@northing)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absEasting">
            <xsl:choose>
                <xsl:when test="@easting &lt; 0"><xsl:value-of select="number(-1 * @easting)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(@easting)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="absElevation">
            <xsl:choose>
                <xsl:when test="@elevation &lt; 0"><xsl:value-of select="number(-1 * @elevation)"/></xsl:when>
                <xsl:otherwise><xsl:value-of select="number(@elevation)"/></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <!-- Set decimal precision and pad with leading zeros -->
        <xsl:variable name="fmtNorthing" select="inr:zeroDoubleFormat(number($absNorthing), 4, 16)"/>
        <xsl:variable name="fmtEasting" select="inr:zeroDoubleFormat(number($absEasting), 4, 16)"/>
        <xsl:variable name="fmtElevation" select="inr:zeroDoubleFormat(number($absElevation), 4, 16)"/>
        <xsl:text>*11</xsl:text>
        <xsl:call-template name="Number"/>
        <xsl:text>+</xsl:text>
        <xsl:choose>
            <xsl:when test="string-length(@name) &gt; 16">
                <xsl:value-of select="substring(@name, 1, 16)"/>
            </xsl:when>
            <xsl:when test="string-length(@name) &lt; 16">
                <xsl:value-of select="substring('0000000000000000', 1, 16 - string-length(@name))"/>
                <xsl:value-of select="@name"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="@name"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> 71....+</xsl:text>
        <xsl:choose>
            <xsl:when test="string-length(@description) &gt; 16">
                <xsl:value-of select="substring(@description, 1, 16)"/>
            </xsl:when>
            <xsl:when test="string-length(@description) &lt; 16">
                <xsl:value-of select="substring('0000000000000000', 1, 16 - string-length(@description))"/>
                <xsl:value-of select="@description"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="@description"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> 81..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="@easting &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtEasting) &gt; 16">
                <xsl:value-of select="substring($fmtEasting, (string-length($fmtEasting) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtEasting"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> 82..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="@northing &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtNorthing) &gt; 16">
                <xsl:value-of select="substring($fmtNorthing, (string-length($fmtNorthing) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtNorthing"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text> 83..</xsl:text>
        <xsl:value-of select="$unit"/>
        <xsl:choose>
            <xsl:when test="@elevation &lt; 0">
                <xsl:text>-</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>+</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="string-length($fmtElevation) &gt; 16">
                <xsl:value-of select="substring($fmtElevation, (string-length($fmtElevation) - 15), 16)"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$fmtElevation"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Number -->
    <xsl:template name="Number">
        <xsl:variable name="pointNumber">
            <xsl:number count="HorizontalLine/Start | HorizontalCircle/Start | HorizontalSpiral/Start | HorizontalLine/PI | HorizontalSpiral/PI | Center | End[@pointType = 'POE'] | CogoPoints/GeometryPoint" level="any"/>
        </xsl:variable>
        <xsl:value-of select="inr:zeroFormat(string($pointNumber), 4)"/>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one cogo point in the Cogo&#xd;</xsl:text>
        <xsl:text>    Points &gt; Include field or one horizontal alignment with&#xd;</xsl:text>
        <xsl:text>    named points in the Horizontal Alignments &gt; Include&#xd;</xsl:text>
        <xsl:text>    field on the Tools &gt; XML Reports &gt; Geometry command to&#xd;</xsl:text>
        <xsl:text>    get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This style sheet reports coordinates and distances to&#xd;</xsl:text>
        <xsl:text>    the nearest 1/10000th foot or the nearest 1/10000th&#xd;</xsl:text>
        <xsl:text>    meter, depending on the units stored in the XML data&#xd;</xsl:text>
        <xsl:text>    file.  If the resulting coordinate is too long to fit&#xd;</xsl:text>
        <xsl:text>    in the field, only the last 16 digits (including the&#xd;</xsl:text>
        <xsl:text>    decimal portion) will be retained.  However, stations,&#xd;</xsl:text>
        <xsl:text>    distances, radii, etc will retain the first 16 digits&#xd;</xsl:text>
        <xsl:text>    (truncating the decimal portion.)&#xd;&#xd;</xsl:text>
        <xsl:text>    If you wish to use a different precision, you must&#xd;</xsl:text>
        <xsl:text>    change the "unit" variable near the top of the style&#xd;</xsl:text>
        <xsl:text>    sheet as well as the precision value wherever the&#xd;</xsl:text>
        <xsl:text>    "zeroDoubleFormat" function is called.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This Function formats a string with a length, padding with leading zeros
            // strString - String to get formated
            // nLength - Length of returned string
            function zeroFormat( strString, nLength )
            {
                var nBlanks = nLength - strString.length;
                for( var i = 0; i < nBlanks; i++ )
                    strString = "0" + strString;
                return strString;
            }
            // This function converts a double to string and sets precision and length, padding with leading zeros
            // dNum - Double to be converted to String
            // nPrecision - the number of digits after the decimal point
            // nLength - Length of returned string
            function zeroDoubleFormat( dNum, nPrecision, nLength )
            {
                var nRoundTo = Math.pow( 10, nPrecision );
                var strResult = ( Math.round( nRoundTo * dNum ) ).toString();
                var nCount = strResult.length - strResult.indexOf( "." ) - 1;
                for( var j = 0; j < (nPrecision - nCount); j++ )
                    strResult += "0";
                var nBlanks = nLength - strResult.length;
                for( var i = 0; i < nBlanks; i++ )
                    strResult = "0" + strResult;
                return strResult;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
