<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Vertical Alignment to TIW Import Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY VERTICAL ALIGNMENT TO TIW&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment/VerticalAlignment">
                        <xsl:text>* Alignment name: </xsl:text>
                        <xsl:value-of select="@name"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text>
                        <xsl:value-of select="@description"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text>
                        <xsl:value-of select="@style"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text>
                        <xsl:value-of select="//@inputGridScaleFactor"/>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:text>*</xsl:text>
                        <xsl:value-of select="inr:columnFormat('Northing', 16)"/>
                        <xsl:value-of select="inr:columnFormat('Easting', 16)"/>
                        <xsl:value-of select="inr:columnFormat('Elevation', 16)"/>
                        <xsl:choose>
                            <xsl:when test="//VerticalCircle">
                                <xsl:value-of select="inr:columnFormat('Radius', 16)"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="inr:columnFormat('Length', 16)"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="VerticalElements">
                            <xsl:apply-templates/>
                            <xsl:for-each select="*[position() = last()]">
                                <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/@northing), $xslNorthingPrecision, 16)"/>
                                <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/@easting), $xslEastingPrecision, 16)"/>
                                <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@elevation), $xslElevationPrecision, 16)"/>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine[VerticalStart/@pointType = 'POB' or VerticalStart/@pointType = 'PVI']">
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@verticalCurveLength), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@startVerticalCurveLength + @endVerticalCurveLength), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Alignment Circular Data -->
    <xsl:template match="VerticalCircle">
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@northing), $xslNorthingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@easting), $xslEastingPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVI/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select either All or Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
