<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variable to hold cubic factor -->
    <xsl:variable name="cubicFactor">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'">
                <xsl:choose>
                    <xsl:when test="$xslConvertToCY = 1">27</xsl:when>
                    <xsl:otherwise>1</xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>1</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Variable to store the station range.  Change this value to meet conditions. -->
    <xsl:variable name="stationRange" select="700"/>
    <!-- End Area Volume Report by Station Range -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">End Area Volume Report by Station Range</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">End Area Volume Report by Station Range</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Cross Section Set Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <th align="right" lang="en" style="font-size: 80%" nowrap="nowrap" valign="top">
                                                &#xa0; Note: &#xa0;
                                            </th>
                                            <td align="left" lang="en" style="font-size: 80%">
                                                All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">
                                                    <xsl:choose>
                                                        <xsl:when test="$xslConvertToCY = 1">
                                                            feet, square feet and cubic yards
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            feet, square feet and cubic feet
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">
                                                    meters, square meters and cubic meters
                                                </xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Volume Data -->
                                <table width="100%">
                                    <xsl:for-each select="CrossSectionStations">
                                        <tbody>
                                            <xsl:call-template name="showPage">
                                                <xsl:with-param name="list" select="CrossSectionStation"/>
                                            </xsl:call-template>
                                        </tbody>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Show Page Template -->
    <xsl:template name="showPage">
        <xsl:param name="list"/>
        <xsl:param name="rest" select="$list[Station/@internalStation &gt;= ($list[1]/Station/@internalStation + $stationRange)]"/>
        <xsl:call-template name="columnHeadings"/>
        <xsl:for-each select="$list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)][StationVolume]">
            <tr>
                <td align="left" nowrap="nowrap">
                    <xsl:value-of select="inr:stationFormat(number(Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../Station/@externalStationName))"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(StationVolume/CutMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:areaFormat(number(StationVolume/CutMaterial/@area), $xslAreaPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/CutMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/CutMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:distanceFormat(number(StationVolume/FillMaterial/@factor), $xslDistancePrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:areaFormat(number(StationVolume/FillMaterial/@area), $xslAreaPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/FillMaterial/@volume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/FillMaterial/@adjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number((StationVolume/AddedCutMaterial/@volume + sum(StationVolume/*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@volume) + sum(StationVolume/*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@volume)) div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number((StationVolume/AddedCutMaterial/@adjustedVolume + sum(StationVolume/*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume ) + sum(StationVolume/*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume )) div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number((StationVolume/AddedFillMaterial/@volume + sum(StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@volume) + sum(StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@volume)) div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number((StationVolume/AddedFillMaterial/@adjustedVolume + sum(StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume ) + sum(StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume )) div $cubicFactor), $xslCubicPrecision)"/>
                </td>
                <td align="right">
                    <xsl:value-of select="inr:cubicFormat(number(StationVolume/@massOrdinate div $cubicFactor), $xslCubicPrecision)"/>
                </td>
            </tr>
        </xsl:for-each>
        <xsl:variable name="cutVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/CutMaterial/@volume)"/>
        <xsl:variable name="cutAdjustedVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/CutMaterial/@adjustedVolume)"/>
        <xsl:variable name="fillVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/FillMaterial/@volume)"/>
        <xsl:variable name="fillAdjustedVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/FillMaterial/@adjustedVolume)"/>
        <xsl:variable name="addedCutVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/AddedCutMaterial/@volume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@volume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@volume)"/>
        <xsl:variable name="addedCutAdjustedVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/AddedCutMaterial/@adjustedVolume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/UnclassifiedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/RockMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)"/>
        <xsl:variable name="addedFillVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/AddedFillMaterial/@volume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@volume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@volume)"/>
        <xsl:variable name="addedFillAdjustedVolume" select="sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/AddedFillMaterial/@adjustedVolume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/UnsuitableMaterials/Material[@includeInMassOrdinate = 'true']/Replaced/@adjustedVolume) + sum($list[Station/@internalStation &lt; ($list[1]/Station/@internalStation + $stationRange)]/StationVolume/*/DesignedMaterials/Material[@includeInMassOrdinate = 'true']/@adjustedVolume)"/>
        <tr><td colspan="14"><hr/></td></tr>
        <tr>
            <td align="center" colspan="3">Station Range Totals:</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($cutVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($cutAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td colspan="2">&#xa0;</td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($fillVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($fillAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedCutVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedCutAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedFillVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:cubicFormat(number($addedFillAdjustedVolume div $cubicFactor), $xslCubicPrecision)"/>
            </td>
        </tr>
        <tr><td colspan="14"><hr/></td></tr>
        <tr><td colspan="14">&#xa0;</td></tr>
        <xsl:if test="$rest">
            <xsl:call-template name="showPage">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="columnHeadings">
        <tr>
            <th class="underline" lang="en" rowspan="3" valign="bottom">Baseline<br/>Station</th>
            <th colspan="8" lang="en">- - - - - - - - - - - - - - - - Station Quantities - - - - - - - - - - - - - - - -</th>
            <th colspan="4" lang="en">- - - - - Added and Material Quantities - - - - -</th>
            <th class="underline" lang="en" rowspan="3" valign="bottom"><br/>Mass<br/>Ordinate</th>
        </tr>
        <tr>
            <th colspan="4" lang="en">- - - - - - - - - - Cut - - - - - - - - - -</th>
            <th colspan="4" lang="en">- - - - - - - - - - Fill - - - - - - - - - -</th>
            <th colspan="2" lang="en">- - - - - - Cut - - - - - -</th>
            <th colspan="2" lang="en">- - - - - - Fill - - - - - -</th>
        </tr>
        <tr>
            <th class="underline" lang="en">Factor</th>
            <th class="underline" lang="en">Area</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
            <th class="underline" lang="en">Factor</th>
            <th class="underline" lang="en">Area</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
            <th class="underline" lang="en">Volume</th>
            <th class="underline" lang="en">Adjusted</th>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross sections along your alignment and the cross section set must 
                have the surfaces and features upon which you wish to report displayed.
            </p>
            <p class="normal1" lang="en">
                You can create the XML data file from the <em>End-Area Volumes</em> leaf of the <em>
                Evaluation &gt; Cross Section &gt; Cross Sections</em> command by toggling on the <em>
                Create XML Report</em> option on the <em>General</em> leaf or from the <em>Evaluation &gt; 
                Cross Section &gt; Cross Section Report</em> command by toggling on the <em>Include Volumes
                </em> option on the <em>Main</em> tab.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for datasets containing material quantities or MDC.
            </p>
            <p class="normal1" lang="en">
                This report is an example of how to display volume totals by station range based on a 
                specified length.&#xa0; The default is 700, but you can change this length by changing the 
                value in the <code>stationRange</code> variable near the top of the style sheet.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
