<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- LandXML Horizontal Alignment Review Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">LandXML Horizontal Alignment Review Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="LandXML">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">LandXML Horizontal Alignment Review Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <table class="margin" cellpadding="2" width="90%">
                                <tbody>
                                    <tr>
                                        <th align="right" lang="en">Project:&#xa0; </th>
                                        <td align="left" colspan="2"><xsl:value-of select="Project/@name"/></td>
                                    </tr>
                                    <tr>
                                        <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                        <td align="left" style="font-size: 80%">
                                            <xsl:value-of select="Project/Feature/Property[@label = 'GridScaleFactor']/@value" />
                                        </td>
                                        <td align="right" lang="en" style="font-size: 80%">
                                            <strong>Note:&#xa0; </strong>All units in this report are in
                                            <xsl:if test="Units[Imperial]">feet</xsl:if>
                                            <xsl:if test="Units[Metric]">meters</xsl:if>
                                            unless specified otherwise.
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <hr/>
                            <!-- Horizontal Alignment Data -->
                            <table class="margin" width="90%">
                                <colgroup span="5">
                                    <col width="18%"/>
                                    <col width="13%"/>
                                    <col width="25%"/>
                                    <col width="22%"/>
                                    <col width="22%"/>
                                </colgroup>
                                <tbody>
                                    <xsl:for-each select="Alignments/Alignment/CoordGeom">
                                        <tr>
                                            <th align="right" colspan="2" lang="en"><br />Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="3" valign="bottom"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" colspan="2" lang="en">Alignment Description:&#xa0; </th>
                                            <td align="left" colspan="3"><xsl:value-of select="@desc"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" colspan="2" lang="en">Alignment Style:&#xa0; </th>
                                            <td align="left" colspan="3">
                                                <xsl:value-of select="*/Feature/Property[@label = 'style']/@value"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th colspan="2"/>
                                            <th align="right" class="underline" lang="en">Station</th>
                                            <th align="right" class="underline" lang="en">Northing</th>
                                            <th align="right" class="underline" lang="en">Easting</th>
                                        </tr>
                                        <xsl:apply-templates/>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Linear Data -->
    <xsl:template match="Line">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: linear</td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Start/@code"/></td>
            <td align="right">( <xsl:value-of select="Start/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(@staStart), $xslStationFormat, $xslStationPrecision, '')"/>
            </td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="Start"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="End/@code"/></td>
            <td align="right">( <xsl:value-of select="End/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(@staStart + @length), $xslStationFormat, $xslStationPrecision, '')"/>
            </td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="End"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangential Direction:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@dir), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangential Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Horizontal Circular Data -->
    <xsl:template match="Curve">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: circular</td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Start/@code"/></td>
            <td align="right">( <xsl:value-of select="Start/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(@staStart), $xslStationFormat, $xslStationPrecision, '')"/>
            </td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="Start"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Center/@code"/></td>
            <td align="right">( <xsl:value-of select="Center/@name"/> )</td>
            <td />
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="Center"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="End/@code"/></td>
            <td align="right">( <xsl:value-of select="End/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(@staStart + @length), $xslStationFormat, $xslStationPrecision, '')"/>
            </td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="End"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Radius:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
            <td align="left" lang="en">
                <xsl:if test="@rot = 'cw'">Right</xsl:if>
                <xsl:if test="@rot = 'ccw'">Left</xsl:if>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Chord:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@chord), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="Spiral">
        <tr>
            <td align="left" colspan="5" lang="en"><br/>Element: <xsl:value-of select="@spiType"/></td>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="Start/@code"/></td>
            <td align="right">( <xsl:value-of select="Start/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(@staStart), $xslStationFormat, $xslStationPrecision, '')"/>
            </td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="Start"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="PI/@code"/></td>
            <td align="right">( <xsl:value-of select="PI/@name"/> )</td>
            <td />
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="PI"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right"><xsl:value-of select="End/@code"/></td>
            <td align="right">( <xsl:value-of select="End/@name"/> )</td>
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(@staStart + @length), $xslStationFormat, $xslStationPrecision, '')"/>
            </td>
            <xsl:call-template name="outputYCoord">
                <xsl:with-param name="list" select="End"/>
            </xsl:call-template>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Entrance Radius:</td>
            <td align="right">
                <xsl:choose>
                    <xsl:when test="string(number(@radiusStart)) = 'NaN'">INF</xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:distanceFormat(number(@radiusStart), $xslDistancePrecision)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Exit Radius:</td>
            <td align="right">
                <xsl:choose>
                    <xsl:when test="string(number(@radiusEnd)) = 'NaN'">INF</xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:distanceFormat(number(@radiusEnd), $xslDistancePrecision)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Length:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Angle:</td>
            <td align="right">
                <xsl:value-of select="inr:angularFormat(number(@theta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td lang="en">
                <xsl:if test="@rot = 'cw'">Right</xsl:if>
                <xsl:if test="@rot = 'ccw'">Left</xsl:if>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Constant:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@constant), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Long Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@tanLong), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Short Tangent:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@tanShort), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Xs:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@totalX), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Ys:</td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@totalY), $xslDistancePrecision)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Direction Start:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@dirStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
        <tr>
            <td align="right" colspan="2" lang="en">Tangent Direction End:</td>
            <td align="right">
                <xsl:value-of select="inr:directionFormat(number(@dirEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Coordinates -->
    <xsl:template name="outputYCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <xsl:variable name="rest" select="substring-after($nList, ' ')"/>
        <td align="right"><xsl:value-of select="inr:northingFormat(number($first), $xslNorthingPrecision)"/></td>
        <xsl:if test="$rest">
            <xsl:call-template name="outputXCoord">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="outputXCoord">
        <xsl:param name="list"/>
        <xsl:variable name="nList" select="concat(normalize-space($list), ' ')"/>
        <xsl:variable name="first" select="substring-before($nList, ' ')"/>
        <td align="right"><xsl:value-of select="inr:eastingFormat(number($first), $xslEastingPrecision)"/></td>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Export Alignment</em> tab of the <em>File &gt; Translators &gt; LandXML Translator</em> 
                command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                You must also edit the file produced by the <em>LandXML Translator</em> command to remove 
                the following attributes from the LandXML element at the top:
            </p>
            <ul style="list-style-type:none">
                <li>xmlns="http://www.landxml.org/schema/LandXML-1.1"</li>
                <li>xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"</li>
                <li>
                    xsi:schemaLocation="http://www.landxml.org/schema/LandXML-1.1 
                    http://www.landxml.org/schema/landxml-1.1/LandXML-1.1.xsd"
                </li>
            </ul>
            <p class="normal1" lang="en">
                The LandXML element should now resemble the following, where the version, date and time are 
                replaced with your actual values:
            </p>
            <ul style="list-style-type:none">
                <li>&lt;LandXML version="1.1" date="2009-11-16" time="12:29:43"&gt;</li>
            </ul>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
