<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Occupied key -->
    <xsl:key name="occupiedPoint" match="Observation" use="@occupiedPointName"/>
    <!-- Least Squares Adjusted Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Least Squares Adjusted Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="AdjustmentNet">
                                <center>
                                    <!-- Report Title -->
                                    <h2 lang="en">Least Squares Adjusted Report</h2>
                                    <p lang="en">
                                        Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                        Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                    </p>
                                </center>
                                <p lang="en" style="text-align:right;font-size:80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in 
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                </p>
                                <hr/>
                                <!-- Adjusted Data -->
                                <table class="margin" cellpadding="1" cellspacing="1" width="90%">
                                    <tr>
                                        <th class="underline" lang="en" valign="bottom">From</th>
                                        <th class="underline" lang="en" valign="bottom">To</th>
                                        <th class="underline" lang="en" valign="bottom">Observed<br/>Direction /<br/>Distance</th>
                                        <th class="underline" lang="en" valign="bottom">Standard<br/>Residual</th>
                                        <th class="underline" lang="en" valign="bottom">Least Squares<br/>Correction</th>
                                        <th class="underline" lang="en" valign="bottom">Adjusted<br/>Bearing</th>
                                        <th class="underline" lang="en" valign="bottom">Horizontal<br/>Ground<br/>Distance</th>
                                    </tr>
                                    <xsl:for-each select="//Observation[generate-id() = generate-id(key('occupiedPoint', @occupiedPointName)[1])]">
                                        <xsl:variable name="curOP" select="@occupiedPointName"/>
                                        <xsl:variable name="curFP" select="@foresightPointName"/>
                                        <tr>
                                            <xsl:for-each select="//Observation[@occupiedPointName = $curOP][@foresightPointName = $curFP][@type = 'Horizontal Angle']">
                                                <td><xsl:value-of select="$curOP"/></td>
                                                <td><xsl:value-of select="@foresightPointName[../@occupiedPointName = $curOP]"/></td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:angularFormat(number(ObservationData/@observedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                </td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:distanceFormat(number(ObservationData/@standardResidual), $xslDistancePrecision)"/>
                                                </td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:angularFormat(number(ObservationData/@residualValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                </td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:angularFormat(number(ObservationData/@adjustedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                </td>
                                                <xsl:for-each select="//Observation[@occupiedPointName = $curOP][@foresightPointName = $curFP][@type = 'Horizontal Distance']">
                                                    <td align="right" style="white-space:nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(ObservationData/@adjustedValue), $xslDistancePrecision)"/>
                                                    </td>
                                                </xsl:for-each>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:for-each>
                                    <tr><td colspan="7">&#xa0;</td></tr>
                                    <xsl:for-each select="//Observation[generate-id() = generate-id(key('occupiedPoint', @occupiedPointName)[1])]">
                                        <xsl:variable name="curOP" select="@occupiedPointName"/>
                                        <xsl:variable name="curFP" select="@foresightPointName"/>
                                        <tr>
                                            <xsl:for-each select="//Observation[@occupiedPointName = $curOP][@foresightPointName = $curFP][@type = 'Horizontal Distance']">
                                                <td><xsl:value-of select="$curOP"/></td>
                                                <td><xsl:value-of select="@foresightPointName[../@occupiedPointName = $curOP]"/></td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:distanceFormat(number(ObservationData/@observedValue), $xslDistancePrecision)"/>
                                                </td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:distanceFormat(number(ObservationData/@standardResidual), $xslDistancePrecision)"/>
                                                </td>
                                                <td align="right" style="white-space:nowrap">
                                                    <xsl:value-of select="inr:distanceFormat(number(ObservationData/@residualValue), $xslDistancePrecision)"/>
                                                </td>
                                                <xsl:for-each select="//Observation[@occupiedPointName = $curOP][@foresightPointName = $curFP][@type = 'Horizontal Angle']">
                                                    <td align="right" style="white-space:nowrap">
                                                        <xsl:value-of select="inr:angularFormat(number(ObservationData/@adjustedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                    </td>
                                                </xsl:for-each>
                                                <xsl:for-each select="//Observation[@occupiedPointName = $curOP][@foresightPointName = $curFP][@type = 'Horizontal Distance']">
                                                    <td align="right" style="white-space:nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(ObservationData/@adjustedValue), $xslDistancePrecision)"/>
                                                    </td>
                                                </xsl:for-each>
                                            </xsl:for-each>
                                        </tr>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have a survey network and you must also have run the <em>Survey &gt; Network &gt; 
                Least Squares Adjustment</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
