<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Level by Alpha Code Report -->
    <xsl:template match="/">
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Design File Level by Alpha Code Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="CivilIni">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Design File Level by Alpha Code Report</h2>
                                <p lang="en">
                                    Report Created: &#xa0;<xsl:value-of select="inr:date()"/><br/>
                                    Time: &#xa0;<xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="FeatureStyleCollection">
                                <table class="margin" cellpadding="2" width="90%">
                                    <thead>
                                        <tr>
                                            <th class="underline" lang="en">Alpha Code</th>
                                            <th class="underline" lang="en">Numeric Code</th>
                                            <th class="underline" lang="en">Default</th>
                                            <th class="underline" lang="en">Plan</th>
                                            <th class="underline" lang="en">Custom Operations</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="FeatureStyle/SurveyFeature/NamedSymbologyName">
                                            <xsl:variable name="nsName" select="@Name"/>
                                            <xsl:choose>
                                                <xsl:when test="string(../AlphaCode/@Code) != ''">
                                                    <xsl:for-each select="../AlphaCode">
                                                        <tr>
                                                            <td align="left" valign="top"><xsl:value-of select="@Code"/></td>
                                                            <xsl:choose>
                                                                <xsl:when test="../@NumericCode != 0">
                                                                    <td align="left" valign="top"><xsl:value-of select="../@NumericCode"/></td>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <td align="left" valign="top">--</td>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                            <xsl:for-each select="../../../../NamedSymbologyCollection/NamedSymbology">
                                                                <xsl:if test="@ItemName=$nsName">
                                                                    <td>
                                                                        <table class="margin" cellpadding="2" width="90%">
                                                                            <tbody>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(DefaultLineSymbology/LineSymbology/@LayerName) != ''">
                                                                                            <td align="left"><b>Line:  <xsl:value-of select="DefaultLineSymbology/LineSymbology/@LayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Line:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(DefaultTextSymbology/BaseTextSymbology/@LayerName) != ''">
                                                                                            <td align="left"><b>Text:  <xsl:value-of select="DefaultTextSymbology/BaseTextSymbology/@LayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Text:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(DefaultPointSymbology/BasePointSymbology/@DisplaySymbol) != 0">
                                                                                            <td align="left"><b>Point-Symbol: <xsl:value-of select="DefaultPointSymbology/BasePointSymbology/@SymbolLayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Point-Symbol: --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr><tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="(DefaultPointSymbology/BasePointSymbology/@DisplayCellBlock) != 0">
                                                                                            <td align="left"><b>Point-Cell: <xsl:value-of select="DefaultPointSymbology/BasePointSymbology/@CellLayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Point-Cell: --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                    <td>
                                                                        <table class="margin" cellpadding="2" width="90%">
                                                                            <tbody>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(PlanLineSymbology/LineSymbology/@LayerName) != ''">
                                                                                            <td align="left"><b>Line:  <xsl:value-of select="PlanLineSymbology/LineSymbology/@LayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Line:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(PlanTextSymbology/BaseTextSymbology/@LayerName) != ''">
                                                                                            <td align="left"><b>Text:  <xsl:value-of select="PlanTextSymbology/BaseTextSymbology/@LayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Text:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(PlanPointSymbology/BasePointSymbology/@DisplaySymbol) != 0">
                                                                                            <td align="left"><b>Point-Symbol: <xsl:value-of select="PlanPointSymbology/BasePointSymbology/@SymbolLayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Point-Symbol: --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr><tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="(PlanPointSymbology/BasePointSymbology/@DisplayCellBlock) != 0">
                                                                                             <td align="left"><b>Point-Cell: <xsl:value-of select="PlanPointSymbology/BasePointSymbology/@CellLayerName"/></b></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Point-Cell: --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </xsl:if>
                                                            </xsl:for-each>
                                                            <xsl:for-each select="../CustomOperations">
                                                                <xsl:if test="string-length(@Value) &gt; 3 ">
                                                                    <xsl:variable name="value" select="substring(@Value, 1, 3)"/>
                                                                    <xsl:if test="$value = 'LV='">
                                                                        <td align="left" valign="top"><b><xsl:value-of select="substring( @Value, 4, string-length(@Value) - 3)"/></b></td>
                                                                    </xsl:if>
                                                                </xsl:if>
                                                            </xsl:for-each>
                                                        </tr>
                                                    </xsl:for-each>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:if test="../@NumericCode != 0">
                                                        <tr>
                                                            <td align="left" valign="top">--</td>
                                                            <td align="left" valign="top"><xsl:value-of select="../@NumericCode"/></td>
                                                            <xsl:for-each select="../../../../NamedSymbologyCollection/NamedSymbology">
                                                                <xsl:if test="@ItemName=$nsName">
                                                                    <td>
                                                                        <table class="margin" cellpadding="2" width="90%">
                                                                            <tbody>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(DefaultLineSymbology/LineSymbology/@LayerName) != ''">
                                                                                            <td align="left">Line:  <xsl:value-of select="DefaultLineSymbology/LineSymbology/@LayerName"/></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Line:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(DefaultTextSymbology/BaseTextSymbology/@LayerName) != ''">
                                                                                            <td align="left">Text:  <xsl:value-of select="DefaultTextSymbology/BaseTextSymbology/@LayerName"/></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Text:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(DefaultPointSymbology/BasePointSymbology/@SymbolLayerName) != ''">
                                                                                            <td align="left">Point: <xsl:value-of select="DefaultPointSymbology/BasePointSymbology/@SymbolLayerName"/></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Point: --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                    <td>
                                                                        <table class="margin" cellpadding="2" width="90%">
                                                                            <tbody>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(PlanLineSymbology/LineSymbology/@LayerName) != ''">
                                                                                            <td align="left">Line:  <xsl:value-of select="PlanLineSymbology/LineSymbology/@LayerName"/></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Line:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(PlanTextSymbology/BaseTextSymbology/@LayerName) != ''">
                                                                                            <td align="left">Text:  <xsl:value-of select="PlanTextSymbology/BaseTextSymbology/@LayerName"/></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Text:  --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                                <tr>
                                                                                    <xsl:choose>
                                                                                        <xsl:when test="string(PlanPointSymbology/BasePointSymbology/@SymbolLayerName) != ''">
                                                                                            <td align="left">Point: <xsl:value-of select="PlanPointSymbology/BasePointSymbology/@SymbolLayerName"/></td>
                                                                                        </xsl:when>
                                                                                        <xsl:otherwise>
                                                                                            <td align="left">Point: --</td>
                                                                                        </xsl:otherwise>
                                                                                    </xsl:choose>
                                                                                </tr>
                                                                            </tbody>
                                                                        </table>
                                                                    </td>
                                                                </xsl:if>
                                                            </xsl:for-each>
                                                            <xsl:for-each select="../CustomOperations">
                                                                <xsl:if test="string-length(@Value) &gt; 3 ">
                                                                    <xsl:variable name="value" select="substring(@Value, 1, 3)"/>
                                                                    <xsl:if test="$value = 'LV='">
                                                                        <td align="left" valign="top"><b><xsl:value-of select="substring( @Value, 4, string-length(@Value) - 3)"/></b></td>
                                                                    </xsl:if>
                                                                </xsl:if>
                                                            </xsl:for-each>
                                                        </tr>
                                                    </xsl:if>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must open a Preferences file by selecting <em>File &gt; Open</em> on the <em>Report 
                Browser</em> menu and setting the <em>Files of type</em> field to <em>Preferences 
                (*.xin)</em>.
            </p>
            <p class="normal1" lang="en">
                Your Preferences file must contain Alpha Codes for your survey feature styles.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
