<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- SDR33 Export Format Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/SurveyFieldbook/SurveyPointList">
                    <xsl:text/>
                    <xsl:for-each select="SurveyPoint">
                        <xsl:variable name="fmtNorthing" select="inr:northingFormat(number(@northing), 4)"/>
                        <xsl:variable name="fmtEasting" select="inr:northingFormat(number(@easting), 4)"/>
                        <xsl:variable name="fmtElevation" select="inr:northingFormat(number(@elevation), 4)"/>
                        <xsl:text>08KI</xsl:text>
                        <xsl:choose>
                            <xsl:when test="string-length(@name) &gt; 16">
                                <xsl:value-of select="substring(@name, (string-length(@name) - 15), 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length(@name) &lt; 16">
                                <xsl:value-of select="@name"/>
                                <xsl:value-of select="substring('                ', 1, (16 - string-length(@name)))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@name"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="string-length($fmtNorthing) &gt; 16">
                                <xsl:value-of select="substring($fmtNorthing, (string-length($fmtNorthing) - 15), 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length($fmtNorthing) &lt; 16">
                                <xsl:value-of select="$fmtNorthing"/>
                                <xsl:value-of select="substring('          ', 1, (16 - string-length($fmtNorthing)))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$fmtNorthing"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="string-length($fmtEasting) &gt; 16">
                                <xsl:value-of select="substring($fmtEasting, (string-length($fmtEasting) - 15), 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length($fmtEasting) &lt; 16">
                                <xsl:value-of select="$fmtEasting"/>
                                <xsl:value-of select="substring('          ', 1, (16 - string-length($fmtEasting)))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$fmtEasting"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="string-length($fmtElevation) &gt; 16">
                                <xsl:value-of select="substring($fmtElevation, (string-length($fmtElevation) - 15), 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length($fmtElevation) &lt; 16">
                                <xsl:value-of select="$fmtElevation"/>
                                <xsl:value-of select="substring('          ', 1, (16 - string-length($fmtElevation)))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$fmtElevation"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="string-length(@code) &gt; 16">
                                <xsl:value-of select="substring(@code, 1, 16)"/>
                            </xsl:when>
                            <xsl:when test="string-length(@code) &lt; 16">
                                <xsl:value-of select="@code"/>
                                <xsl:value-of select="substring('                ', 1, (16 - string-length(@code)))"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="@code"/>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select at least one fieldbook in the Survey &gt;&#xd;</xsl:text>
        <xsl:text>    XML Report command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Your fieldbook must contain data for a complete report.&#xd;&#xd;</xsl:text>
        <xsl:text>    This report emulates the Text Export Wizard called&#xd;</xsl:text>
        <xsl:text>    SDR33.tew.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
