<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Single Table Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Single Table Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/HorizontalAnnotationTable">
                            <table class="margin" border="1" cellpadding="2" cellspacing="0" width="90%">
                                <thead style="display:table-header-group">
                                    <tr style="line-height:300%">
                                        <th colspan="6" lang="en" valign="middle">Horizontal Elements Table</th>
                                    </tr>
                                    <tr>
                                        <th lang="en" valign="middle">Name</th>
                                        <th lang="en" valign="middle">Direction /<br/>Chord Direction</th>
                                        <th lang="en" valign="middle">Length</th>
                                        <th lang="en" valign="middle">Delta</th>
                                        <th lang="en" valign="middle">Radius</th>
                                        <th lang="en" valign="middle">Theta</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <xsl:for-each select="*">
                                        <xsl:apply-templates/>
                                    </xsl:for-each>
                                </tbody>
                            </table>
                            <br style="line-height:200%"/>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <tr>
            <td><xsl:value-of select="../@name"/></td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">&#xa0;</td>
            <td class="sidepad" align="right" style="white-space:nowrap">&#xa0;</td>
            <td class="sidepad" align="right" style="white-space:nowrap">&#xa0;</td>
        </tr>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <tr>
            <td><xsl:value-of select="../@name"/></td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:angularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:choose>
                    <xsl:when test="@rotationDirection = 'ccw'">
                        <xsl:value-of select="inr:distanceFormat(number(-1 * @radius), $xslDistancePrecision)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                    </xsl:otherwise>
                </xsl:choose>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">&#xa0;</td>
        </tr>
    </xsl:template>
    <!-- Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <tr>
            <td><xsl:value-of select="../@name"/></td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:directionFormat(number(@chordDirection), $xslDirectionFormat,  $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>
            <td class="sidepad" align="right" style="white-space:nowrap">&#xa0;</td>
            <td class="sidepad" align="right" style="white-space:nowrap">&#xa0;</td>
            <td class="sidepad" align="right" style="white-space:nowrap">
                <xsl:value-of select="inr:angularFormat(number(@thetaAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment or one Cogo point on the <em>Main</em> 
                tab of the <em>Geometry &gt; View Geometry &gt; Horizontal Annotation</em> command.
            </p>
            <p class="normal1" lang="en">
                You must select <em>Assigned</em> or <em>Active</em> in the <em>Apply Style</em> group and 
                the selected style, whether it is the assigned style or the active, must have the <em>Allow 
                Tabling</em> option toggled on for the element type you wish to table.&#xa0; For example, 
                if you wish to table spirals, select the <em>Tools &gt; Style Manager</em> command and find 
                your style.&#xa0; Select the <em>Edit</em> button and navigate to the <em>Geometry Feature 
                &gt; Spirals &gt; Alternate</em> leaf and toggle on the <em>Allow Tabling</em> 
                option.&#xa0; Do this for each element type in each feature style that you plan to table.
            </p>
            <p class="normal1" lang="en">
                You must select either <em>Basic Element Information</em> or <em>All Element 
                Information</em> on the <em>Tabling</em> tab of the <em>Geometry &gt; View Geometry &gt; 
                Horizontal Annotation</em> command to get results from this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                You can place the results of your report into your MicroStation design file by highlighting 
                the text you wish to copy in the <em>Report Browser</em>, keying in CTRL+C, and then keying 
                in CTRL+V in your design file.
            </p>
            <p class="normal1" lang="en">
                You may have to edit the text once placed in your design file to correct the 
                alignment.&#xa0; You will have better results if you select a "text only" style sheet and 
                choose a monospaced font in MicroStation.
            </p>
            <p class="normal1" lang="en">
                Also, many of the fonts delivered within the MicroStation resource file have mapped the 
                degree symbol (&#xb0;) to something else.&#xa0; You can either edit the text and replace 
                whatever it mapped to with the caret (^), which will then display properly as the degree 
                symbol, or you can select a standard TrueType font.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
