<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique bearing lines -->
    <xsl:variable name="uniqueBearingLine" select="//TransverseLines/TransverseLine[not (@name = preceding-sibling::TransverseLine/@name)][@type != 'Abutment']/@name"/>
    <!-- Coninutous Girder Layout from Bearing Line Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Continuous Girder Layout from Bearing Line Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Girder Layout from Bearing Line Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="BridgeProject">
                                <table cellpadding="2" class="margin" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Beam Layout Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="BridgeCenterLine">
                                        <xsl:for-each select="$uniqueBearingLine[following::*[1]/@type != 'Abutment']">
                                            <xsl:variable name="bckBLName" select="current()"/>
                                            <xsl:variable name="ahdBLName" select="following::*[1]/@name"/>
                                            <tbody>
                                                <tr>
                                                    <th colspan="5">
                                                        Span <xsl:value-of select="//TransverseLine[@name = $bckBLName]/@startSpan"/>
                                                        <xsl:if test="//TransverseLine[@name = $bckBLName]/@startSpan != //TransverseLine[@name = $bckBLName]/@stopSpan">
                                                            to <xsl:value-of select="//TransverseLine[@name = $bckBLName]/@stopSpan"/>
                                                        </xsl:if>
                                                    </th>
                                                </tr>
                                                <tr>
                                                    <th valign="bottom">&#xa0;</th>
                                                    <th colspan="2" lang="en" valign="bottom">- - - - - Back Bearing Line - - - - -</th>
                                                    <th colspan="2" lang="en" valign="bottom">- - - - - Ahead Bearing Line - - - - -</th>
                                                </tr>
                                                <tr>
                                                    <th valign="bottom">&#xa0;</th>
                                                    <td align="center">
                                                        <xsl:value-of select="$bckBLName"/>
                                                    </td>
                                                    <td align="center">
                                                        (<xsl:value-of select="inr:angularFormat(number(//TransverseLine[@name = $bckBLName]/@direction), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>)
                                                    </td>
                                                    <td align="center">
                                                        <xsl:value-of select="$ahdBLName"/>
                                                    </td>
                                                    <td align="center">
                                                        (<xsl:value-of select="inr:angularFormat(number(//TransverseLine[@name = $ahdBLName]/@direction), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>)
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th valign="bottom">&#xa0;</th>
                                                    <th class="underline" lang="en" valign="bottom">Girder Spacing<br/>at Bearing Line</th>
                                                    <th class="underline" lang="en" valign="bottom">Girder Angle</th>
                                                    <th class="underline" lang="en" valign="bottom">Girder Spacing<br/>at Bearing Line</th>
                                                    <th class="underline" lang="en" valign="bottom">Girder Angle</th>
                                                </tr>
                                                <xsl:for-each select="//Girder[*/Layouts/Layout/@transverseName = $ahdBLName]">
                                                    <tr>
                                                        <td align="left"><xsl:value-of select="@name"/></td>
                                                        <td align="center">
                                                            <xsl:value-of select="inr:distanceFormat(number(*/Layouts/Layout[@transverseName = $bckBLName]/@distanceToLeftGirder), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="center" nowrap="nowrap">
                                                            <xsl:value-of select="inr:angularFormat(number(*/Layouts/Layout[@transverseName = $bckBLName]/@radialSkewAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                        </td>
                                                        <td align="center">
                                                            <xsl:value-of select="inr:distanceFormat(number(*/Layouts/Layout[@transverseName = $ahdBLName]/@distanceToLeftGirder), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="center" nowrap="nowrap">
                                                            <xsl:value-of select="inr:angularFormat(number(*/Layouts/Layout[@transverseName = $ahdBLName]/@radialSkewAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:for-each>
                                                <tr><td colspan="4">&#xa0;</td></tr>
                                            </tbody>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active alignment must be a bridge alignment and you must have created slab fascia, 
                abutments/piers, bearing lines and girders for the bridge.
            </p>
            <p class="normal1" lang="en">
                You must also select the <em>Bridge &gt; Bridge Reports</em> command to get results from 
                this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2009 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
