<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique cross section surfaces -->
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <!-- Cross Section to AGTEK Compressed EndArea Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <xsl:text/>
                    <xsl:for-each select="CrossSectionSet/CrossSectionStations/CrossSectionStation">
                        <xsl:for-each select="CrossSectionSurfaces/CrossSectionSurface[@type = '0']">
                            <xsl:text>     STA.</xsl:text>
                            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(../../Station/@externalStation), $xslStationFormat, $xslStationPrecision, string(../Station/@externalStationName)), 10)"/>
                            <xsl:value-of select="inr:columnFormat(string(@name), 11)"/>
                            <xsl:text> SURFACE&#xd;&#xd;</xsl:text>
                            <xsl:text>     ELEV     DIST      ELEV     DIST      ELEV     DIST      ELEV     DIST      ELEV     DIST&#xd;</xsl:text>
                            <xsl:text>    ======   ======    ======   ======    ======   ======    ======   ======    ======   ======&#xd;</xsl:text>
                            <xsl:for-each select="CrossSectionPoints">
                                <xsl:call-template name="showPointData">
                                    <xsl:with-param name="list" select="CrossSectionPoint"/>
                                </xsl:call-template>
                            </xsl:for-each>
                            <xsl:text>&#xd;&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:for-each select="CrossSectionBottomOfDesign">
                            <xsl:text>     STA.</xsl:text>
                            <xsl:value-of select="inr:columnFormat(inr:stationFormat(number(../Station/@externalStation), $xslStationFormat, $xslStationPrecision, string(../Station/@externalStationName)), 10)"/>
                            <xsl:value-of select="inr:columnFormat(string(../CrossSectionSurfaces/CrossSectionSurface[@type = '1']/@name), 11)"/>
                            <xsl:text> SURFACE&#xd;&#xd;</xsl:text>
                            <xsl:text>     ELEV     DIST      ELEV     DIST      ELEV     DIST      ELEV     DIST      ELEV     DIST&#xd;</xsl:text>
                            <xsl:text>    ======   ======    ======   ======    ======   ======    ======   ======    ======   ======&#xd;</xsl:text>
                            <xsl:for-each select="CrossSectionPoints">
                                <xsl:call-template name="showPointData">
                                    <xsl:with-param name="list" select="CrossSectionPoint"/>
                                </xsl:call-template>
                            </xsl:for-each>
                            <xsl:text>&#xd;&#xd;</xsl:text>
                        </xsl:for-each>
                        <xsl:text>===============================================================================================&#xd;&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="showPointData">
        <xsl:param name="list"/>
        <xsl:param name="rest" select="$list[position() &gt; 5]"/>
        <xsl:if test="$list[1]">
            <xsl:value-of select="inr:columnDoubleFormat(number($list[1]/@elevation), $xslElevationPrecision, 10)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($list[1]/@offset), $xslDistancePrecision, 9)"/>
        </xsl:if>
        <xsl:if test="$list[2]">
            <xsl:value-of select="inr:columnDoubleFormat(number($list[2]/@elevation), $xslElevationPrecision, 10)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($list[2]/@offset), $xslDistancePrecision, 9)"/>
        </xsl:if>
        <xsl:if test="$list[3]">
            <xsl:value-of select="inr:columnDoubleFormat(number($list[3]/@elevation), $xslElevationPrecision, 10)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($list[3]/@offset), $xslDistancePrecision, 9)"/>
        </xsl:if>
        <xsl:if test="$list[4]">
            <xsl:value-of select="inr:columnDoubleFormat(number($list[4]/@elevation), $xslElevationPrecision, 10)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($list[4]/@offset), $xslDistancePrecision, 9)"/>
        </xsl:if>
        <xsl:if test="$list[5]">
            <xsl:value-of select="inr:columnDoubleFormat(number($list[5]/@elevation), $xslElevationPrecision, 10)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number($list[5]/@offset), $xslDistancePrecision, 9)"/>
        </xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="$rest">
            <xsl:call-template name="showPointData">
                <xsl:with-param name="list" select="$rest"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must have created cross sections along your&#xd;</xsl:text>
        <xsl:text>    alignment and the cross section set must have the&#xd;</xsl:text>
        <xsl:text>    surfaces and features upon which you wish to report&#xd;</xsl:text>
        <xsl:text>    displayed.&#xd;&#xd;</xsl:text>
        <xsl:text>    You can create the XML data file from the Evaluation &gt;&#xd;</xsl:text>
        <xsl:text>    Cross Section &gt; Cross Section Report command or from&#xd;</xsl:text>
        <xsl:text>    the End-Area Volumes leaf of the Evaluation &gt; Cross&#xd;</xsl:text>
        <xsl:text>    Section &gt; Cross Sections command by toggling on&#xd;</xsl:text>
        <xsl:text>    the Create XML Report option on the General leaf.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
