<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:variable name="pi" select="inr:setPI()"/>
    <!-- Variable to hold unit string -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> feet</xsl:when>
            <xsl:otherwise> meters</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Variable to hold tangency tolerance -->
    <xsl:variable name="tangentTol" select="number(0.1 div 3600)"/>
    <!-- Phoenix Legal Description Format -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <!--link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/-->
                <style type="text/css">body{font-family:"Times New Roman";}</style>
                <!-- Title displayed in browser Title Bar -->
                <title>Phoenix Legal Description Format</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/GeometryProject">
                            <p lang="en">
                                <xsl:value-of select="inr:date()"/><br/>
                                Rick No.<br/>
                                SCB
                            </p>
                            <center><h3 lang="en">DESCRIPTION</h3></center>
                            <p lang="en">
                                &#xa0; &#xa0;A portion of the ___ quarter of Section ___, Township ___ North,
                                Range ___ East, Gila and Salt River Meridian, Maricopa County, Arizona, 
                                being more particularly described as follows:
                            </p>
                            <xsl:for-each select="HorizontalAlignment">
                                <p lang="en">
                                    COMMENCING at ____;<br/>
                                    THENCE ____ to the POINT OF BEGINNING;<br/>
                                    <xsl:apply-templates/>
                                    <xsl:choose>
                                        <xsl:when test="@area &gt; 0">
                                            to the POINT OF BEGINNING, as shown on Exhibit "A" attached 
                                            herewith as page ___ of ___.&#xa0;  Subject parcel comprising 
                                            <xsl:choose>
                                                <xsl:when test="//@linearUnits = 'Metric'">
                                                    <xsl:value-of select="inr:acreFormat(number(@area) div 10000, $xslAcrePrecision)"/>
                                                    hectares,
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="inr:acreFormat(number(@area) div 43560, $xslAcrePrecision)"/>
                                                    acres,
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            more or less, and subject to all easements of record.
                                        </xsl:when>
                                        <xsl:otherwise>
                                            to the POINT OF TERMINATION, as shown on Exhibit "A" attached 
                                            herewith as page ___ of ___.
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </p>
                                <br/>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Line -->
    <xsl:template match="HorizontalLine">
        <xsl:variable name="angDiffAhead">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @direction &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @direction) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @direction &gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@tangentialDirectionStart - @direction"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="position() = 1">
                THENCE continuing
                <xsl:value-of select="inr:phxDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <xsl:value-of select="$unit"/>
                        <xsl:choose>
                            <!-- Ahead curve is not tangent within tangency tolerance -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                to the beginning of a non-tangent curve, the center of which bears
                                <xsl:choose>
                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                        <xsl:value-of select="inr:phxDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="inr:phxDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                <xsl:value-of select="$unit"/>;<br/>
                            </xsl:when>
                            <!-- Ahead curve is tangent within tangency tolerance -->
                            <xsl:otherwise>
                                to the beginning of a curve with a radius of 
                                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                <xsl:value-of select="$unit"/>
                                <xsl:choose>
                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                        to the left;<br/>
                                    </xsl:when>
                                    <xsl:otherwise> to the right;<br/></xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        spirals not supported<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$unit"/>;<br/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:when test="position() = last()">
                THENCE
                <xsl:value-of select="inr:phxDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
            </xsl:when>
            <xsl:otherwise>
                THENCE
                <xsl:value-of select="inr:phxDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <xsl:value-of select="$unit"/>
                        <xsl:choose>
                            <!-- Direction of current line is not equal to start direction of following curve -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                to the beginning of a non-tangent curve, the center of which bears
                                <xsl:choose>
                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                        <xsl:value-of select="inr:phxDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="inr:phxDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                <xsl:value-of select="$unit"/>;<br/>
                            </xsl:when>
                            <!-- Otherwise, the following curve is tangent -->
                            <xsl:otherwise>
                                to the beginning of a curve with a radius of 
                                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                <xsl:value-of select="$unit"/>
                                <xsl:choose>
                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                        to the left;<br/>
                                    </xsl:when>
                                    <xsl:otherwise> to the right;<br/></xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        spirals not supported<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$unit"/>;<br/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Circle -->
    <xsl:template match="HorizontalCircle">
        <xsl:variable name="angDiffAhead">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd &gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="angDiffAheadLin">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@direction - @tangentialDirectionEnd &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@direction - @tangentialDirectionEnd) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@direction - @tangentialDirectionEnd&gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@direction - @tangentialDirectionEnd"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="position() = 1">
                THENCE continuing
                <xsl:value-of select="inr:phxDirectionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>;<br/>
            </xsl:when>
            <xsl:when test="position() = last()">
                THENCE
                <xsl:call-template name="directionAdverbComma">
                    <xsl:with-param name="inputDir" select="@chordDirection"/>
                </xsl:call-template>
                along the arc of said curve, through a central angle of 
                <xsl:value-of select="inr:phxAngularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>,
                for an arc distance of 
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
            </xsl:when>
            <xsl:otherwise>
                THENCE
                <xsl:call-template name="directionAdverbComma">
                    <xsl:with-param name="inputDir" select="@chordDirection"/>
                </xsl:call-template>
                along the arc of said curve, through a central angle of 
                <xsl:value-of select="inr:phxAngularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>,
                for an arc distance of 
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <xsl:choose>
                            <!-- End direction of current curve is not equal to start direction of following curve -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                to the beginning of a non-tangent curve, the center of which bears
                                <xsl:choose>
                                    <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                        <xsl:value-of select="inr:phxDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="inr:phxDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>,
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                <xsl:value-of select="$unit"/>;<br/>
                            </xsl:when>
                            <!-- Otherwise, following curve is tangent -->
                            <xsl:otherwise>
                                <xsl:choose>
                                    <!-- If directions are not equal, it is a reverse curve -->
                                    <xsl:when test="@rotationDirection != following-sibling::*[1]/@rotationDirection">
                                        <xsl:value-of select="$unit"/>
                                        to a point of reverse curvature marking the beginning of a curve with a radius of 
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unit"/>
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                to the left;<br/>
                                            </xsl:when>
                                            <xsl:otherwise> to the right;<br/></xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <!-- Otherwise, it is a compound -->
                                    <xsl:otherwise>
                                        <xsl:value-of select="$unit"/>
                                        to a point of compound curvature marking the beginning of a curve with a radius of 
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unit"/>
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                to the left;<br/>
                                            </xsl:when>
                                            <xsl:otherwise> to the right;<br/></xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        spirals not supported<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:choose>
                            <!-- End direction of current curve is not equal to direction of following line -->
                            <xsl:when test="$angDiffAheadLin &gt; $tangentTol">
                                <xsl:value-of select="$unit"/>
                                to the beginning of a non-tangent line;<br/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$unit"/>;<br/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="directionAdverbComma">
        <xsl:param name="inputDir"/>
        <xsl:choose>
            <xsl:when test="$inputDir &gt;= 0.125 * $pi and $inputDir &lt; 0.375 * $pi">
                northeasterly,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.375 * $pi and $inputDir &lt; 0.625 * $pi">
                easterly,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.625 * $pi and $inputDir &lt; 0.875 * $pi">
                southeasterly,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.875 * $pi and $inputDir &lt; 1.125 * $pi">
                southerly,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.125 * $pi and $inputDir &lt; 1.375 * $pi">
                southwesterly,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.375 * $pi and $inputDir &lt; 1.625 * $pi">
                westerly,
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.625 * $pi and $inputDir &lt; 1.875 * $pi">
                northwesterly,
            </xsl:when>
            <xsl:otherwise>
                northerly,
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Legal Description</em> or the <em>Tools &gt; XML Reports 
                &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for a reference alignment or for alignments containing spirals.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of directional information with North, East, South and West 
            // and degrees, minutes and seconds spelled out fully.
            // n - value from XML
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // precision - the number of digits after the decimal point
            // mode - (1 - Bearing, 2 - Bearings from North Only, 3 - North Azimuth, 4 - South Azimuth)
            function phxDirectionFormat(n, format, precision, mode, method)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // this adds 360 to a negative number until it becomes positive
                    while (n < 0)
                    {
                        n += (2 * Math.PI);
                    }
                    // this subtracts 360 if the number is greater than 360
                    while (n >= (2 * Math.PI))
                    {
                        n -= (2 * Math.PI);
                    }
                    // mode 1 - Bearing, mode 2 - North Bearing
                    if (mode == 1 || mode == 2)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // identifies the quadrant
                        if (decdeg <= 90)
                        {
                            var strAngle = phxAngularFormat(n, format, precision, method);
                            return "North " + strAngle + " East";
                        }
                        // identifies the quadrant
                        if (90 < decdeg && decdeg <= 180)
                        {
                            n = Math.PI - n;
                            var strAngle = phxAngularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "South " + strAngle + " East";
                            }
                            else
                            {
                                return "North " + strAngle + " West";
                            }
                        }
                        // identifies the quadrant 
                        if (180 < decdeg && decdeg < 270)
                        {
                            n -= Math.PI;
                            var strAngle = phxAngularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "South " + strAngle + " West";
                            }
                            else
                            {
                                return "North " + strAngle + " East";
                            }
                        }
                        // identifies the quadrant
                        if (270 <= decdeg && decdeg < 360)
                        {
                            n = (2.0 * Math.PI) - n;
                            var strAngle = phxAngularFormat(n, format, precision, method);
                            return "North " + strAngle + " West";
                        }
                    }
                    // mode 3 - North Azimuth
                    if (mode == 3)
                    {
                        var strAngle = phxAngularFormat(n, format, precision, method);
                        return strAngle;
                    }
                    // mode 4 - South Azimuth
                    if (mode == 4)
                    {
                        n = n + Math.PI;
                        if (n >= (2.0 * Math.PI))
                        {
                            n = n - (2.0 * Math.PI);
                        }
                        var strAngle = phxAngularFormat(n, format, precision, method);
                        return strAngle;
                     }
                }
                return "NaN";
             }
            // This function sets the format of angular information.
            // n - value from xml
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // formatMethod - (1 - Degrees, 2 - Grads, 3 - Radians, 4 - Mils)
            // precision - the number of digits after the decimal point
            function phxAngularFormat(n, format, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if (!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the value
                    if (formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // format 1 - this converts the number to "degrees minutes seconds"
                        if (format == 1)
                        {
                            // takes only the whole number (ddd)
                            deg = Math.floor(Math.abs(decdeg));
                            if (deg < 10)
                            {
                                deg = "0" + deg;
                            }
                            // multiplies the decimal portion by 60 to get the minutes
                            var decmin = (Math.abs(decdeg) - deg) * 60;
                            // takes only the whole part of that number (minutes)
                            var min = Math.floor(decmin);
                            // multiplies the decimal portion by 60 to get the seconds
                            var decsec = (decmin - min) * 60;
                            // calls the function that gives the number the correct precision
                            var str = formatNumber(decsec, precision);
                            if (str.substring(0,2) == "60")
                            {
                                decsec = 0;
                                str = formatNumber(decsec, precision);
                                min = min + 1;
                                if (min == 60)
                                {
                                    min = 0;
                                    deg = deg + 1;
                                }
                            }
                            if (min < 10)
                            {
                                min = "0" + min;
                            }
                            var sec = str;
                            if (sec < 10)
                            {
                                sec = "0" + sec;
                            }
                            var msg;
                            if(decdeg >= 0 || decdeg <= -1)
                            {
                                if (decdeg < 0)
                                {
                                    msg =  "-" + deg + " degrees " + min + " minutes " + sec + " seconds";
                                }
                                else
                                {
                                    msg =  deg + " degrees " + min + " minutes " + sec + " seconds";
                                }
                            }
                            else
                            {
                                msg =  "-0" + " degrees " + min + " minutes " + sec + " seconds";
                            }
                            return msg;
                        }
                        // format 2 - "decimal degrees"
                        if (format == 2)
                        {
                            // this calls the function that gives the number the correct precision
                            var str = formatNumber(decdeg, precision);
                            str = str + "degrees";
                            return str;
                        }
                    }
                    //converts Radians to Grads
                    if (formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        if (useAngSuffix == true)
                        {
                            grad = grad + "g";
                        }
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if (formatMethod == 3)
                    {
                        // this calls the function that gives the number the correct precision
                        var radian = formatNumber(n, precision);
                        if (useAngSuffix == true)
                        {
                            radian = radian + "r";
                        }
                        return radian;
                    }
                    //converts Radians to Mils
                    if (formatMethod == 4)
                    {
                         var radtomils = n * (6400.0 / (2.0 * Math.PI));
                         var mils = formatNumber(radtomils, precision);
                         return mils;
                    }
                }
                return "NaN";
            }
            function setPI()
            {
                var strPI = Math.PI;
                return strPI;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
