<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:variable name="pi" select="inr:setPI()"/>
    <!-- Variables to hold unit strings -->
    <xsl:variable name="unit">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> feet</xsl:when>
            <xsl:otherwise> meters</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="unitSingular">
        <xsl:choose>
            <xsl:when test="//@linearUnits = 'Imperial'"> foot</xsl:when>
            <xsl:otherwise> meter</xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Variable to hold tangency tolerance -->
    <xsl:variable name="tangentTol" select="number(0.1 div 3600)"/>
    <!-- San Diego Course Legal Description Format -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <!--link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/-->
                <style type="text/css">body{font-family:"Times New Roman";}</style>
                <!-- Title displayed in browser Title Bar -->
                <title>San Diego Course Legal Description Format</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads/GeometryProject">
                            <p lang="en">J-______</p>
                            <center>
                                <p lang="en">EXHIBIT "A"</p>
                                <p lang="en">EXAMPLE EASEMENT</p>
                            </center>
                            <p lang="en">
                                <span style="text-decoration:underline;">Parcel " "</span><br/>
                                Being a portion of Lot ____ of (name of Subdivision) in the City of 
                                ____________, County of ____________, State of California, according to Map 
                                thereof No. _____ filed in the Office of the County Recorder of San Diego 
                                County _________ ___, ______ said portion being more particularly described 
                                as follows:
                            </p>
                            <xsl:for-each select="HorizontalAlignment">
                                <p lang="en">
                                    <strong>Beginning</strong> at the ______;<br/>
                                    to the <strong>TRUE POINT OF BEGINNING;</strong><br/>
                                    <xsl:apply-templates/>
                                    <xsl:choose>
                                        <xsl:when test="@area &gt; 0">
                                            to the <strong>TRUE POINT OF BEGINNING.</strong><br/><br/>
                                            Containing
                                            <xsl:choose>
                                                <xsl:when test="//@linearUnits = 'Metric'">
                                                    <xsl:value-of select="inr:acreFormat(number(@area) div 10000, $xslAcrePrecision)"/>
                                                    hectares,
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="inr:acreFormat(number(@area) div 43560, $xslAcrePrecision)"/>
                                                    acres,
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            more or less.
                                        </xsl:when>
                                        <xsl:otherwise>
                                            to the <strong>POINT OF TERMINATION.</strong>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </p>
                                <br/>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Line -->
    <xsl:template match="HorizontalLine">
        <xsl:variable name="angDiffBack">
            <xsl:choose>
                <!-- If the angle is less than zero -->
                <xsl:when test="preceding-sibling::*[1]/@tangentialDirectionEnd - @direction &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (preceding-sibling::*[1]/tangentialDirectionEnd - @direction) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (preceding-sibling::*[1]/tangentialDirectionEnd - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (preceding-sibling::*[1]/@tangentialDirectionEnd - @direction)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="preceding-sibling::*[1]/tangentialDirectionEnd - @direction &gt; $pi">
                            <xsl:value-of select="2 * $pi - (preceding-sibling::*[1]/tangentialDirectionEnd - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="preceding-sibling::*[1]/@tangentialDirectionEnd - @direction"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="angDiffAhead">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @direction &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @direction) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @direction &gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@tangentialDirectionStart - @direction)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@tangentialDirectionStart - @direction"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:text> &#xa0; &#xa0;</xsl:text>
        <xsl:value-of select="position()"/>) &#xa0;
        <xsl:choose>
            <!-- Back curve is not tangent within tangency tolerance and is not nearly straight -->
            <xsl:when test="$angDiffBack &gt; $tangentTol and not($angDiffBack &gt; $pi - $tangentTol and $angDiffBack &lt; $pi + $tangentTol)">
                thence non-tangent to said curve
            </xsl:when>
            <!-- Back curve is tangent within tangency tolerance -->
            <xsl:when test="$angDiffBack &gt; $pi - $tangentTol and $angDiffBack &lt; $pi + $tangentTol">
                thence tangent to said curve
            </xsl:when>
            <!-- Next element is another line -->
            <xsl:otherwise>
                thence
            </xsl:otherwise>
        </xsl:choose>
        <xsl:value-of select="inr:sndDirectionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
        <xsl:text>&#xa0;</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:choose>
            <xsl:when test="position() = last()">
                <xsl:value-of select="$unit"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <!-- Find the direction perpendicular to the chord direction -->
                        <xsl:variable name="concaveDirection">
                            <xsl:choose>
                                <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (1.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (1.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (1.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (0.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (0.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (0.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:value-of select="$unit"/>
                        <xsl:choose>
                            <!-- Direction of current line is not equal to start direction of following curve -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                <xsl:choose>
                                    <!-- Angle difference between current line and following curve is tangent or nearly tangent, but goes back on itself -->
                                    <xsl:when test="($angDiffAhead &gt; $pi - $tangentTol) and ($angDiffAhead &lt; $pi + $tangentTol)">
                                        to the point of cusp of a tangent
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverbSemiColon">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <!-- Angle difference between current line and following curve is less than 45 degrees -->
                                    <xsl:when test="$angDiffAhead &gt; 0.75 * $pi">
                                        to the point of cusp of a non-tangent
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverb">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        to which a radial line bears
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <!-- Simple non-tangent following curve -->
                                    <xsl:otherwise>
                                        to the beginning of a non-tangent
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverb">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        to which a radial line bears
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Otherwise, the following curve is tangent -->
                            <xsl:otherwise>
                                to the beginning of a tangent
                                <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                <xsl:value-of select="$unitSingular"/>
                                radius curve concave
                                <xsl:call-template name="directionAdverbSemiColon">
                                    <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                </xsl:call-template>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        spirals not supported<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$unit"/>;<br/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Circle -->
    <xsl:template match="HorizontalCircle">
        <xsl:variable name="angDiffAhead">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd &gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@tangentialDirectionStart - @tangentialDirectionEnd"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="angDiffAheadLin">
            <xsl:choose>
                <!-- If angle is less than zero -->
                <xsl:when test="following-sibling::*[1]/@direction - @tangentialDirectionEnd &lt; 0">
                    <xsl:choose>
                        <!-- If absolute value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="-1 * (following-sibling::*[1]/@direction - @tangentialDirectionEnd) &gt; $pi">
                            <xsl:value-of select="2 * $pi + (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the absolute value -->
                        <xsl:otherwise>
                            <xsl:value-of select="-1 * (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!-- If angle is greater than zero -->
                <xsl:otherwise>
                    <xsl:choose>
                        <!-- If value of angle is greater than 180º, subtract it from 360º -->
                        <xsl:when test="following-sibling::*[1]/@direction - @tangentialDirectionEnd&gt; $pi">
                            <xsl:value-of select="2 * $pi - (following-sibling::*[1]/@direction - @tangentialDirectionEnd)"/>
                        </xsl:when>
                        <!-- Otherwise, just use the value -->
                        <xsl:otherwise>
                            <xsl:value-of select="following-sibling::*[1]/@direction - @tangentialDirectionEnd"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:text> &#xa0; &#xa0;</xsl:text>
        <xsl:value-of select="position()"/>) &#xa0;
        <xsl:choose>
            <xsl:when test="position() = last()">
                thence
                <xsl:call-template name="directionAdverb">
                    <xsl:with-param name="inputDir" select="@chordDirection"/>
                </xsl:call-template>
                along the arc of said curve through a central angle of 
                <xsl:value-of select="inr:sndAngularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                a distance of 
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:value-of select="$unit"/>
            </xsl:when>
            <xsl:otherwise>
                thence
                <xsl:call-template name="directionAdverb">
                    <xsl:with-param name="inputDir" select="@chordDirection"/>
                </xsl:call-template>
                along the arc of said curve through a central angle of 
                <xsl:value-of select="inr:sndAngularFormat(number(@delta), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                a distance of 
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                <xsl:choose>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalCircle']">
                        <!-- Find the direction perpendicular to the chord direction -->
                        <xsl:variable name="concaveDirection">
                            <xsl:choose>
                                <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (1.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (1.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (1.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:choose>
                                        <xsl:when test="following-sibling::*[1]/@chordDirection + (0.5 * $pi) &gt; 2 * $pi">
                                            <xsl:value-of select="(following-sibling::*[1]/@chordDirection + (0.5 * $pi)) - 2 * $pi"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="following-sibling::*[1]/@chordDirection + (0.5 * $pi)"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:choose>
                            <!-- End direction of current curve is not equal to start direction of following curve -->
                            <xsl:when test="$angDiffAhead &gt; $tangentTol">
                                <xsl:value-of select="$unit"/>
                                <xsl:choose>
                                    <!-- Angle difference between current curve and following curve is tangent or nearly tangent, but goes back on itself -->
                                    <xsl:when test="($angDiffAhead &gt; $pi - $tangentTol) and ($angDiffAhead &lt; $pi + $tangentTol)">
                                        to the point of cusp of a tangent
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverbSemiColon">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <!-- Angle difference between current curve and following curve is less than 45 degrees -->
                                    <xsl:when test="$angDiffAhead &gt; 0.75 * $pi">
                                        to the point of cusp of a non-tangent
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverb">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        to which a radial line bears
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <!-- Simple non-tangent following curve -->
                                    <xsl:otherwise>
                                        to the beginning of a non-tangent
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverb">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                        to which a radial line bears
                                        <xsl:choose>
                                            <xsl:when test="following-sibling::*[1]/@rotationDirection = 'ccw'">
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:sndDirectionFormat(number(following-sibling::*[1]/@radialDirectionStart + $pi), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>;<br/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Otherwise, following curve is tangent -->
                            <xsl:otherwise>
                                <xsl:choose>
                                    <!-- If directions are not equal, it is a reverse curve -->
                                    <xsl:when test="@rotationDirection != following-sibling::*[1]/@rotationDirection">
                                        <xsl:value-of select="$unit"/>
                                        to the beginning of a reverse
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverbSemiColon">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <!-- Otherwise, it is a compound -->
                                    <xsl:otherwise>
                                        <xsl:value-of select="$unit"/>
                                        to the beginning of a compound
                                        <xsl:value-of select="inr:distanceFormat(number(following-sibling::*[1]/@radius), $xslDistancePrecision)"/>
                                        <xsl:value-of select="$unitSingular"/>
                                        radius curve concave
                                        <xsl:call-template name="directionAdverbSemiColon">
                                            <xsl:with-param name="inputDir" select="$concaveDirection"/>
                                        </xsl:call-template>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:when test="following-sibling::*[1][name() = 'HorizontalSpiral']">
                        spirals not supported<br/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:choose>
                            <!-- Angle difference between current curve and following line is less than 45 degrees -->
                            <xsl:when test="$angDiffAheadLin &gt; 0.75 * $pi">
                                <xsl:value-of select="$unit"/>
                                to a point of cusp;<br/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$unit"/>;<br/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="directionAdverb">
        <xsl:param name="inputDir"/>
        <xsl:choose>
            <xsl:when test="$inputDir &gt;= 0.0625 * $pi and $inputDir &lt; 0.4375 * $pi">
                Northeasterly
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.4375 * $pi and $inputDir &lt; 0.5625 * $pi">
                Easterly
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.5625 * $pi and $inputDir &lt; 0.9375 * $pi">
                Southeasterly
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.9375 * $pi and $inputDir &lt; 1.0625 * $pi">
                Southerly
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.0625 * $pi and $inputDir &lt; 1.4375 * $pi">
                Southwesterly
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.4375 * $pi and $inputDir &lt; 1.5625 * $pi">
                Westerly
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.5625 * $pi and $inputDir &lt; 1.9375 * $pi">
                Northwesterly
            </xsl:when>
            <xsl:otherwise>
                Northerly
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="directionAdverbSemiColon">
        <xsl:param name="inputDir"/>
        <xsl:choose>
            <xsl:when test="$inputDir &gt;= 0.0625 * $pi and $inputDir &lt; 0.4375 * $pi">
                Northeasterly;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.4375 * $pi and $inputDir &lt; 0.5625 * $pi">
                Easterly;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.5625 * $pi and $inputDir &lt; 0.9375 * $pi">
                Southeasterly;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 0.9375 * $pi and $inputDir &lt; 1.0625 * $pi">
                Southerly;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.0625 * $pi and $inputDir &lt; 1.4375 * $pi">
                Southwesterly;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.4375 * $pi and $inputDir &lt; 1.5625 * $pi">
                Westerly;<br/>
            </xsl:when>
            <xsl:when test="$inputDir &gt;= 1.5625 * $pi and $inputDir &lt; 1.9375 * $pi">
                Northwesterly;<br/>
            </xsl:when>
            <xsl:otherwise>
                Northerly;<br/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Legal Description</em> or the <em>Tools &gt; XML Reports 
                &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for a reference alignment or for alignments containing spirals.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of directional information with North, East, South and West
            // spelled out fully.
            // n - value from XML
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // precision - the number of digits after the decimal point
            // mode - (1 - Bearing, 2 - Bearings from North Only, 3 - North Azimuth, 4 - South Azimuth)
            function sndDirectionFormat(n, format, precision, mode, method)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // this adds 360 to a negative number until it becomes positive
                    while (n < 0)
                    {
                        n += (2 * Math.PI);
                    }
                    // this subtracts 360 if the number is greater than 360
                    while (n >= (2 * Math.PI))
                    {
                        n -= (2 * Math.PI);
                    }
                    // mode 1 - Bearing, mode 2 - North Bearing
                    if (mode == 1 || mode == 2)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // identifies the quadrant
                        if (decdeg <= 90)
                        {
                            var strAngle = sndAngularFormat(n, format, precision, method);
                            return "North " + strAngle + " East";
                        }
                        // identifies the quadrant
                        if (90 < decdeg && decdeg <= 180)
                        {
                            n = Math.PI - n;
                            var strAngle = sndAngularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "South " + strAngle + " East";
                            }
                            else
                            {
                                return "North " + strAngle + " West";
                            }
                        }
                        // identifies the quadrant 
                        if (180 < decdeg && decdeg < 270)
                        {
                            n -= Math.PI;
                            var strAngle = sndAngularFormat(n, format, precision, method);
                            if(mode == 1)
                            {
                                return "South " + strAngle + " West";
                            }
                            else
                            {
                                return "North " + strAngle + " East";
                            }
                        }
                        // identifies the quadrant
                        if (270 <= decdeg && decdeg < 360)
                        {
                            n = (2.0 * Math.PI) - n;
                            var strAngle = sndAngularFormat(n, format, precision, method);
                            return "North " + strAngle + " West";
                        }
                    }
                    // mode 3 - North Azimuth
                    if (mode == 3)
                    {
                        var strAngle = sndAngularFormat(n, format, precision, method);
                        return strAngle;
                    }
                    // mode 4 - South Azimuth
                    if (mode == 4)
                    {
                        n = n + Math.PI;
                        if (n >= (2.0 * Math.PI))
                        {
                            n = n - (2.0 * Math.PI);
                        }
                        var strAngle = sndAngularFormat(n, format, precision, method);
                        return strAngle;
                     }
                }
                return "NaN";
             }
            // This function sets the format of angular information.
            // n - value from xml
            // format - (1 - "ddd^mm'ss.s", 2 - "ddd.ddd")
            // formatMethod - (1 - Degrees, 2 - Grads, 3 - Radians, 4 - Mils)
            // precision - the number of digits after the decimal point
            function sndAngularFormat(n, format, precision, formatMethod)
            {
                // Checking to see if the number is valid
                if (!isNaN(n))
                {
                    // converts from Radians to Degrees and formats the value
                    if (formatMethod == 1)
                    {
                        var decdeg = (n * 180) / Math.PI;
                        // format 1 - this converts the number to "ddd^mm'ss.s"
                        if (format == 1)
                        {
                            // takes only the whole number (ddd)
                            deg = Math.floor(Math.abs(decdeg));
                            if (deg < 10)
                            {
                                deg = "0" + deg;
                            }
                            // multiplies the decimal portion by 60 to get the minutes
                            var decmin = (Math.abs(decdeg) - deg) * 60;
                            // takes only the whole part of that number (mm')
                            var min = Math.floor(decmin);
                            // multiplies the decimal portion by 60 to get the seconds
                            var decsec = (decmin - min) * 60;
                            // calls the function that gives the number the correct precision
                            var str = formatNumber(decsec, precision);
                            if (str.substring(0,2) == "60")
                            {
                                decsec = 0;
                                str = formatNumber(decsec, precision);
                                min = min + 1;
                                if (min == 60)
                                {
                                    min = 0;
                                    deg = deg + 1;
                                }
                            }
                            if (min < 10)
                            {
                                min = "0" + min;
                            }
                            var sec = str;
                            if (sec < 10)
                            {
                                sec = "0" + sec;
                            }
                            var msg;
                            if (decdeg >= 0 || decdeg <= -1)
                            {
                                if (decdeg < 0)
                                {
                                    msg =  "-" + deg + unescape("%b0") + min + "'" + sec + '"';
                                }
                                else
                                {
                                    msg =  deg + unescape("%b0") + min + "'" + sec + '"';
                                }
                            }
                            else
                            {
                                msg =  "-0" + unescape("%b0") + min + "'" + sec + '"';
                            }
                            return msg;
                        }
                        // format 2 - "ddd.ddd"
                        if (format == 2)
                        {
                            // calls the function that gives the number the correct precision
                            var str = formatNumber(decdeg, precision);
                            str = str + unescape("%b0");
                            return str;
                        }
                    }
                    //converts Radians to Grads
                    if (formatMethod == 2)
                    {
                        var radtograd = (n * 200) / Math.PI;
                        var grad = formatNumber(radtograd, precision);
                        if (useAngSuffix == true)
                        {
                            grad = grad + "g";
                        }
                        return grad;
                    }
                    // value in Radians needs to be formated
                    if (formatMethod == 3)
                    {
                        // calls the function that gives the number the correct precision
                        var radian = formatNumber(n, precision);
                        if (useAngSuffix == true)
                        {
                            radian = radian + "r";
                        }
                        return radian;
                    }
                    //converts Radians to Mils
                    if (formatMethod == 4)
                    {
                         var radtomils = n * (6400.0 / (2.0 * Math.PI));
                         var mils = formatNumber(radtomils, precision);
                         return mils;
                    }
                }
                return "NaN";
            }
            function setPI()
            {
                var strPI = Math.PI;
                return strPI;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
