<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Vertical Alignment Review Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Vertical Alignment Review Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Vertical Alignment Review Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <xsl:for-each select="HorizontalAlignment[VerticalAlignment]">
                                    <table class="margin" width="75%">
                                <colgroup span="4">
                                    <col width="23%"/>
                                    <col width="18%"/>
                                    <col width="31%"/>
                                    <col width="28%"/>
                                </colgroup>

                                        <tbody>
                                            <!-- Vertical Alignment Data -->
                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <th align="right" colspan="2" lang="en"><br/>Vertical Alignment:</th>
                                                    <td align="left" colspan="2" valign="bottom"><xsl:value-of select="@name"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Description:</th>
                                                    <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="right" colspan="2" lang="en">Vertical Style:</th>
                                                    <td align="left" colspan="2"><xsl:value-of select="@style"/></td>
                                                </tr>





<table border="1" cellpadding="2" cellspacing="0" width="100%">
                        <thead>
                            <tr>
                                <th colspan="12" lang="en" valign="middle">STATEMENT OF PROPOSED GRADE</th>
                            </tr>
			   <tr style="font-size: 90%">
                                <th lang="en" rowspan="2" valign="bottom">Type</th>
                                <th lang="en" rowspan="2" valign="bottom">Start Chainage<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">Start Elevation<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">Start Grade</th>
                                <th lang="en" rowspan="2" valign="bottom">End Chainage<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">End Elevation<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">End Grade</th>
                                <th lang="en" rowspan="2" valign="bottom">Length<br/></th>
                                <th lang="en" rowspan="2" valign="bottom">Rise/Fall</th>
				
 			
			</tr>
 			<tr> </tr> 
			<xsl:apply-templates/>
                        </thead>
                        
                    </table>

                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>







   <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <tr>
            <td align="left" lang="en">Linear</td>

   <!-- Start Chainage -->
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>

   <!-- Start Elevation -->

            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>


   <!-- Start Grade-->

            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>

   <!-- End Chainage-->
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>

   <!-- End Elevation-->


            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
   <!-- End Grade-->
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@grade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>

   <!-- Length-->
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>

   <!-- Rise/Fall-->


 <xsl:if test="number(@grade) &lt; 0">
           <td align="left" lang="en">Fall</td>
 </xsl:if>

 <xsl:if test="number(@grade) &gt; 0">
           <td align="left" lang="en">Rise</td>
 </xsl:if>
 <xsl:if test="number(@grade) = 0">
           <td align="left" lang="en">Level</td>
 </xsl:if>


 </tr>

    </xsl:template>
 



   <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        



  <tr>
            <td align="left" lang="en">Symmetrical Parabola</td>


   <!-- Start Chainage -->
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>

   <!-- Start Elevation -->
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>


   <!-- Start Grade-->
           <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
           </td>

   <!-- End Chainage-->

            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>
   <!-- End Elevation-->

            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
   <!-- End Grade-->

            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>

   <!-- Length-->
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@verticalCurveLength), $xslDistancePrecision)"/>
            </td>

   <!-- Rise/Fall-->

 <xsl:if test="number(@endGrade) &lt; 0">
           <td align="left" lang="en">Fall</td>
 </xsl:if>

 <xsl:if test="number(@endGrade) &gt; 0">
           <td align="left" lang="en">Rise</td>
 </xsl:if>
 <xsl:if test="number(@endGrade) = 0">
           <td align="left" lang="en">Level</td>
 </xsl:if>
        </tr>

    </xsl:template>





    <!-- Vertical Alignment Circle Data -->
    <xsl:template match="VerticalCircle">
        <tr>
            <td align="left" lang="en">Circular</td>


   <!-- Start Chainage -->
            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalStart/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalStart/station/@externalStationName))"/>
            </td>

   <!-- Start Elevation -->
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
            </td>


   <!-- Start Grade-->
            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@startGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>


   <!-- End Chainage-->

            <td align="right">
                <xsl:value-of select="inr:stationFormat(number(VerticalEnd/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(VerticalEnd/station/@externalStationName))"/>
            </td>

   <!-- End Elevation-->


            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            </td>
   <!-- End Grade-->

            <td align="right">
                <xsl:value-of select="inr:gradeFormat(number(@endGrade), $xslGradeFormat, $xslGradePrecision)"/>
            </td>

   <!-- Length-->
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>

   <!-- Rise/Fall-->
 <xsl:if test="number(@endGrade) &lt; 0">
           <td align="left" lang="en">Fall</td>
 </xsl:if>

 <xsl:if test="number(@endGrade) &gt; 0">
           <td align="left" lang="en">Rise</td>
 </xsl:if>

 <xsl:if test="number(@endGrade) = 0">
           <td align="left" lang="en">Level</td>
 </xsl:if>
        </tr>




    </xsl:template>


    
<xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment with at least one curve in the <em>
                Include</em> field on the <em>Tools &gt; XML Reports &gt; Geometry</em> command to get 
                results from this report.
            </p>
            <p class="normal1" lang="en">
                This report is not suitable for XML data produced by versions earlier than V8.8.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>

  
</xsl:stylesheet>
