<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- List Coordinates - SDR33 Format US Survey Foot -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>00NMSDR33  V04-04.xx                    132211&#xd;</xsl:text>
                    <xsl:text>06NM1.00000000000000&#xd;</xsl:text>
                    <xsl:text>13NM</xsl:text>
                    <xsl:value-of select="inr:date()"/>
                    <xsl:text> Point Listing for SDR33&#xd;</xsl:text>
                    <xsl:text>13NMProject Name: </xsl:text>
                    <xsl:value-of select="@name"/>
                    <xsl:text>&#xd;</xsl:text>
                    <xsl:text>13TS</xsl:text>
                    <xsl:value-of select="inr:SDRdate()"/>
                    <xsl:text>&#xd;</xsl:text>
                    <xsl:for-each select="//HorizontalElements | //CogoPoints">
                        <xsl:apply-templates/>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Element Point Data -->
    <xsl:template match="Start | HorizontalLine/PI | HorizontalSpiral/PI | Center | End[@pointType = 'POE'] | CogoPoints/GeometryPoint">
        <xsl:text>08KI</xsl:text>
        <xsl:choose>
            <xsl:when test="string-length(@name) &gt; 16">
                <xsl:value-of select="substring(@name, 1, 16)"/>
            </xsl:when>
            <xsl:when test="string-length(@name) &lt; 16">
                <xsl:value-of select="inr:columnFormat( string(@name), 16 )"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="@name"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:if test="//@linearUnits = 'Imperial'">
            <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 8, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 8, 16)"/>
        </xsl:if>
        <xsl:if test="//@linearUnits = 'Metric'">
            <xsl:value-of select="inr:columnDoubleFormat(number(@easting), 8, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(@northing), 8, 16)"/>
        </xsl:if>
        <xsl:value-of select="inr:columnDoubleFormat(number(@elevation), 8, 16)"/>
        <xsl:choose>
            <xsl:when test="string-length(@description) &gt; 16">
                <xsl:value-of select="substring(@description, 1, 16)"/>
            </xsl:when>
            <xsl:when test="string-length(@description) &lt; 16">
                <xsl:value-of select="inr:columnFormat( string(@description), 16 )"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="@description"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one cogo point in the Cogo&#xd;</xsl:text>
        <xsl:text>    Points &gt; Include field or one horizontal alignment with&#xd;</xsl:text>
        <xsl:text>    named points in the Horizontal Alignments &gt; Include&#xd;</xsl:text>
        <xsl:text>    field on the Tools &gt; XML Reports &gt; Geometry command to&#xd;</xsl:text>
        <xsl:text>    get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function gets the current date and formats it for SDR Timestamp.
            function SDRdate()
            {
                var today = new Date();
                var monthName = new Array ("JAN", "FEB", "MAR", "APR", "MAY", "JUN", "JUL", "AUG", "SEP", "OCT", "NOV", "DEC");
                var dayOfMonth = today.getDate();
                var year = today.getFullYear();
                var minutes = today.getMinutes();
                if (dayOfMonth < 10)
                {
                    dayOfMonth = "0" + dayOfMonth;
                }
                return dayOfMonth + "-" + monthName[today.getMonth()] + "-" + year;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>