<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- TDS RD5 Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="//HorizontalAlignment">
                    <xsl:text/>
                    <xsl:text>HR++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:apply-templates mode="horizontal"/>
                    <xsl:for-each select="VerticalAlignment">
                        <xsl:text/>
                        <xsl:text>VR++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                        <xsl:apply-templates mode="vertical"/>
                    </xsl:for-each>
                    <xsl:text>XR++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:text>XL++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:text>SR++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:text>SL++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:text>WR++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:text>WL++++++++++++++++++++++++++++++++++++++++++++++++++&#xd;</xsl:text>
                    <xsl:text>&#xd;</xsl:text>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Alignment Linear Data -->
    <xsl:template match="HorizontalLine" mode="horizontal">
        <xsl:text>HL,</xsl:text>
        <xsl:value-of select="inr:tdsDirectionFormat(number(@direction), $xslDirectionPrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Horizontal Alignment Circular Data -->
    <xsl:template match="HorizontalCircle" mode="horizontal">
        <xsl:text>HC,</xsl:text>
        <xsl:value-of select="inr:tdsDirectionFormat(number(@tangentialDirectionStart), $xslDirectionPrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:text>,L&#xd;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>,R&#xd;</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Horizontal Alignment Spiral Data -->
    <xsl:template match="HorizontalSpiral" mode="horizontal">
        <xsl:text>HS,</xsl:text>
        <xsl:value-of select="inr:tdsDirectionFormat(number(@tangentialDirectionStart), $xslDirectionPrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:choose>
            <xsl:when test="preceding-sibling::*[2][name() = 'HorizontalLine']">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[1][name() = 'HorizontalLine']">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[1][name() = 'HorizontalCircle']">
                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
            </xsl:when>
            <xsl:otherwise/>
        </xsl:choose>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:choose>
            <xsl:when test="@rotationDirection = 'ccw'">
                <xsl:text>,L</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>,R</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:choose>
            <xsl:when test="preceding-sibling::*[2][name() = 'HorizontalLine']">
                <xsl:text>,T&#xd;</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[1][name() = 'HorizontalLine']">
                <xsl:text>,T&#xd;</xsl:text>
            </xsl:when>
            <xsl:when test="preceding-sibling::*[1][name() = 'HorizontalCircle']">
                <xsl:text>,C&#xd;</xsl:text>
            </xsl:when>
            <xsl:otherwise/>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine" mode="vertical">
        <xsl:text>VG,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:tdsGradeFormat(number(@grade), $xslGradePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <!-- Vertical Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola" mode="vertical">
        <xsl:text>VC,</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@verticalCurveLength), $xslDistancePrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:tdsGradeFormat(number(@startGrade), $xslGradePrecision)"/>
        <xsl:text>,</xsl:text>
        <xsl:value-of select="inr:tdsGradeFormat(number(@endGrade), $xslGradePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment with&#xd;</xsl:text>
        <xsl:text>    named points in the Include field on the Tools &gt; XML&#xd;</xsl:text>
        <xsl:text>    Reports &gt; Geometry command to get results from this&#xd;</xsl:text>
        <xsl:text>    report.  If you wish to report vertical alignment data,&#xd;</xsl:text>
        <xsl:text>    you must also toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    The following are not supported:  Right and Left Cross&#xd;</xsl:text>
        <xsl:text>    Section Templates, Right and Left Superelevation, and&#xd;</xsl:text>
        <xsl:text>    Right and Left Widening.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This function sets the format of directional information.
            // n - value from XML
            // precision - the number of digits after the decimal point
            function tdsDirectionFormat(n, precision)
            {
                // Make sure we have a valid number
                if (!isNaN(n))
                {   
                    // North Azimuth
                    var strAngle = tdsAngularFormat(n, precision);
                    return strAngle;
                }
                return "";
             }
            // This function sets the format of angular information.
            // n - value from xml
            // precision - the number of digits after the decimal point
            function tdsAngularFormat(n, precision)
            {
                // Check to see if the number is valid
                if (!isNaN(n))
                {
                    // converts from Radians to Degrees Minutes Seconds and 
                    // outputs the value in the format ddd.mmsssssss
                    var decdeg = (n * 180) / Math.PI;
                    // find the degrees (ddd)
                    var deg = Math.floor(Math.abs(decdeg));
                    // find the minutes (mm)
                    var decmin = (Math.abs(decdeg) - deg) * 60;
                    var min = Math.floor(decmin);
                    // find the seconds (ss)
                    var decsec = (decmin - min) * 60;
                    var sec = Math.floor(decsec);
                    // formats the decimal portion to specified precision
                    var nRoundTo = Math.pow(10, precision);
                    var lastdec = Math.round(nRoundTo * (decsec - sec));
                    // pad with leading zeros
                    if (min < 10)
                    {
                        min = "0" + min;
                    }
                    if (sec < 10)
                    {
                        sec = "0" + sec;
                    }
                    var str = deg + "." + min + sec + lastdec;
                    return str;
                }
                return 985;
             }
            // This function formats the grade or slope and adjusts the
            // precision according to input
            // n - grade value
            // precision - the number of digits after the decimal
            function tdsGradeFormat(n, precision)
            {
                var str = "";
                // Make sure we have a valid number
                if (!isNaN(n))
                {
                    var value = (n * 100);
                    // this calls the function that gives the number the correct precision
                    str = formatNumber(value, precision);
                    return str;
                }
                return "";
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
