<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Vertical Alignment to ASCII Import Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:text/>
                    <xsl:text>* BENTLEY VERTICAL ALIGNMENT TO ASCII&#xd;</xsl:text>
                    <xsl:text>* &#xd;</xsl:text>
                    <xsl:for-each select="HorizontalAlignment/VerticalAlignment">
                        <xsl:text>* Alignment name: </xsl:text><xsl:value-of select="@name"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment description: </xsl:text><xsl:value-of select="@description"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Alignment style: </xsl:text><xsl:value-of select="@style"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* Input Factor: </xsl:text><xsl:value-of select="//@inputGridScaleFactor"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>* &#xd;</xsl:text>
                        <xsl:choose>
                            <xsl:when test="//VerticalCircle">
                                <xsl:text>{ TYPE STATION ELEVATION SLOPE VC_LENGTH RADIUS&#xd;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>{ TYPE STATION ELEVATION SLOPE VC_LENGTH&#xd;</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:for-each select="VerticalElements">
                            <xsl:apply-templates/>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <xsl:text>LIN</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@grade), $xslGradePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
        <xsl:if test="//VerticalCircle">
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
        </xsl:if>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/@elevation), $xslElevationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslGradePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:if test="//VerticalCircle">
                <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            </xsl:if>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:text>PAR</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@startGrade), $xslGradePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@verticalCurveLength), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/@elevation), $xslElevationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslGradePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <xsl:text>PAR</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@startGrade), $xslGradePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@startVerticalCurveLength), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>PAR</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVCC/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(PVCC/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number((((@startRateOfChange * @startVerticalCurveLength) div 100) + (@startGrade * 100)) div 100), $xslGradePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@endVerticalCurveLength), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/@elevation), $xslElevationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslGradePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Circular Data -->
    <xsl:template match="VerticalCircle">
        <xsl:text>CIR</xsl:text>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/station/@internalStation), $xslStationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(VerticalStart/@elevation), $xslElevationPrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@startGrade), $xslGradePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@length), $xslDistancePrecision, 16)"/>
        <xsl:value-of select="inr:columnDoubleFormat(number(@radius), $xslDistancePrecision, 16)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>LIN</xsl:text>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/station/@internalStation), $xslStationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(number(VerticalEnd/@elevation), $xslElevationPrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslGradePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:value-of select="inr:columnDoubleFormat(0.0, $xslDistancePrecision, 16)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select either All or Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
