<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <!-- Vertical Elements Geodimeter Format -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="//VerticalAlignment">
                    <xsl:text/>
                    <xsl:text>15=</xsl:text><xsl:value-of select="substring(@name, 1, 6)"/>
                    <xsl:text>#2&#xd;</xsl:text>
                    <xsl:apply-templates/>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <!-- Vertical Alignment Linear Data -->
    <xsl:template match="VerticalLine">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>39=</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>39=</xsl:text>
            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Symmetrical Parabola Data -->
    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>39=</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>44=</xsl:text>
        <xsl:value-of select="@startGrade"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>84=</xsl:text>
        <xsl:value-of select="format-number(0.005 div @kValue, '0.##########')"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>39=</xsl:text>
            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Unsymmetrical Parabola Data -->
    <xsl:template match="VerticalUnsymmetricalParabola">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>39=</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>44=</xsl:text>
        <xsl:value-of select="@startGrade"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>84=</xsl:text>
        <xsl:value-of select="format-number(0.005 div @startKValue, '0.##########')"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(PVCC/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>39=</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(PVCC/@elevation), $xslElevationPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>44=</xsl:text>
        <xsl:value-of select="number((((@startRateOfChange * @startVerticalCurveLength) div 100) + (@startGrade * 100)) div 100)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>84=</xsl:text>
        <xsl:value-of select="format-number(0.005 div @endKValue, '0.##########')"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>39=</xsl:text>
            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <!-- Vertical Alignment Circular Data -->
    <xsl:template match="VerticalCircle">
        <xsl:text>80=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(VerticalStart/station/@internalStation), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>39=</xsl:text>
        <xsl:value-of select="inr:elevationFormat(number(VerticalStart/@elevation), $xslElevationPrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>44=</xsl:text>
        <xsl:value-of select="@startGrade"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>64=</xsl:text>
        <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:if test="position() = last()">
            <xsl:text>80=</xsl:text>
            <xsl:value-of select="inr:distanceFormat(number(VerticalEnd/station/@internalStation), $xslDistancePrecision)"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>39=</xsl:text>
            <xsl:value-of select="inr:elevationFormat(number(VerticalEnd/@elevation), $xslElevationPrecision)"/>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must include at least one horizontal alignment in&#xd;</xsl:text>
        <xsl:text>    the Include field on the Tools &gt; XML Reports &gt;&#xd;</xsl:text>
        <xsl:text>    Geometry command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    You must toggle on the Include Vertical Alignments&#xd;</xsl:text>
        <xsl:text>    option and select either All or Active.&#xd;&#xd;</xsl:text>
        <xsl:text>    Most style sheets in the DataCollection directory do&#xd;</xsl:text>
        <xsl:text>    not honor Tools &gt; Format Options with the exception of&#xd;</xsl:text>
        <xsl:text>    precision, where practical.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
