<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Unique cross section surfaces -->
    <xsl:variable name="uniqueSurfaceName" select="//CrossSectionSurfaces/CrossSectionSurface[not (@name = preceding::CrossSectionSurface/@name)]/@name"/>
    <!-- Cross Section Profile List -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Cross Section Profile List</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Cross Section Profile List</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Cross Section Set Data -->
                            <xsl:for-each select="CrossSectionSet">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Set Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@setName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Alignment Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@alignmentName"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Cross Section Point Data -->
                                <table class="margin" width="90%">
                                    <xsl:for-each select="$uniqueSurfaceName[../@type = 1]">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th class="underline" lang="en" rowspan="2" valign="bottom">Station</th>
                                                <th colspan="2" lang="en" valign="bottom">- - - Centerline - - -</th>
                                                <th colspan="2" lang="en" valign="bottom">- - - Left Edge - - -</th>
                                                <th colspan="2" lang="en" valign="bottom">- - - Right Edge - - -</th>
                                            </tr>
                                            <tr>
                                                <th class="underline" lang="en" valign="bottom">Existing<br/>Elevation</th>
                                                <th class="underline" lang="en" valign="bottom">Design<br/>Elevation</th>
                                                <th class="underline" lang="en" valign="bottom">Elevation</th>
                                                <th class="underline" lang="en" valign="bottom">Profile<br/>Slope</th>
                                                <th class="underline" lang="en" valign="bottom">Elevation</th>
                                                <th class="underline" lang="en" valign="bottom">Profile<br/>Slope</th>
                                            </tr>
                                            <tr>
                                                <th align="left" lang="en">Surface:&#xa0; </th>
                                                <td align="left" colspan="6"><xsl:value-of select="."/></td>
                                            </tr>
                                        </thead>
                                        <xsl:for-each select="//CrossSectionSurface[@name = current()]">
                                            <tbody>
                                                <xsl:for-each select="CrossSectionPoints">
                                                    <tr>
                                                        <td align="right" style="white-space:nowrap">
                                                            <xsl:value-of select="inr:stationFormat(number(../../../Station/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../../Station/@externalStationName))"/>
                                                        </td>
                                                        <xsl:call-template name="showPointData">
                                                            <xsl:with-param name="listNegative" select="CrossSectionPoint[@offset &lt; 0]"/>
                                                            <xsl:with-param name="listPositive" select="CrossSectionPoint[@offset &gt; 0]"/>
                                                            <xsl:with-param name="listZero" select="CrossSectionPoint[@offset = 0]"/>
                                                        </xsl:call-template>
                                                    </tr>
                                                </xsl:for-each>
                                            </tbody>
                                        </xsl:for-each>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="showPointData">
        <xsl:param name="listNegative"/>
        <xsl:param name="listPositive"/>
        <xsl:param name="listZero"/>
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number($listZero[position() = 1]/@elevation - $listZero[position() = 1]/@cutFillHeight), $xslElevationPrecision)"/>
        </td>
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number($listZero[position() = 1]/@elevation), $xslElevationPrecision)"/>
        </td>
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number($listNegative[position() = 1]/@elevation), $xslElevationPrecision)"/>
        </td>
        <td align="right">
            <xsl:value-of select="inr:gradeFormat(number($listNegative[position() = 1]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope), $xslGradeFormat, $xslGradePrecision)"/>
        </td>
        <td align="right">
            <xsl:value-of select="inr:elevationFormat(number($listPositive[position() = last()]/@elevation), $xslElevationPrecision)"/>
        </td>
        <td align="right">
            <xsl:value-of select="inr:gradeFormat(number($listPositive[position() = last()]/CrossSectionFeatures/CrossSectionFeature/@aheadLongitudinalSlope), $xslGradeFormat, $xslGradePrecision)"/>
        </td>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have created cross sections along your alignment and the cross section set must 
                have the surfaces and features upon which you wish to report displayed.&#xa0; This report 
                requires the exterior boundary feature or other feature(s) representing the edge of the 
                surface to be displayed on the cross section set.
            </p>
            <p class="normal1" lang="en">
                You can create the XML data file from the <em>Evaluation &gt; Cross Section &gt; Cross 
                Section Report</em> command or from the <em>End-Area Volumes</em> leaf of the <em>
                Evaluation &gt; Cross Section &gt; Cross Sections</em> command by toggling on the <em>
                Create XML Report</em> option on the <em>General</em> leaf.
            </p>
            <p class="normal1" lang="en">
                This report works only with surfaces whose <em>Type</em> on the <em>Main</em> tab of the 
                <em>Surface &gt; Surface Properties</em> command is set to <em>Design</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
