<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>&lt;?xml version=&quot;1.0&quot; encoding=&quot;iso-8859-1&quot; ?&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>
                <xsl:text>&lt;LandXML xmlns=&quot;http://www.landxml.org/schema/LandXML-1.1&quot; </xsl:text>
                <xsl:text>xmlns:xsi=&quot;http://www.w3.org/2001/XMLSchema-instance&quot; </xsl:text>
                <xsl:text>xsi:schemaLocation=&quot;http://www.landxml.org/schema/LandXML-1.1 http://www.landxml.org/schema/landxml-1.1/LandXML-1.1.xsd&quot; </xsl:text>
                <xsl:text>version=&quot;1.1&quot; </xsl:text>
                <xsl:text>date=</xsl:text>
                <xsl:text>&quot;</xsl:text>
                <xsl:value-of select="inr:landXMLDate()"/>
                <xsl:text>&quot;</xsl:text>
                <xsl:text> </xsl:text>
                <xsl:text>time=</xsl:text>
                <xsl:text>&quot;</xsl:text>
                <xsl:value-of select="inr:landXMLTime()"/>
                <xsl:text>&quot;&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:text>&lt;Units&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:if test="//InRoads/@linearUnits = 'Metric'">
                    <xsl:text>&lt;Metric areaUnit=&quot;squareMeter&quot; linearUnit=&quot;meter&quot; volumeUnit=&quot;cubicMeter&quot; temperatureUnit=&quot;celsius&quot; pressureUnit=&quot;HPA&quot; angularUnit=&quot;radians&quot; directionUnit=&quot;radians&quot;/&gt;</xsl:text>
                </xsl:if>
                <xsl:if test="//InRoads/@linearUnits = 'Imperial'">
                    <xsl:choose>
                        <xsl:when test="//InRoads/@isInternationalFoot = 'true'">
                            <xsl:text>&lt;Imperial areaUnit=&quot;acre&quot; linearUnit=&quot;foot&quot; volumeUnit=&quot;cubicFeet&quot; temperatureUnit=&quot;fahrenheit&quot; pressureUnit=&quot;inHG&quot; angularUnit=&quot;radians&quot; directionUnit=&quot;radians&quot;/&gt;</xsl:text>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:text>&lt;Imperial areaUnit=&quot;acre&quot; linearUnit=&quot;USSurveyFoot&quot; volumeUnit=&quot;cubicFeet&quot; temperatureUnit=&quot;fahrenheit&quot; pressureUnit=&quot;inHG&quot; angularUnit=&quot;radians&quot; directionUnit=&quot;radians&quot;/&gt;</xsl:text>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:if>

                <xsl:text>&#xd;</xsl:text>
                <xsl:text>&lt;/Units&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:text>&lt;Alignments&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:for-each select="InRoads/GeometryProject">
                    <xsl:for-each select="HorizontalAlignment">
                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates mode ="horizontal"/>
                        </xsl:for-each>

                        <xsl:text>&lt;/CoordGeom&gt;</xsl:text>
                        <xsl:text>&#xd;</xsl:text>

                        <xsl:for-each select="HorizontalElements">
                            <xsl:apply-templates mode ="equations"/>
                        </xsl:for-each>

                        <xsl:text>&lt;Profile&gt;</xsl:text>
                        <xsl:text>&#xd;</xsl:text>

                        <xsl:for-each select="VerticalAlignment">
                            <xsl:text>&lt;ProfAlign</xsl:text>
                            <xsl:text> </xsl:text>
                            <xsl:text>name=</xsl:text>
                            <xsl:text>&quot;</xsl:text>
                            <xsl:value-of select="@name"/>
                            <xsl:text>&quot;</xsl:text>
                            <xsl:text>&gt;</xsl:text>
                            <xsl:text>&#xd;</xsl:text>

                            <xsl:for-each select="VerticalElements">
                                <xsl:apply-templates/>
                            </xsl:for-each>

                            <xsl:text>&lt;/ProfAlign&gt;</xsl:text>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>

                        <xsl:text>&lt;/Profile&gt;</xsl:text>
                        <xsl:text>&#xd;</xsl:text>

                        <xsl:for-each select="Superelevation/CantAlignment">
                            <xsl:text>&lt;Cant</xsl:text>
                            <xsl:text> </xsl:text>
                            <xsl:text>name=</xsl:text>
                            <xsl:text>&quot;</xsl:text>
                            <xsl:value-of select="@name"/>
                            <xsl:text>&quot;</xsl:text>
                            <xsl:text> </xsl:text>
                            <xsl:text>gauge=</xsl:text>

                            <xsl:if test="//InRoads/@linearUnits = 'Metric'">
                                <xsl:text>&quot;1.5000000</xsl:text>
                            </xsl:if>
                            <xsl:if test="//InRoads/@linearUnits != 'Metric'">
                                <xsl:text>&quot;4.708333333</xsl:text>
                            </xsl:if>

                            <xsl:text>&quot;</xsl:text>
                            <xsl:text> </xsl:text>
                            <xsl:text>rotationPoint=</xsl:text>
                            <xsl:text>&quot;insideRail</xsl:text>
                            <xsl:text>&quot;&gt;</xsl:text>
                            <xsl:text>&#xd;</xsl:text>

                            <xsl:apply-templates/>

                            <xsl:text>&lt;/Cant&gt;</xsl:text>
                            <xsl:text>&#xd;</xsl:text>
                        </xsl:for-each>

                        <xsl:text>&lt;/Alignment&gt;</xsl:text>
                        <xsl:text>&#xd;</xsl:text>
                    </xsl:for-each>
                </xsl:for-each>

                <xsl:text>&lt;/Alignments&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:text>&lt;CgPoints&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:for-each select="//CogoPoints/GeometryPoint">
                    <xsl:text>&lt;CgPoint</xsl:text>
                    <xsl:text> </xsl:text>
                    <xsl:text>name=</xsl:text>
                    <xsl:text>&quot;</xsl:text>
                    <xsl:value-of select="@name"/>
                    <xsl:text>&quot;</xsl:text>
                    <xsl:text> </xsl:text>
                    <xsl:text>code=</xsl:text>
                    <xsl:text>&quot;</xsl:text>
                    <xsl:value-of select="@style"/>
                    <xsl:text>&quot;&gt;</xsl:text>
                    <xsl:text>&#xd;</xsl:text>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="@northing"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="@easting"/>
                    <xsl:text> </xsl:text>
                    <xsl:value-of select="@elevation"/>
                    <xsl:text>&#xd;</xsl:text>
                    <xsl:text>&lt;/CgPoint&gt;</xsl:text>
                    <xsl:text>&#xd;</xsl:text>
                </xsl:for-each>

                <xsl:text>&lt;/CgPoints&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>

                <xsl:text>&lt;/LandXML&gt;</xsl:text>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="HorizontalLine" mode="horizontal">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;Alignment</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>name=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>length=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@perimeter"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>state=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text>proposed</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>staStart=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="Start/station/@externalStation"/>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;CoordGeom</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>name=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>state=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text>proposed</xsl:text>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:text>&lt;Line</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>length=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@length"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>dir=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@direction"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>staStart=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/station/@externalStation"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text>&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;Start </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/Start&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;End </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="End/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/End&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;/Line&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template match="HorizontalCircle" mode="horizontal">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;Alignment</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>name=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>length=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@perimeter"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>state=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text>proposed</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>staStart=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="Start/station/@externalStation"/>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;CoordGeom</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>name=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>state=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text>proposed</xsl:text>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:text>&lt;Curve</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>rot=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@rotationDirection"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>crvType=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="../../@curvatureDefinition"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>radius=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@radius"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>length=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@length"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>chord=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@chord"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>dirStart=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@tangentialDirectionStart"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>dirEnd=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@tangentialDirectionEnd"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>staStart=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/station/@externalStation"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text>&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;Start </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/Start&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;Center </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Center/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Center/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Center/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Center/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/Center&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;End </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="End/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/End&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;/Curve&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template match="HorizontalSpiral" mode="horizontal">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;Alignment</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>name=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>length=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@perimeter"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>state=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text>proposed</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>staStart=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="Start/station/@externalStation"/>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;CoordGeom</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>name=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="../../@name"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>state=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:text>proposed</xsl:text>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:text>&lt;Spiral</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>rot=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@rotationDirection"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>spiType=</xsl:text>
        <xsl:choose>
        <xsl:when test="@type = 'Clothoid'">
            <xsl:text>&quot;clothoid&quot;</xsl:text>
        </xsl:when>
            <xsl:when test="@type = 'Biquad. Parabola'">
            <xsl:text>&quot;biquadratic&quot;</xsl:text>
        </xsl:when>
            <xsl:when test="@type = 'Bloss'">
                <xsl:text>&quot;bloss&quot;</xsl:text>
            </xsl:when>
            <xsl:when test="@type = 'Sinusoid'">
                <xsl:text>&quot;sinusoid&quot;</xsl:text>
            </xsl:when>
            <xsl:when test="@type = 'Cosine'">
                <xsl:text>&quot;cosine&quot;</xsl:text>
            </xsl:when>
            <xsl:otherwise>
                <xsl:text>&quot;UNSUPPORTED&quot;</xsl:text>
            </xsl:otherwise>
            </xsl:choose>
        <xsl:text> </xsl:text>
        <xsl:text>radiusStart=</xsl:text>
        <xsl:text>&quot;</xsl:text>

        <xsl:if test="@startRadius = '0.000000000'">
            <xsl:text>INF</xsl:text>
        </xsl:if>
        <xsl:if test="@startRadius != '0.000000000'">
            <xsl:value-of select="@startRadius"/>
        </xsl:if>

        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>radiusEnd=</xsl:text>
        <xsl:text>&quot;</xsl:text>

        <xsl:if test="@endRadius = '0.000000000'">
            <xsl:text>INF</xsl:text>
        </xsl:if>
        <xsl:if test="@endRadius != '0.000000000'">
            <xsl:value-of select="@endRadius"/>
        </xsl:if>

        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>length=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@length"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>tanLong=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@longTangent"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>tanShort=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@shortTangent"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>constant=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@aConstant"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>theta=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@thetaAngle"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>totalY=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@ys"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>totalX=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@xs"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>dirStart=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@tangentialDirectionStart"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>dirEnd=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@tangentialDirectionEnd"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>staStart=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/station/@externalStation"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text>&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;Start </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="Start/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/Start&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;PI </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="PI/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PI/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PI/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PI/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/PI&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;End </xsl:text>
        <xsl:text>code=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="End/@type"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@northing"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@easting"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="End/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/End&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:text>&lt;/Spiral&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template match="HorizontalLine | HorizontalCircle | HorizontalSpiral" mode="equations">
        <xsl:for-each select="StationEquation">
            <xsl:text>&lt;StaEquation</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>staAhead=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="@aheadStation"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>staBack=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="@backStation"/>
            <xsl:text>&quot;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:text>staInternal=</xsl:text>
            <xsl:text>&quot;</xsl:text>
            <xsl:value-of select="GeometryPoint/station/@internalStation"/>
            <xsl:text>&quot;&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/StaEquation&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:for-each>
    </xsl:template>

    <xsl:template match="VerticalLine">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:if test="position() != last()">
            <xsl:if test="following-sibling::*[1][name() = 'VerticalLine']">
                <xsl:text>&lt;PVI&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>
                <xsl:text> </xsl:text>
                <xsl:value-of select="VerticalEnd/station/@externalStation"/>
                <xsl:text> </xsl:text>
                <xsl:value-of select="VerticalEnd/@elevation"/>
                <xsl:text>&#xd;</xsl:text>
                <xsl:text>&lt;/PVI&gt;</xsl:text>
                <xsl:text>&#xd;</xsl:text>
            </xsl:if>
        </xsl:if>

        <xsl:if test="position() = last()">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="VerticalCircle">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/station/@internalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:text>&lt;CircCurve</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>radius=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@radius"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>length=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@length"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PVI/station/@externalStation"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PVI/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/CircCurve&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:if test="position() = last()">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="VerticalSymmetricalParabola">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:text>&lt;ParaCurve</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>length=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@verticalCurveLength"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PVI/station/@externalStation"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PVI/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/ParaCurve&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:if test="position() = last()">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="VerticalUnsymmetricalParabola">
        <xsl:if test="position() = 1">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalStart/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>

        <xsl:text>&lt;UnsymParaCurve</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>lengthIn=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@startVerticalCurveLength"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>lengthOut=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@endVerticalCurveLength"/>
        <xsl:text>&quot;&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PVI/station/@externalStation"/>
        <xsl:text> </xsl:text>
        <xsl:value-of select="PVI/@elevation"/>
        <xsl:text>&#xd;</xsl:text>
        <xsl:text>&lt;/ParaCurve&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>

        <xsl:if test="position() = last()">
            <xsl:text>&lt;PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/station/@externalStation"/>
            <xsl:text> </xsl:text>
            <xsl:value-of select="VerticalEnd/@elevation"/>
            <xsl:text>&#xd;</xsl:text>
            <xsl:text>&lt;/PVI&gt;</xsl:text>
            <xsl:text>&#xd;</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template match="Cant">
        <xsl:text>&lt;CantStation</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>station=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="Start/station/@externalStation"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>appliedCant=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@appliedCant"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:text>speed=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@designSpeed"/>
        <xsl:text>&quot;</xsl:text>
        <xsl:text> </xsl:text>
        <xsl:choose>
            <xsl:when test="@transitionType = 'Linear'">
            </xsl:when>
            <xsl:when test="@transitionType = 'Circular'">
            </xsl:when>
            <xsl:when test="@transitionType = 'Clothoid'">
                <xsl:text>transitionType=&quot;clothoid&quot; </xsl:text>
            </xsl:when>
            <xsl:when test="@transitionType = 'Biquadratic'">
                <xsl:text>transitionType=&quot;biquadratic&quot; </xsl:text>
            </xsl:when>
            <xsl:when test="@transitionType = 'Bloss'">
                <xsl:text>transitionType=&quot;bloss&quot; </xsl:text>
            </xsl:when>
            <xsl:when test="@transitionType = 'Sinusoid'">
                <xsl:text>transitionType=&quot;sinusoid&quot; </xsl:text>
            </xsl:when>
            <xsl:when test="@transitionType = 'Cosine'">
                <xsl:text>transitionType=&quot;cosine&quot; </xsl:text>
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:text>curvature=</xsl:text>
        <xsl:text>&quot;</xsl:text>
        <xsl:value-of select="@curvature"/>
        <xsl:text>&quot;/&gt;</xsl:text>
        <xsl:text>&#xd;</xsl:text>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select at least one Civil horizontal geometry element to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2013 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
