<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Project Alignment Detailed Listing -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Project Alignment Detailed Listing</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!--Report Title-->
                                <h2 lang="en">Project Alignment Detailed Listing</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!--Project Data-->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <table cellpadding="2" cellspacing="2">
                                    <thead>
                                        <tr>
                                            <th class="underline" colspan="2" lang="en">Alignment</th>
                                            <th class="underline" lang="en">Type</th>
                                            <th class="underline" lang="en">Description</th>
                                            <th class="underline" lang="en">Style</th>
                                            <th class="underline" lang="en">Last Revised</th>
                                            <th class="underline" lang="en">By</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <!-- Horizontal Alignment Data -->
                                        <xsl:for-each select="HorizontalAlignment">
                                            <tr>
                                                <td class="sidepad" align="left" colspan="2" valign="bottom">
                                                    <br/><xsl:value-of select="@name"/>
                                                </td>
                                                <td class="sidepad" align="left" lang="en" valign="bottom">horizontal</td>
                                                <td class="sidepad" align="left" valign="bottom"><xsl:value-of select="@description"/></td>
                                                <td class="sidepad" align="left" valign="bottom"><xsl:value-of select="@style"/></td>
                                                <td class="sidepad" align="left" valign="bottom"><xsl:value-of select="@lastRevisedDate"/></td>
                                                <td class="sidepad" align="left" valign="bottom"><xsl:value-of select="@lastRevisedBy"/></td>
                                            </tr>
                                            <!-- Vertical Alignment Data -->
                                            <xsl:for-each select="VerticalAlignment">
                                                <tr>
                                                    <td class="sidepad">&#xa0; </td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@name"/></td>
                                                    <td class="sidepad" align="left" lang="en">vertical</td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@description"/></td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@style"/></td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedDate"/></td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedBy"/></td>
                                                </tr>
                                            </xsl:for-each>
                                            <!-- Superelevation Alignment Data -->
                                            <xsl:for-each select="Superelevation/SuperelevationAlignment">
                                                <tr>
                                                    <td class="sidepad">&#xa0; </td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@name"/></td>
                                                    <td class="sidepad" align="left" lang="en">superelevation</td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@description"/></td>
                                                    <td class="sidepad">&#xa0;</td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedDate"/></td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedBy"/></td>
                                                </tr>
                                            </xsl:for-each>
                                            <!-- Cant Alignment Data -->
                                            <xsl:for-each select="Superelevation/CantAlignment">
                                                <tr>
                                                    <td class="sidepad">&#xa0; </td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@name"/></td>
                                                    <td class="sidepad" align="left" lang="en">cant</td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@description"/></td>
                                                    <td class="sidepad">&#xa0;</td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedDate"/></td>
                                                    <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedBy"/></td>
                                                </tr>
                                            </xsl:for-each>
                                            <tr>
                                                <td colspan="7" style="border-style:dashed;border-color:#666633;border-left-width:0px;border-bottom-width:1px;border-top-width:0px;border-right-width:0px">&#xa0;</td>
                                            </tr>
                                        </xsl:for-each>
                                        <xsl:for-each select="Turnout">
                                            <tr>
                                                <td class="sidepad" align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                                <td class="sidepad" align="left" lang="en">turnout</td>
                                                <td class="sidepad" align="left"><xsl:value-of select="@description"/></td>
                                                <td class="sidepad" align="left"><xsl:value-of select="@style"/></td>
                                                <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedDate"/></td>
                                                <td class="sidepad" align="left"><xsl:value-of select="@lastRevisedBy"/></td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
