<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Variables to hold the minimum and maximum slew values -->
    <xsl:variable name="slewDiagramMax">
        <xsl:for-each select="//HorizontalEventPoint[@eventType = 'regressionPoint']/GeometryPoint">
            <xsl:sort select="@offset" data-type="number"/>
            <xsl:if test="position() = last()">
                <xsl:value-of select="@offset"/>
            </xsl:if>
        </xsl:for-each>
    </xsl:variable>
    <xsl:variable name="slewDiagramMin">
        <xsl:for-each select="//HorizontalEventPoint[@eventType = 'regressionPoint']/GeometryPoint">
            <xsl:sort select="@offset" data-type="number"/>
            <xsl:if test="position() = 1">
                <xsl:value-of select="@offset"/>
            </xsl:if>
        </xsl:for-each>
    </xsl:variable>
    <!-- Find greater of absolute values of minimum and maximum slew values -->
    <xsl:variable name="slewRange">
        <xsl:choose>
            <xsl:when test="$slewDiagramMax &gt;= (-1 * $slewDiagramMin)">
                <xsl:value-of select="$slewDiagramMax"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="-1 * $slewDiagramMin"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    <!-- Slew Diagram Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Slew Diagram</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Slew Diagram</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Horizontal Alignment Data -->
                                <xsl:for-each select="HorizontalAlignment">
                                    <table class="margin" width="90%">
                                        <thead>
                                            <tr>
                                                <th align="right" lang="en" width="30%">Alignment Name:&#xa0; </th>
                                                <td align="left" width="70%"><xsl:value-of select="@name"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en">Alignment Description:&#xa0; </th>
                                                <td align="left"><xsl:value-of select="@description"/></td>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <tr><td colspan="2">&#xa0;</td></tr>
                                            <xsl:apply-templates />
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <tr>
            <td colspan="2">
                <table width="70%">
                    <tr>
                        <td align="right" lang="en">Type:&#xa0; </td>
                        <td align="left" lang="en">Linear</td>
                        <td align="right" lang="en">Length:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Direction:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                        </td>
                        <td align="right" lang="en">End Direction:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:directionFormat(number(@direction), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Northing:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
                        </td>
                        <td align="right" lang="en">End Northing:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Easting:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
                        </td>
                        <td align="right" lang="en">End Easting:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Station:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
                        </td>
                        <td align="right" lang="en">End Station: </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <tr>
            <td colspan="2">
                <table width="70%">
                    <tr>
                        <td align="right" lang="en">Type:&#xa0; </td>
                        <td align="left" lang="en">Circular</td>
                        <td align="right" lang="en">Length:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Direction:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                        </td>
                        <td align="right" lang="en">End Direction:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Northing:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
                        </td>
                        <td align="right" lang="en">End Northing:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Easting:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
                        </td>
                        <td align="right" lang="en">End Easting:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Station:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
                        </td>
                        <td align="right" lang="en">End Station:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Radius:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                        </td>
                        <td align="right" lang="en">End Radius:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!--Horizontal Spiral Data-->
    <xsl:template match="HorizontalSpiral">
        <tr>
            <td colspan="2">
                <table width="70%">
                    <tr>
                        <td align="right" lang="en">Type:&#xa0; </td>
                        <td align="left">Spiral</td>
                        <td align="right" lang="en">Length:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Direction:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionStart), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                        </td>
                        <td align="right" lang="en">End Direction:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:directionFormat(number(@tangentialDirectionEnd), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Northing:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
                        </td>
                        <td align="right" lang="en">End Northing:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:northingFormat(number(End/@northing), $xslNorthingPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Easting:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
                        </td>
                        <td align="right" lang="en">End Easting:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:eastingFormat(number(End/@easting), $xslEastingPrecision)"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Station:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:stationFormat(number(Start/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(Start/station/@externalStationName))"/>
                        </td>
                        <td align="right" lang="en">End Station:&#xa0; </td>
                        <td align="left" style="white-space:nowrap;">
                            <xsl:value-of select="inr:stationFormat(number(End/station/@externalStation), $xslStationFormat, $xslStationPrecision, string(End/station/@externalStationName))"/>
                        </td>
                    </tr>
                    <tr>
                        <td align="right" lang="en">Start Radius:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
                        </td>
                        <td align="right" lang="en">End Radius:&#xa0; </td>
                        <td align="left">
                            <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <xsl:call-template name="Data"/>
    </xsl:template>
    <!-- Heading template for Slew Diagram columns -->
    <xsl:template name="Headings">
        <tr>
            <th class="underline" lang="en">Element <br/>Station</th>
            <th class="underline" lang="en">Alignment<br/>Station</th>
            <th class="underline" lang="en">Point Name</th>
            <th class="underline" lang="en">Offset</th>
            <th class="underline" lang="en">Fixity</th>
            <th class="underline" align="right" lang="en">Left</th>
            <th class="underline" lang="en">&#124;</th>
            <th class="underline" align="left" lang="en">Right</th>
        </tr>
    </xsl:template>
    <!-- Slew Diagram Data -->
    <xsl:template name="Data">
        <xsl:variable name="startStation" select="Start/station/@internalStation"/>
        <xsl:variable name="endStation" select="End/station/@internalStation"/>
        <tr>
            <td colspan="2">
                <table width="100%">
                    <colgroup span="8">
                        <col width="14%"/>
                        <col width="14%"/>
                        <col width="13%"/>
                        <col width="9%"/>
                        <col width="9"/>
                        <col width="19%"/>
                        <col width="1%"/>
                        <col width="19%"/>
                    </colgroup>
                    <xsl:call-template name="Headings"/>
                    <xsl:for-each select="ancestor::*/HorizontalEventPoints/HorizontalRegressionPoints/HorizontalRegressionPoint/HorizontalEventPoint/GeometryPoint">
                        <xsl:if test="(station/@internalStation &gt;= $startStation) and (station/@internalStation &lt;= $endStation)">
                            <tr>
                                <td align="right" style="white-space:nowrap;">
                                    <xsl:value-of select="inr:stationFormat(number(station/@externalStation - $startStation), $xslStationFormat, $xslStationPrecision, string(station/@externalStationName))"/>
                                </td>
                                <td align="right" style="white-space:nowrap;">
                                    <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat, $xslStationPrecision, string(station/@externalStationName))"/>
                                </td>
                                <td align="center">
                                    <xsl:value-of select="(@name)"/>
                                </td>
                                <td align="right">
                                    <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                </td>
                                <td align="right"><xsl:value-of select="../../@statusFixFree"/></td>
                                <!-- Slew Diagram Column-->
                                <td align="right">
                                    <xsl:if test="(@offset &lt; 0.0)">
                                        <xsl:call-template name="Diagram"/>
                                    </xsl:if>
                                </td>
                                <td align="center">
                                    <xsl:if test="@offset = 0.0">=</xsl:if>
                                    <xsl:if test="not(@offset = 0.0)">&#124;</xsl:if>
                                </td>
                                <td align="left">
                                    <xsl:if test="(@offset &gt; 0.0)">
                                        <xsl:call-template name="Diagram"/>
                                    </xsl:if>
                                </td>
                            </tr>
                        </xsl:if>
                    </xsl:for-each> 
                </table>
            </td>
        </tr>
        <tr><td colspan="2"><hr/></td></tr>
        <tr><td colspan="2">&#xa0;</td></tr>
    </xsl:template>
    <!-- Slew Diagram -->
    <xsl:template name="Diagram">
        <xsl:if test="@offset &lt; 0.0">
            <xsl:call-template name="LessThan0">
                <xsl:with-param name="valuePerSpace" select="number($slewRange div 9)"/>
            </xsl:call-template>
        </xsl:if>
        <xsl:if test="(@offset &gt; 0.0)">
            <xsl:call-template name="GreaterThan0">
                <xsl:with-param name="valuePerSpace" select="number($slewRange div 9)"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>
    <!-- Positive Offset -->
    <xsl:template name="GreaterThan0">
        <xsl:param name="valuePerSpace"/>
        <xsl:choose>
            <xsl:when test="(number(@offset) &gt; 0.0) and (number(@offset) &lt;= $valuePerSpace)">
                <xsl:value-of select="inr:leadingFormat('>', 3)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; $valuePerSpace) and (number(@offset) &lt;= (2 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 6)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (2 * $valuePerSpace)) and (number(@offset) &lt;= (3 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 9)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (3 * $valuePerSpace)) and (number(@offset) &lt;= (4 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 12)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (4 * $valuePerSpace)) and (number(@offset) &lt;= (5 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 15)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (5 * $valuePerSpace)) and (number(@offset) &lt;= (6 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 18)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (6 * $valuePerSpace)) and (number(@offset) &lt;= (7 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 21)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (7 * $valuePerSpace)) and (number(@offset) &lt;= (8 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 24)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (8 * $valuePerSpace)) and (number(@offset) &lt;= (9 * $valuePerSpace))">
                <xsl:value-of select="inr:leadingFormat('>', 27)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &gt; (9 * $valuePerSpace)) and (number(@offset) &lt;= (slewDiagramMax))">
                <xsl:value-of select="inr:leadingFormat('>', 30)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <!-- Negative Offset -->
    <xsl:template name="LessThan0">
        <xsl:param name="valuePerSpace"/>
        <xsl:choose>
            <xsl:when test="(number(@offset) &lt; 0.0) and (number(@offset) &gt;= (-1 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 3)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-1 * $valuePerSpace)) and (number(@offset) &gt;= (-2 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 6)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-2 * $valuePerSpace)) and (number(@offset) &gt;= (-3 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 9)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-3 * $valuePerSpace)) and (number(@offset) &gt;= (-4 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 12)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-4 * $valuePerSpace)) and (number(@offset) &gt;= (-5 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 15)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-5 * $valuePerSpace)) and (number(@offset) &gt;= (-6 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 18)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-6 * $valuePerSpace)) and (number(@offset) &gt;= (-7 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 21)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-7 * $valuePerSpace)) and (number(@offset) &gt;= (-8 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 24)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-8 * $valuePerSpace)) and (number(@offset) &gt;= (-9 * $valuePerSpace))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 27)"/>
            </xsl:when>
            <xsl:when test="(number(@offset) &lt; (-9 * $valuePerSpace)) and (number(@offset) &gt;= (slewDiagramMin))">
                <xsl:value-of select="inr:trailingFormat('&lt;', 30)"/>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment in the <em>Include</em> field on the 
                <em>Tools &gt; XML Reports &gt; Geometry</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This report requires horizontal regression points for a complete report and you must toggle 
                on the <em>Include Horizontal Event Points</em> option.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
    <msxsl:script implements-prefix="inr" language="JScript">
        <![CDATA[
            // This Function formats a string with a length, padding with leading spaces
            // strString - String to get formated
            // nLength - Length of returned string
            function leadingFormat( strString, nLength )
            {
                var i = 0;
                var nBlanks = nLength - strString.length;
                for( i = 0; i < nBlanks; i++ )
                    strString = unescape("%a0") + strString;
                return strString;
            }
            // This Function formats a string with a length, padding with trailing spaces
            // strString - String to get formated
            // nLength - Length of returned string
            function trailingFormat( strString, nLength )
            {
                var nBlanks = nLength - strString.length;
                for( var i = 0; i < nBlanks; i++ )
                    strString = strString + unescape("%a0");
                return strString;
            }
        ]]>
    </msxsl:script>
</xsl:stylesheet>
