<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Roadway Setup Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Roadway Setup Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                            <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Roadway Setup Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Roadway Designer Data -->
                            <xsl:for-each select="RoadwayDesigner">
                                <table class="margin" cellpadding="2">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left"><xsl:value-of select="@fileName"/></td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Corridor Information -->
                                <table class="margin" width="95%">
                                    <xsl:for-each select="Corridor">
                                        <tr>
                                            <td lang="en"><strong>Corridor:&#xa0; </strong><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <td lang="en">
                                                <strong>Start Station:&#xa0; </strong>
                                                <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                <strong>&#xa0; &#xa0; Stop Station:&#xa0; </strong>
                                                <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                <strong>&#xa0; &#xa0; Station Limits Used:&#xa0; </strong>
                                                <xsl:choose>
                                                    <xsl:when test="@useStationLimits = 'true'">Yes</xsl:when>
                                                    <xsl:otherwise>No</xsl:otherwise>
                                                </xsl:choose>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="40%">
                                                    <tr>
                                                        <th colspan="3" lang="en">Secondary Alignments</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Start<br/>Station</th>
                                                        <th class="underline" lang="en" valign="bottom">End<br/>Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Offset</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="SecondaryAlignment">
                                                            <xsl:for-each select="SecondaryAlignment">
                                                                <tr>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="3" lang="en">No Secondary Alignments used</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <tr><td>&#xa0;</td></tr>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="40%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="3" lang="en">Key Stations</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Station</th>
                                                        <th class="underline" lang="en" valign="bottom">X</th>
                                                        <th class="underline" lang="en" valign="bottom">Y</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="KeyStation">
                                                            <xsl:for-each select="KeyStation">
                                                                <tr>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(@externalStation), $xslStationFormat,$xslStationPrecision, string(@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right">
                                                                        <xsl:value-of select="inr:eastingFormat(number(@xLocation), $xslEastingPrecision)"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right">
                                                                        <xsl:value-of select="inr:northingFormat(number(@yLocation), $xslNorthingPrecision)"/>
                                                                    </td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="3" lang="en">No Key Stations found</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="70%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="5" lang="en">Template Drops</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Start<br/>Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Interval</th>
                                                        <th class="underline" lang="en" valign="bottom">Template</th>
                                                        <th class="underline" lang="en" valign="bottom">Horizontal<br/>Offset</th>
                                                        <th class="underline" lang="en" valign="bottom">Vertical<br/>Offset</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="TemplateDrop">
                                                            <xsl:for-each select="TemplateDrop">
                                                                <tr>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right"><xsl:value-of select="@interval"/></td>
                                                                    <td class="sidepad"><xsl:value-of select="Template/@name"/></td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap" valign="bottom">
                                                                        <xsl:value-of select="inr:distanceFormat(number(Template/@translationDX), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap" valign="bottom">
                                                                        <xsl:value-of select="inr:distanceFormat(number(Template/@translationDY), $xslDistancePrecision)"/>
                                                                    </td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="5" lang="en">No Template Drops found</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <tr><td>&#xa0;</td></tr>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="70%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="5" lang="en">Labeled Constraints</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Label</th>
                                                        <th class="underline" lang="en" valign="bottom">Start<br/>Value</th>
                                                        <th class="underline" lang="en" valign="bottom">Stop<br/>Value</th>
                                                        <th class="underline" lang="en" valign="bottom">Start<br/>Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Stop<br/>Station</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="LabeledConstraint">
                                                            <xsl:for-each select="LabeledConstraint">
                                                                <tr>
                                                                    <td class="sidepad"><xsl:value-of select="@label"/></td>
                                                                    <td class="sidepad" align="right">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@startValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@stopValue), $xslDistancePrecision)"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                                    </td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="5" lang="en">No Labeled Constraints found</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <tr><td>&#xa0;</td></tr>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="100%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="7" lang="en">Point Controls</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Priority</th>
                                                        <th class="underline" lang="en" valign="bottom">Point Name</th>
                                                        <th class="underline" lang="en" valign="bottom">Start<br/>Station/Offset</th>
                                                        <th class="underline" lang="en" valign="bottom">End<br/>Station/Offset</th>
                                                        <th class="underline" lang="en" valign="bottom">Mode</th>
                                                        <th class="underline" lang="en" valign="bottom">Control<br/>Type</th>
                                                        <th class="underline" lang="en" valign="bottom">Control Name</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="HVControl">
                                                            <xsl:for-each select="HVControl">
                                                                <tr>
                                                                    <td class="sidepad" valign="top"><xsl:value-of select="@priority"/></td>
                                                                    <td class="sidepad" valign="top"><xsl:value-of select="@pointName"/></td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap" valign="top">
                                                                        <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                                        <br/>
                                                                        <xsl:choose>
                                                                            <xsl:when test="@mode='Horizontal'">
                                                                                <xsl:value-of select="inr:distanceFormat(number(@offsetStart), $xslDistancePrecision)"/>
                                                                            </xsl:when>
                                                                            <xsl:otherwise>
                                                                                <xsl:choose>
                                                                                    <xsl:when test="@mode='Vertical'">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@verticalOffsetStart), $xslDistancePrecision)"/>
                                                                                    </xsl:when>
                                                                                    <xsl:otherwise>
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@offsetStart), $xslDistancePrecision)"/>
                                                                                        <br/>
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@verticalOffsetStart), $xslDistancePrecision)"/>
                                                                                    </xsl:otherwise>
                                                                                </xsl:choose>
                                                                            </xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap" valign="top">
                                                                        <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                                        <br/>
                                                                        <xsl:choose>
                                                                            <xsl:when test="@mode='Horizontal'">
                                                                                <xsl:value-of select="inr:distanceFormat(number(@offsetStop), $xslDistancePrecision)"/>
                                                                            </xsl:when>
                                                                            <xsl:otherwise>
                                                                                <xsl:choose>
                                                                                    <xsl:when test="@mode='Vertical'">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@verticalOffsetStop), $xslDistancePrecision)"/>
                                                                                    </xsl:when>
                                                                                    <xsl:otherwise>
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@offsetStop), $xslDistancePrecision)"/>
                                                                                        <br/>
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@verticalOffsetStop), $xslDistancePrecision)"/>
                                                                                    </xsl:otherwise>
                                                                                </xsl:choose>
                                                                            </xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </td>
                                                                    <td class="sidepad" valign="top"><xsl:value-of select="@mode"/></td>
                                                                    <td class="sidepad" valign="top"><xsl:value-of select="@controlType"/></td>
                                                                    <td class="sidepad" valign="top"><xsl:value-of select="@controlName"/></td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="7" lang="en">No Point Controls used</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <tr><td>&#xa0;</td></tr>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="100%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="6" lang="en">Transitions</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" rowspan="2" valign="bottom">Start<br/>Station</th>
                                                        <th class="underline" lang="en" rowspan="2" valign="bottom">Stop<br/>Station</th>
                                                        <th colspan="2" lang="en" valign="bottom">- - - - - - From - - - - - -</th>
                                                        <th colspan="2" lang="en" valign="bottom">- - - - - - - To - - - - - - -</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Template</th>
                                                        <th class="underline" lang="en" valign="bottom">Point</th>
                                                        <th class="underline" lang="en" valign="bottom">Template</th>
                                                        <th class="underline" lang="en" valign="bottom">Point</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="Transition">
                                                            <xsl:for-each select="Transition">
                                                                <xsl:for-each select="TransitionLine">
                                                                    <tr>
                                                                        <xsl:choose>
                                                                            <xsl:when test="position() = 1">
                                                                                <td align="right" nowrap="nowrap">
                                                                                    <xsl:value-of select="inr:stationFormat(number(../../TemplateDrop[@oid = current()/../@templateDropOID1]/StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../TemplateDrop[@oid = current()/../@templateDropOID1]/StartStation/@externalStationName))"/>
                                                                                </td>
                                                                                <td align="right" nowrap="nowrap">
                                                                                    <xsl:value-of select="inr:stationFormat(number(../../TemplateDrop[@oid = current()/../@templateDropOID2]/StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(../../TemplateDrop[@oid = current()/../@templateDropOID2]/StartStation/@externalStationName))"/>
                                                                                </td>
                                                                            </xsl:when>
                                                                            <xsl:otherwise><td colspan="2">&#xa0;</td></xsl:otherwise>
                                                                        </xsl:choose>
                                                                        <td>
                                                                            <xsl:value-of select="../../TemplateDrop/Template[@oid = current()/../@templateOID1]/@name"/>
                                                                        </td>
                                                                        <td class="sidepad"><xsl:value-of select="@point1"/></td>
                                                                        <td>
                                                                            <xsl:value-of select="../../TemplateDrop/Template[@oid = current()/../@templateOID2]/@name"/>
                                                                        </td>
                                                                        <td class="sidepad"><xsl:value-of select="@point2"/></td>
                                                                    </tr>
                                                                    <xsl:if test="position() = last()">
                                                                        <tr><td colspan="6">&#xa0;</td></tr>
                                                                    </xsl:if>
                                                                </xsl:for-each>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="6" lang="en">No Transitions found</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="40%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="3" lang="en">End Condition Exceptions</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Start Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Stop Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Type</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="EndConditionException">
                                                            <xsl:for-each select="EndConditionException">
                                                                <tr>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad">
                                                                        <xsl:choose>
                                                                            <xsl:when test="@type = 'OverrideLeft'">Left Override</xsl:when>
                                                                            <xsl:when test="@type = 'OverrideRight'">Right Override</xsl:when>
                                                                            <xsl:when test="@type = 'TransitionLeft'">Left Transition</xsl:when>
                                                                            <xsl:when test="@type = 'TransitionRight'">Right Transition</xsl:when>
                                                                            <xsl:otherwise>Unknown</xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="3" lang="en">No End Condition Exceptions found</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td><hr size="1"/></td></tr>
                                        <tr><td>&#xa0;</td></tr>
                                        <tr>
                                            <td>
                                                <table width="100%">
                                                    <tr style="page-break-before:always">
                                                        <th colspan="6" lang="en">Superelevation Sections</th>
                                                    </tr>
                                                    <tr>
                                                        <th class="underline" lang="en" valign="bottom">Name</th>
                                                        <th class="underline" lang="en" valign="bottom">Start Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Stop Station</th>
                                                        <th class="underline" lang="en" valign="bottom">Crown Point</th>
                                                        <th class="underline" lang="en" valign="bottom">Left Range Point</th>
                                                        <th class="underline" lang="en" valign="bottom">Right Range Point</th>
                                                        <th class="underline" lang="en" valign="bottom">Pivot From</th>
                                                        <th class="underline" lang="en" valign="bottom">Pivot By</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="SuperSection">
                                                            <xsl:for-each select="SuperSection">
                                                                <tr>
                                                                    <td class="sidepad"><xsl:value-of select="@name"/></td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad" align="right" nowrap="nowrap">
                                                                        <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                                    </td>
                                                                    <td class="sidepad"><xsl:value-of select="@crown"/></td>
                                                                    <td class="sidepad"><xsl:value-of select="@leftRange"/></td>
                                                                    <td class="sidepad"><xsl:value-of select="@rightRange"/></td>
                                                                    <td class="sidepad">
                                                                        <xsl:choose>
                                                                            <xsl:when test="@pivotFrom = '0'">Crown</xsl:when>
                                                                            <xsl:when test="@pivotFrom = '1'">Left</xsl:when>
                                                                            <xsl:when test="@pivotFrom = '2'">Right</xsl:when>
                                                                            <xsl:when test="@pivotFrom = '3'">Inside</xsl:when>
                                                                            <xsl:when test="@pivotFrom = '4'">Outside</xsl:when>
                                                                            <xsl:otherwise>Undefined</xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </td>
                                                                    <td class="sidepad">
                                                                        <xsl:choose>
                                                                            <xsl:when test="@pivotBy = '0'">Single Point</xsl:when>
                                                                            <xsl:when test="@pivotBy = '1'">Adjacent Point</xsl:when>
                                                                            <xsl:otherwise>Undefined</xsl:otherwise>
                                                                        </xsl:choose>
                                                                    </td>
                                                                </tr>
                                                            </xsl:for-each>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td colspan="6" lang="en">No Superelevation Sections defined</td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </table>
                                            </td>
                                        </tr>
                                        <tr><td>&#xa0;</td></tr>
                                    </xsl:for-each>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must open a Roadway Design file by selecting <em>File &gt; Open</em> on the <em>Report 
                Browser</em> menu and setting the <em>Files of type</em> field to <em>Roadway Design 
                (*.ird)</em>.
            </p>
            <p class="normal1" lang="en">
                You must also have at least one corridor defined in the <em>Modeler &gt; Roadway Designer 
                &gt; Corridor &gt; Corridor Manager</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
