<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl" />
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Complex Data Report for LRM -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Complex Data Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Complex Data Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()" /><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()" />
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor" />
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <table class="margin" cellpadding="2" cellspacing="1" width="95%">
                                    <tbody>
                                        <!-- Rail Length Data -->
                                        <tr>
                                            <th align="left" colspan="10" lang="en">Rail Lengths</th>
                                        </tr>
                                        <tr>
                                            <th colspan="4">&#xa0;</th>
                                            <th colspan="2" lang="en">- - - - Start - - - -</th>
                                            <th colspan="2" lang="en">- - - - Stop  - - - -</th>
                                            <th lang="en">Start</th>
                                            <th lang="en">Stop</th>
                                        </tr>
                                        <tr>
                                            <th lang="en">Name</th>
                                            <th lang="en">L/R</th>
                                            <th lang="en">Rail ID</th>
                                            <th lang="en">Length</th>
                                            <th lang="en">Easting</th>
                                            <th lang="en">Northing</th>
                                            <th lang="en">Easting</th>
                                            <th lang="en">Northing</th>
                                            <th lang="en">Station</th>
                                            <th lang="en">Station</th>
                                        </tr>
                                        <xsl:for-each select="HorizontalAlignment/Rails/Rail">
                                            <xsl:for-each select="KeyPoints/KeyPoint">
                                                <tr>
                                                    <xsl:if test="position() != last()">
                                                        <td><xsl:value-of select="../../../../@name" /></td>
                                                        <td><xsl:value-of select="../../@name" /></td>
                                                        <td>
                                                            <xsl:value-of select="@name" /> - <xsl:value-of select="following-sibling::KeyPoint/@name" />
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@railLength), $xslDistancePrecision)" />
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)" />
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)" />
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(following-sibling::KeyPoint/@easting), $xslEastingPrecision)" />
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(following-sibling::KeyPoint/@northing), $xslNorthingPrecision)" />
                                                        </td>
                                                        <td align="right" nowrap="nowrap">
                                                            <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat,$xslStationPrecision, string(station/@externalStationName))" />
                                                        </td>
                                                        <td align="right" nowrap="nowrap">
                                                            <xsl:value-of select="inr:stationFormat(number(following-sibling::KeyPoint/station/@externalStation), $xslStationFormat,$xslStationPrecision, string(station/@externalStationName))" />
                                                        </td>
                                                    </xsl:if>
                                                </tr>
                                            </xsl:for-each>
                                            <tr><td colspan="10">&#xa0;</td></tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                                <table class="margin" cellpadding="2" cellspacing="1" width="50%">
                                    <tbody>
                                        <!-- Joint Coordinate Data -->
                                        <tr>
                                            <th align="left" colspan="5" lang="en">Joint Coordinates</th>
                                        </tr>
                                        <tr>
                                            <th lang="en">Joint</th>
                                            <th lang="en">Alignment</th>
                                            <th lang="en">Station</th>
                                            <th lang="en">Easting</th>
                                            <th lang="en">Northing</th>
                                        </tr>
                                        <xsl:for-each select="HorizontalAlignment/Rails/Rail/KeyPoints/KeyPoint">
                                            <xsl:sort select="@name" />
                                            <tr>
                                                <td><xsl:value-of select="@name" /></td>
                                                <td><xsl:value-of select="../../../../@name" /></td>
                                                <td align="right" nowrap="nowrap">
                                                    <xsl:value-of select="inr:stationFormat(number(station/@externalStation), $xslStationFormat,$xslStationPrecision, string(station/@externalStationName))" />
                                                </td>
                                                <td align="right">
                                                    <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)" />
                                                </td>
                                                <td align="right">
                                                    <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)" />
                                                </td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select a horizontal alignment that has rails in the <em>Horizontal Alignment</em> 
                field on the <em>General</em> tab of the <em>Geometry &gt; Light Rail Manufacturing &gt; 
                Reports</em> command.&#xa0; You must also toggle on the <em>Include Rails</em> option.
            </p>
            <p class="normal1" lang="en">
                Your rails must have keypoints, joints, switches and crossings defined to get results from 
                this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                To access the <em>Light Rail Manufacturing</em> commands, select the <em>Tools &gt; 
                Application Add-Ins</em> command and toggle on the <em>Light Rail Manufacturing 
                Add-In</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
