<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:variable name="distanceJointToConnectionHole" select="number(0.08250000)"/>
    <xsl:variable name="distanceBetweenConnectionHoles" select="number(0.24000000)"/>
    <xsl:variable name="distanceBetweenDistanceKeeperHoles" select="number(0.09000000)"/>
    <xsl:variable name="bendingMachineLength" select="number(0.50000000)"/>
    <!-- Distance Keepers List -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Distance Keepers List</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Distance Keepers List</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">File Name:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@file"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Last Revised:&#xa0; </th>
                                            <td align="left" colspan="2">
                                                <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                            </td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%">
                                                <xsl:value-of select="../@inputGridScaleFactor"/>
                                            </td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <table class="margin" cellpadding="2" cellspacing="1" width="80%">
                                    <thead>
                                        <colgroup span="7">
                                            <col width="14%"/>
                                            <col width="14%"/>
                                            <col width="14%"/>
                                            <col width="16%"/>
                                            <col width="14%"/>
                                            <col width="14%"/>
                                            <col width="14%"/>
                                        </colgroup>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="HorizontalAlignment/DistanceKeepers/DistanceKeeper">
                                            <xsl:variable name="currentLeftBackJoint" select="@leftBackJoint"/>
                                            <xsl:variable name="currentRightBackJoint" select="@rightBackJoint"/>
                                            <xsl:choose>
                                                <xsl:when test="number(@leftBackKeeperToKeeper) = 0.0">
                                                    <xsl:if test="@leftRailName">
                                                        <tr>
                                                            <th align="left" lang="en" valign="bottom"><br/>Section:</th>
                                                            <th align="left" colspan="2" valign="bottom"><xsl:value-of select="@leftRailName"/></th>
                                                            <th>&#xa0;</th>
                                                            <th align="left" lang="en" valign="bottom"><br/>Section:</th>
                                                            <th align="left" colspan="2" valign="bottom"><xsl:value-of select="@rightRailName"/></th>
                                                        </tr>
                                                    </xsl:if>
                                                    <xsl:if test="@leftBackJoint">
                                                        <tr>
                                                            <th align="left" colspan="3" lang="en">
                                                                From <xsl:value-of select="@leftBackJoint"/>
                                                                to <xsl:value-of select="@leftAheadJoint"/>
                                                            </th>
                                                            <th>&#xa0;</th>
                                                            <th align="left" colspan="3" lang="en">
                                                                From <xsl:value-of select="@rightBackJoint"/>
                                                                to <xsl:value-of select="@rightAheadJoint"/>
                                                            </th>
                                                        </tr>
                                                    </xsl:if>
                                                    <tr>
                                                        <th class="underline" align="left" lang="en" valign="bottom">Horizontal<br/>Alignment</th>
                                                        <th class="underline" align="left" lang="en" valign="bottom">Rail</th>
                                                        <th class="underline" align="right" lang="en" valign="bottom">Length</th>
                                                        <th valign="bottom"></th>
                                                        <th class="underline" align="left" lang="en" valign="bottom">Horizontal<br/>Alignment</th>
                                                        <th class="underline" align="left" lang="en" valign="bottom">Rail</th>
                                                        <th class="underline" align="right" lang="en" valign="bottom">Length</th>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="//KeyPoint[@name = $currentLeftBackJoint]/@railCurvature = 'right' or //KeyPoint[@name = $currentLeftBackJoint]/@railCurvature = 'complex right'">
                                                            <tr>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole + $bendingMachineLength), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td/>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole + $bendingMachineLength), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td/>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenConnectionHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenConnectionHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftBackJointToKeeper - (@leftBackJointLength div 2) - $distanceJointToConnectionHole - $distanceBetweenConnectionHoles - ($distanceBetweenDistanceKeeperHoles div 2)), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightBackJointToKeeper - (@rightBackJointLength div 2) - $distanceJointToConnectionHole - $distanceBetweenConnectionHoles - ($distanceBetweenDistanceKeeperHoles div 2)), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:when>
                                                <xsl:when test="number(@leftAheadKeeperToKeeper) = 0.0">
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftBackKeeperToKeeper - $distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightBackKeeperToKeeper - $distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftAheadJointToKeeper - (@leftAheadJointLength div 2) - $distanceJointToConnectionHole - $distanceBetweenConnectionHoles - ($distanceBetweenDistanceKeeperHoles div 2)), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td></td>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightAheadJointToKeeper - (@rightAheadJointLength div 2) - $distanceJointToConnectionHole - $distanceBetweenConnectionHoles - ($distanceBetweenDistanceKeeperHoles div 2)), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenConnectionHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenConnectionHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <xsl:choose>
                                                        <xsl:when test="//KeyPoint[@name = $currentLeftBackJoint]/@railCurvature = 'left' or //KeyPoint[@name = $currentLeftBackJoint]/@railCurvature = 'complex left'">
                                                            <tr>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole + $bendingMachineLength), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td/>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole + $bendingMachineLength), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            <tr>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td/>
                                                                <td><xsl:value-of select="../../@name"/></td>
                                                                <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number($distanceJointToConnectionHole), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <xsl:if test="@leftBackJoint">
                                                        <tr>
                                                            <th align="right" colspan="2" lang="en">Total:</th>
                                                            <td align="right"><xsl:value-of select="inr:distanceFormat(number(//KeyPoint[@name = $currentLeftBackJoint]/@railLength + $bendingMachineLength), $xslDistancePrecision)"/></td>
                                                            <td/>
                                                            <th align="right" colspan="2" lang="en">Total:</th>
                                                            <td align="right"><xsl:value-of select="inr:distanceFormat(number(//KeyPoint[@name = $currentRightBackJoint]/@railLength + $bendingMachineLength), $xslDistancePrecision)"/></td>
                                                        </tr>
                                                    </xsl:if>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number($distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@leftParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@leftBackKeeperToKeeper - $distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td/>
                                                        <td><xsl:value-of select="../../@name"/></td>
                                                        <td align="left"><xsl:value-of select="@rightParentRail"/></td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@rightBackKeeperToKeeper - $distanceBetweenDistanceKeeperHoles), $xslDistancePrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select a horizontal alignment that has rails in the <em>Horizontal Alignment</em> 
                field on the <em>General</em> tab of the <em>Geometry &gt; Light Rail Manufacturing &gt; 
                Reports</em> command.&#xa0; You must also toggle on the <em>Include Distance Keepers</em> 
                option.
            </p>
            <p class="normal1" lang="en">
                Your rails must have keypoints, joints, switches, crossings and distance keepers defined to 
                get results from this report.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                To access the <em>Light Rail Manufacturing</em> commands, select the <em>Tools &gt; 
                Application Add-Ins</em> command and toggle on the <em>Light Rail Manufacturing 
                Add-In</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
