<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Roadway Visibility Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Roadway Visibility Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Roadway Visibility Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/>&#xa0; 
                                    <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <xsl:for-each select="RoadwayVisibility">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <!-- Visibility surfaces data -->
                                        <tr>
                                            <th align="right" lang="en" valign="top">Surface(s):&#xa0; </th>
                                            <td valign="top">
                                                <xsl:for-each select="VisibilitySurfaces/VisibilitySurface">
                                                    <xsl:value-of select="@name"/><br/>
                                                </xsl:for-each>
                                            </td>
                                        </tr>
                                        <tr><td colspan="4">&#xa0;</td></tr>
                                        <!-- Visibility parameters -->
                                        <xsl:for-each select="VisibilityParameters">
                                            <tr>
                                                <th align="right" lang="en" valign="top">Alignment Name:&#xa0; </th>
                                                <td valign="top"><xsl:value-of select="@alignmentName"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" valign="top">Start Station:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:stationFormat(number(StartStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StartStation/@externalStationName))"/>
                                                </td>
                                                <th align="right" lang="en" valign="top">Analysis Range:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:distanceFormat(number(@sightDistance), $xslDistancePrecision)"/>
                                                </td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" valign="top">Stop Station:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:stationFormat(number(StopStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(StopStation/@externalStationName))"/>
                                                </td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" valign="top">Interval:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:distanceFormat(number(@interval), $xslDistancePrecision)"/>
                                                </td>
                                            </tr>
                                            <tr><td colspan="4">&#xa0;</td></tr>
                                            <tr>
                                                <th align="right" lang="en" valign="top">Eye Position:&#xa0; </th>
                                                <td valign="top"><xsl:value-of select="@eyePosition"/></td>
                                                <th align="right" lang="en" valign="top">Object Position:&#xa0; </th>
                                                <td valign="top"><xsl:value-of select="@objectPosition"/></td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" valign="top">Eye Height:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:distanceFormat(number(@eyeHeight), $xslDistancePrecision)"/>
                                                </td>
                                                <th align="right" lang="en" valign="top">Object Height:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:distanceFormat(number(@objectHeight), $xslDistancePrecision)"/>
                                                </td>
                                            </tr>
                                            <tr>
                                                <th align="right" lang="en" valign="top">Eye Offset:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:distanceFormat(number(@eyeOffset), $xslDistancePrecision)"/>
                                                </td>
                                                <th align="right" lang="en" valign="top">Object Offset:&#xa0; </th>
                                                <td valign="top">
                                                    <xsl:value-of select="inr:distanceFormat(number(@objectOffset), $xslDistancePrecision)"/>
                                                </td>
                                            </tr>
                                            <tr><td colspan="4">&#xa0;</td></tr>
                                        </xsl:for-each>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%" valign="top">
                                                Input Grid Factor:&#xa0; 
                                            </th>
                                            <td align="left" style="font-size: 80%" valign="top">
                                                <xsl:value-of select="../@inputGridScaleFactor"/>
                                            </td>
                                            <td align="right" colspan="2" lang="en" style="font-size: 80%" valign="top">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Visibility data -->
                                <xsl:for-each select="Visibilities">
                                    <table class="margin" cellpadding="1" cellspacing="2" width="65%">
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th>&#xa0;</th>
                                                <th class="underline" lang="en">Station</th>
                                                <th class="underline" lang="en">Offset</th>
                                                <th class="underline" lang="en">Elevation</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <xsl:for-each select="Visibility">
                                                <tr>
                                                    <th align="left" lang="en">Eye Position:&#xa0; </th>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:stationFormat(number(EyeStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(EyeStation/@externalStationName))"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:distanceFormat(number(@eyeOffset), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@eyeElevation), $xslElevationPrecision)"/>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Object Position:&#xa0; </th>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:stationFormat(number(ObjectStation/@externalStation), $xslStationFormat,$xslStationPrecision, string(ObjectStation/@externalStationName))"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:distanceFormat(number(@objectOffset), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td class="sidepad" align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@objectElevation), $xslElevationPrecision)"/>
                                                    </td>
                                                </tr>
                                              <tr>
                                                <th align="left" lang="en">Speed:&#xa0; </th>
                                                <xsl:choose>
                                                  <xsl:when test="@isUnlimited = 'true'">
                                                    <td class="sidepad" align="right">Unlimited</td>
                                                  </xsl:when>
                                                  <xsl:otherwise>
                                                    <td class="sidepad" align="right">
                                                      <xsl:value-of select="inr:distanceFormat(number(@speed), $xslDistancePrecision)"/>
                                                    </td>
                                                  </xsl:otherwise>
                                                </xsl:choose>
                                              </tr>
                                              <tr>
                                                <th align="left" lang="en">Acceleration:&#xa0; </th>
                                                <xsl:choose>
                                                  <xsl:when test="@isUnlimited = 'true'">
                                                    <td class="sidepad" align="right">Unlimited</td>
                                                  </xsl:when>
                                                  <xsl:otherwise>
                                                    <td class="sidepad" align="right">
                                                      <xsl:value-of select="inr:distanceFormat(number(@acceleration), $xslDistancePrecision)"/>
                                                    </td>
                                                  </xsl:otherwise>
                                                </xsl:choose>
                                              </tr>
                                              <tr>
                                                <th align="left" lang="en">Stopping Distance:&#xa0; </th>
                                                <xsl:choose>
                                                  <xsl:when test="@isUnlimited = 'true'">
                                                    <td class="sidepad" align="right">Unlimited</td>
                                                  </xsl:when>
                                                  <xsl:otherwise>
                                                    <td class="sidepad" align="right">
                                                      <xsl:value-of select="inr:distanceFormat(number(@stoppingDistance), $xslDistancePrecision)"/>
                                                    </td>
                                                  </xsl:otherwise>
                                                </xsl:choose>
                                              </tr>
                                              <tr>
                                                <th align="left" lang="en">Effective Distance:&#xa0; </th>
                                                <xsl:choose>
                                                  <xsl:when test="@isUnlimited = 'true'">
                                                    <td class="sidepad" align="right">Unlimited</td>
                                                  </xsl:when>
                                                  <xsl:otherwise>
                                                    <td class="sidepad" align="right">
                                                      <xsl:value-of select="inr:distanceFormat(number(@sightDistance), $xslDistancePrecision)"/>
                                                    </td>
                                                  </xsl:otherwise>
                                                </xsl:choose>
                                              </tr>
                                              <tr>
                                                <th align="left" lang="en">Reacquired Distance:&#xa0; </th>
                                                <xsl:choose>
                                                  <xsl:when test="@reacquiredIsUnlimited = 'true'">
                                                    <td class="sidepad" align="right">Unlimited</td>
                                                  </xsl:when>
                                                  <xsl:otherwise>
                                                    <td class="sidepad" align="right">
                                                      <xsl:value-of select="inr:distanceFormat(number(@reacquiredDistance), $xslDistancePrecision)"/>
                                                    </td>
                                                  </xsl:otherwise>
                                                </xsl:choose>
                                              </tr>
                                              <tr><td colspan="4">&#xa0;</td></tr>
                                            </xsl:for-each>
                                        </tbody>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one surface in the <em>Surfaces</em> list on the <em>Evaluation 
                &gt; Sight Visibility &gt; Roadway Visibility</em> command and you must toggle on the 
                <em>Create XML Report</em> option to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2007 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
