<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <title lang="en">Station Offset Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <h2 lang="en">Station Offset Northing Easting Elevation Feature Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>

                          <xsl:for-each select="GeometryProject">
                            <table class="margin" cellpadding="2" width="90%">
                              <tbody>
                                <tr>
                                  <th align="right" lang="en">Project:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="@name"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">Description:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="@description"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">Baseline (Active) Alignment:</th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="HorizontalAlignment/@name"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">File Name:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="@file"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en">Last Revised:&#xa0; </th>
                                  <td align="left" colspan="2">
                                    <xsl:value-of select="concat(@lastRevisedBy, '  ', @lastRevisedDate)"/>
                                  </td>
                                </tr>
                                <tr>
                                  <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                  <td align="left" style="font-size: 80%">
                                    <xsl:value-of select="../@inputGridScaleFactor" />
                                  </td>
                                  <td align="right" lang="en" style="font-size: 80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                  </td>
                                </tr>
                              </tbody>
                            </table>
                            <hr/>

                            <xsl:for-each select="HorizontalAlignment">
                              <table cellspacing="4" width="100%">
                                <thead style="display:table-header-group">
                                  <tr>
                                    <th class="underline" lang="en" align="left">Point</th>
                                    <th class="underline" lang="en" align="left">Station</th>
                                    <th class="underline" lang="en" align="left">Offset</th>
                                    <th class="underline" lang="en" align="left">Northing</th>
                                    <th class="underline" lang="en" align="left">Easting</th>
									<th class="underline" lang="en" align="left">Elevation</th>
									<th class="underline" lang="en" align="left">Feature</th>
                                  </tr>
                                </thead>
                                <tbody>
                                  <xsl:for-each select="OffsetPoint">
                                    <tr>
                                      <td align="left">
                                        <xsl:value-of select="@PointName"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="inr:stationFormat(number(@externalStation), $xslStationFormat, $xslStationPrecision, string(@externalStationName))"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="inr:distanceFormat(number(@offset), $xslDistancePrecision)"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="inr:northingFormat(number(@northing), $xslNorthingPrecision)"/>
                                      </td>
                                      <td align="left">
                                        <xsl:value-of select="inr:eastingFormat(number(@easting), $xslEastingPrecision)"/>
                                      </td>
									  <td align="left">
									  	<xsl:if test="@elevation">
                                        	<xsl:value-of select="inr:elevationFormat(number(@elevation), $xslElevationPrecision)"/>
										</xsl:if>
									  </td>
									  <td align="left">
                                        <xsl:value-of select="@FeatureName"/>
                                      </td>
                                    </tr>
                                  </xsl:for-each>
                                </tbody>
                              </table>
                            </xsl:for-each>
                          </xsl:for-each>

                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>

    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must create station offset points for this report by selecting <em>
                    Tools &gt; XML
                    Reports &gt; Station Offset
                </em>.
            </p>
            <p class="normal1" lang="en">
                You must include at least one horizontal alignment or one feature on the <em>General</em>
                leaf in the <em>From</em> fields.
            </p>
            <p class="normal1" lang="en">
                You must also include at least one horizontal alignment on the <em>
                    Horizontal Alignments
                </em> leaf or one feature on the <em> Features</em> leaf.
            </p>
            <p class="normal1" lang="en">
                You must choose at least one option on the <em>Include</em> leaf (<em>
                    Horizontal On-
                    Alignment Points, Horizontal Event Points, Vertical On-Alignment Points, Vertical Event
                    Points
                </em> or <em>Interval</em>.)
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2013 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
<!-- Stylus Studio meta-information - (c) 2004-2009. Progress Software Corporation. All rights reserved.

<metaInformation>
	<scenarios/>
	<MapperMetaTag>
		<MapperInfo srcSchemaPathIsRelative="yes" srcSchemaInterpretAsXML="no" destSchemaPath="" destSchemaRoot="" destSchemaPathIsRelative="yes" destSchemaInterpretAsXML="no"/>
		<MapperBlockPosition></MapperBlockPosition>
		<TemplateContext></TemplateContext>
		<MapperFilter side="source"></MapperFilter>
	</MapperMetaTag>
</metaInformation>
-->