<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Key value for summing -->
    <xsl:key name="qtoByPayItem" match="Feature" use="@payItem"/>
    <!-- Unique pay items of all linear features that do not have an area and are not random type -->
    <xsl:variable name="uniquePayItemsByLength" select="//Features/Feature[not(@payItem = preceding::Feature/@payItem) and @length > 0.0 and not(@area) and not(@type = 'random')]/@payItem"/>
    <!-- Unique pay items of all features with an area greater than zero -->
    <xsl:variable name="uniquePayItemsByArea" select="//Features/Feature[not(@payItem = preceding::Feature/@payItem) and @area > 0.0]/@payItem"/>
    <!-- Unique pay items of all random point features -->
    <xsl:variable name="uniquePayItemsByPoints" select="//Features/Feature[not(@payItem = preceding::Feature/@payItem) and @type = 'random']/@payItem"/>
    <!-- Include an example Pay Items XML File -->
    <xsl:variable name="payItemList" select="document('payitems.xml')"/>
    <!-- Quantity Takeoff Report -->
    <xsl:template match="/">
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!--Title displayed in browser Title Bar-->
                <title lang="en">Quantity Takeoff Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!--Report Title-->
                                <h2 lang="en">Quantity Takeoff Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <span lang="en" style="font-size:smaller">
                                Input Grid Factor:&#xa0; <xsl:value-of select="@inputGridScaleFactor" />
                            </span>
                            <hr />
                            <br />
                            <table class="margin" border="1" cellpadding="3" cellspacing="0" width="90%">
                                <tr>
                                    <th lang="en">Pay Item</th>
                                    <th lang="en">Description</th>
                                    <th lang="en">Quantity</th>
                                    <th lang="en">Unit</th>
                                    <th lang="en">Unit Cost</th>
                                    <th lang="en">Total</th>
                                </tr>
                                <!-- Linear Features -->
                                <xsl:for-each select="$uniquePayItemsByLength">
                                    <tr>
                                        <td><xsl:value-of select="."/></td>
                                        <td><xsl:value-of select="../@style"/></td>
                                        <xsl:call-template name="totalLength"/>
                                    </tr>
                                </xsl:for-each>
                                <!-- Area Features -->
                                <xsl:for-each select="$uniquePayItemsByArea">
                                    <tr>
                                        <td><xsl:value-of select="."/></td>
                                        <td><xsl:value-of select="../@style"/></td>
                                        <xsl:call-template name="totalArea"/>
                                    </tr>
                                </xsl:for-each>
                                <!-- Point Features -->
                                <xsl:for-each select="$uniquePayItemsByPoints">
                                    <tr>
                                        <td><xsl:value-of select="."/></td>
                                        <td><xsl:value-of select="../@style"/></td>
                                        <xsl:call-template name="totalPoints"/>
                                    </tr>
                                </xsl:for-each>
                            </table>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Templates for summing by pay item, retrieving unit cost from pay items
         file and calculating costs.  Use of a factor is for illustration only
         and is not required.  Set all factors to one if it is not needed. -->
    <xsl:template name="totalLength">
        <xsl:variable name="sumOfLengths" select="sum(key('qtoByPayItem', string(.))/@length)"/>
        <xsl:variable name="units" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@units"/>
        <xsl:variable name="factor" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@factor"/>
        <xsl:variable name="unitCost" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@unitCost"/>
        <td><xsl:value-of select="inr:distanceFormat(number($sumOfLengths * $factor), $xslDistancePrecision)"/></td>
        <td><xsl:value-of select="$units"/></td>
        <td align="right"><xsl:value-of select="$unitCost"/></td>
        <td align="right"><xsl:value-of select="msxsl:formatNumber(number($sumOfLengths * $factor * $unitCost),'$ #,##0.00')"/></td>
    </xsl:template>
    <xsl:template name="totalArea">
        <xsl:variable name="sumOfAreas" select="sum(key('qtoByPayItem', string(.))/@area)"/>
        <xsl:variable name="units" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@units"/>
        <xsl:variable name="factor" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@factor"/>
        <xsl:variable name="unitCost" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@unitCost"/>
        <td><xsl:value-of select="inr:areaFormat(number($sumOfAreas * $factor), $xslAreaPrecision)"/></td>
        <td><xsl:value-of select="$units"/></td>
        <td align="right"><xsl:value-of select="$unitCost"/></td>
        <td align="right"><xsl:value-of select="msxsl:formatNumber(number($sumOfAreas * $factor * $unitCost),'$ #,##0.00')"/></td>
    </xsl:template>
    <xsl:template name="totalPoints">
        <xsl:variable name="sumOfPoints" select="sum(key('qtoByPayItem', string(.))/@numberPoints)"/>
        <xsl:variable name="units" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@units"/>
        <xsl:variable name="factor" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@factor"/>
        <xsl:variable name="unitCost" select="$payItemList/*/PayItem[@name = current()/../@payItem]/@unitCost"/>
        <td><xsl:value-of select="$sumOfPoints * $factor"/></td>
        <td><xsl:value-of select="$units"/></td>
        <td align="right"><xsl:value-of select="$unitCost"/></td>
        <td align="right"><xsl:value-of select="msxsl:formatNumber(number($sumOfPoints * $factor * $unitCost),'$ #,##0.00')"/></td>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must include at least one feature in the <em>Features</em> list on the <em>Tools &gt; 
                XML Reports &gt; Surfaces</em> command to get results from this report.
            </p>
            <p class="normal1" lang="en">
                This style sheet uses a "look-up table" to select a pay item unit, factor and cost from a 
                separate XML file by finding a pay item name in it that matches the <code>payItem</code> 
                attribute of the feature.&#xa0; An example XML file called <span class="directory">
                payitems.xml</span> is included in the <span class="directory">Surfaces</span> 
                directory.&#xa0; This file can be modified to suit your needs, or you can create your own 
                file.&#xa0; The file name is stored in a variable called <code>payItemList</code> near the 
                top of the style sheet, and you should change this value if you create your own file.
            </p>
            <p class="normal1" lang="en">
                This report sums the areas of closed features, the lengths of linear features and the 
                number of points of random features based on feature style.&#xa0; If you wish to sum random 
                features, you must toggle on the <em>Include Feature Points</em> option on the <em>Tools 
                &gt; XML Reports &gt; Surfaces</em> command.&#xa0; After summing the values, templates in 
                the style sheet multiply the totals by the pay item factor and unit cost retrieved from the 
                Pay Item List XML file.&#xa0; The use of a factor is for illustration only and is not 
                required.&#xa0; You should set all factors to one in the <span 
                class="directory">payitems.xml</span> file if you do not need factors.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
