<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Error Ellipse Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Error Ellipse Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="AdjustmentNet">
                                <center>
                                    <!-- Report Title -->
                                    <h2 lang="en">Error Ellipse Report</h2>
                                    <p lang="en">
                                        Report Created:&#xa0; <xsl:value-of select="inr:date()"/>
                                        <br/>
                                        Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                    </p>
                                </center>
                                <p lang="en" style="text-align:right;font-size:80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in 
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                </p>
                                <hr/>
                                <xsl:choose>
                                    <xsl:when test="@adjustmentConverges='true'">
                                        <xsl:for-each select="AdjustmentPoints">
                                            <center><h4>Absolute Ellipses</h4></center>
                                            <hr/>
                                            <table cellpadding="1" cellspacing="1" width="100%">
                                                <colgroup span="8">
                                                    <col width="10%"/>
                                                    <col width="15%"/>
                                                    <col width="15%"/>
                                                    <col width="12%"/>
                                                    <col width="12%"/>
                                                    <col width="12%"/>
                                                    <col width="12%"/>
                                                    <col width="12%"/>
                                                </colgroup>
                                                <thead style="display:table-header-group">
                                                    <tr>
                                                        <th class="underline" valign="bottom">Name</th>
                                                        <th class="underline" valign="bottom">Northing</th>
                                                        <th class="underline" valign="bottom">Easting</th>
                                                        <th class="underline" valign="bottom">Sx</th>
                                                        <th class="underline" valign="bottom">Sy</th>
                                                        <th class="underline" valign="bottom">Su</th>
                                                        <th class="underline" valign="bottom">Sv</th>
                                                        <th class="underline" valign="bottom">t</th>
                                                    </tr>
                                                </thead>
                                                <xsl:for-each select="AdjustmentPoint">
                                                    <tbody>
                                                        <xsl:if test="@type='Free'">
                                                            <tr style="line-height:10%"><td colspan="8">&#xa0;</td></tr>
                                                            <tr>
                                                                <xsl:call-template name="displayPointName">
                                                                    <xsl:with-param name="name" select="@occupiedPointName"/>
                                                                    <xsl:with-param name="type" select="@type"/>
                                                                </xsl:call-template>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:northingFormat(number(@unadjustedNorthing), $xslNorthingPrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:eastingFormat(number(@unadjustedEasting), $xslEastingPrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@errorEllipseSx), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@errorEllipseSy), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@errorEllipseSu), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@errorEllipseSv), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@errorEllipset)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                    </tbody>
                                                </xsl:for-each>
                                            </table>
                                            <hr/>
                                        </xsl:for-each>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <p lang="en">
                                            A network least squares solution has not been obtained for the 
                                            active network.&#xa0; Blunder (error ellipse) reporting is 
                                            unavailable.
                                        </p>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:for-each select="RelativeEllipsePairs">
                                    <center><h4>Relative Ellipses</h4></center>
                                    <hr/>
                                    <table cellpadding="2" cellspacing="1" width="100%">
                                        <colgroup span="8">
                                            <col width="10%"/>
                                            <col width="15%"/>
                                            <col width="15%"/>
                                            <col width="12%"/>
                                            <col width="12%"/>
                                            <col width="12%"/>
                                            <col width="12%"/>
                                            <col width="12%"/>
                                        </colgroup>
                                        <thead style="display:table-header-group">
                                            <tr>
                                                <th class="underline" valign="bottom">Point Pair</th>
                                                <th class="underline" valign="bottom">Northing</th>
                                                <th class="underline" valign="bottom">Easting</th>
                                                <th class="underline" valign="bottom">Sx</th>
                                                <th class="underline" valign="bottom">Sy</th>
                                                <th class="underline" valign="bottom">Su</th>
                                                <th class="underline" valign="bottom">Sv</th>
                                                <th class="underline" valign="bottom">t</th>
                                            </tr>
                                        </thead>
                                        <xsl:for-each select="RelativeEllipsePair">
                                            <tbody>
                                                <tr style="line-height:10%"><td colspan="8">&#xa0;</td></tr>
                                                <tr>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="@relativeErrorEllipsePair"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:northingFormat(number(@relativeErrorEllipseNorthing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:eastingFormat(number(@relativeErrorEllipseEasting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(@relativeErrorEllipseSx), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(@relativeErrorEllipseSy), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(@relativeErrorEllipseSu), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:distanceFormat(number(@relativeErrorEllipseSv), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="center" nowrap="nowrap">
                                                        <xsl:value-of select="inr:angularFormat(number(@relativeErrorEllipset)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </xsl:for-each>
                                    </table>
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="displayPointName">
        <xsl:param name="name"/>
        <xsl:param name="type" select="'Fixed'"/>
        <th align="left" nowrap="nowrap">
            <xsl:choose>
                <xsl:when test="$type='Fixed'">
                    <img src="{$xslRootDirectory}/Images/SrvFixed.png" alt="Fixed"/>&#xa0;
                </xsl:when>
                <xsl:when test="$type='Free'">
                    <img src="{$xslRootDirectory}/Images/SrvFree.png" alt="Free"/>&#xa0;
                </xsl:when>
                <xsl:otherwise>
                    <img src="{$xslRootDirectory}/Images/SrvAzimuth.png" alt="Azimuth"/>&#xa0;
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="$name"/>
        </th>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have a survey network and you must also have run the <em>Survey &gt; Network &gt; 
                Least Squares Adjustment</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
