<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Feature Table Report from XIN -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Feature Table Report from XIN</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="CivilIni">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Feature Table Report from XIN</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <hr/>
                            <xsl:for-each select="FeatureStyleCollection">
                                <table class="margin" cellspacing="2" width="90%">
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" lang="en" valign="bottom">Feature Description</th>
                                            <th class="underline" lang="en" valign="bottom">Alpha<br/>Code</th>
                                            <th class="underline" lang="en" valign="bottom">Numeric<br/>Code</th>
                                            <th class="underline" lang="en" valign="bottom">Point Type</th>
                                            <th class="underline" lang="en" valign="bottom">Style</th>
                                        </tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="FeatureStyle[SurveyFeature]">
                                            <xsl:sort data-type="text" select="@Description"/>
                                            <tr>
                                                <td class="sidepad" valign="top"><xsl:value-of select="@Description"/></td>
                                                <td class="sidepad" valign="top">
                                                    <xsl:for-each select="SurveyFeature/AlphaCode">
                                                        <xsl:value-of select="@Code"/><br/>
                                                    </xsl:for-each>
                                                </td>
                                                <td class="sidepad" valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurveyFeature/@NumericCode">
                                                            <xsl:value-of select="SurveyFeature/@NumericCode"/>
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            [NONE]
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                </td>
                                                <td class="sidepad" valign="top">
                                                    <xsl:choose>
                                                        <xsl:when test="SurveyFeature/@FeatureType = '0'">
                                                            Random
                                                        </xsl:when>
                                                        <xsl:when test="SurveyFeature/@FeatureType = '1'">
                                                            Breakline
                                                        </xsl:when>
                                                        <xsl:when test="SurveyFeature/@FeatureType = '2'">
                                                            Contour
                                                        </xsl:when>
                                                        <xsl:when test="SurveyFeature/@FeatureType = '3'">
                                                            Interior
                                                        </xsl:when>
                                                        <xsl:when test="SurveyFeature/@FeatureType = '4'">
                                                            Exterior
                                                        </xsl:when>
                                                        <xsl:otherwise>
                                                            unknown
                                                        </xsl:otherwise>
                                                    </xsl:choose>
                                                    <xsl:if test="SurveyFeature/@ExcludeFromTriangulation = '1'"> - Do Not Triangulate</xsl:if>
                                                </td>
                                                <td class="sidepad" valign="top"><xsl:value-of select="@ItemName"/></td>
                                            </tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must open a Preferences file by selecting <em>File &gt; Open</em> on the <em>Report 
                Browser</em> menu and setting the <em>Files of type</em> field to <em>Preferences 
                (*.xin)</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
