<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- List Coordinates Report -->
    <xsl:output method="text" media-type="text/plain" encoding="iso-8859-1"/>
    <xsl:template match="/">
    	  <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <xsl:choose>
            <xsl:when test="$xslShowHelp = 'true'">
                <xsl:call-template name="StyleSheetHelp"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:for-each select="InRoads">
                    <!-- Project Data -->
                    <xsl:for-each select="SurveyFieldbook">
                        <xsl:if test="@surveyLinearUnits= 'Metric'">
                            <xsl:text>Linear Units                     =               Meters&#xd;</xsl:text>
                        </xsl:if>
                        <xsl:if test="@surveyLinearUnits= 'International Feet'">
                            <xsl:text>Linear Units                     =            Intl Feet&#xd;</xsl:text>
                        </xsl:if>
                        <xsl:if test="@surveyLinearUnits= 'US Feet'">
                            <xsl:text>Linear Units                     =              US Feet&#xd;</xsl:text>
                        </xsl:if>
                        <xsl:choose>
                            <xsl:when test="$xslAngularMethod = $ANGULAR_METHOD_GRADS">
                                <xsl:text>Angular Units                    =             Gradians&#xd;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:choose>
                                    <xsl:when test="$xslAngularMethod = $ANGULAR_METHOD_RADIANS">
                                        <xsl:text>Angular Units                    =              Radians&#xd;</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>Angular Units                    =              Degrees&#xd;</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="$xslDirectionModeFormat = $DIRECTION_MODE_SOUTH_AZIMUTH">
                                <xsl:text>Direction Units                  =        South Azimuth&#xd;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>Direction Units                  =        North Azimuth&#xd;</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="$xslFaceModeFormat = $FACE_MODE_RIGHT_FACE">
                                <xsl:text>Horz. Obs. Units                 =           Right Face&#xd;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:text>Horz. Obs. Units                 =            Left Face&#xd;</xsl:text>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="$xslVerticalObservationModeFormat = $VERTICAL_OBSERVATION_MODE_ZENITH">
                                <xsl:text>Vert. Obs. Units                 =               Zenith&#xd;</xsl:text>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:choose>
                                    <xsl:when test="$xslVerticalObservationModeFormat = $VERTICAL_OBSERVATION_MODE_HORIZONTAL">
                                        <xsl:text>Vert. Obs. Units                 =              Horizon&#xd;</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>Vert. Obs. Units                 =          Horizon +/-&#xd;</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:text>Slope Distance Scale             =</xsl:text><xsl:value-of select="inr:columnFormat(string(@slopeDistanceScale),21)"/><xsl:text>&#xd;</xsl:text>
                        <xsl:text>&#xd;</xsl:text>
                        <xsl:for-each select="SurveyStation">
                            <xsl:text>STN     </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(@name), 15 )"/><xsl:text>&#xd;</xsl:text>
                            <xsl:if test="@instrumentHeight">
                                <xsl:text>HI      </xsl:text>
                            <xsl:value-of select="inr:columnFormat(string(@instrumentHeight), 15 )"/><xsl:text>&#xd;</xsl:text>
                            </xsl:if>
                            <xsl:if test="@backsightDirection">
                                <xsl:choose>
                                    <xsl:when test="@backsightPoint">
                                        <xsl:text>BKB     </xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(@backsightPoint), 15)"/><xsl:text> </xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@backsightDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 17)"/><xsl:text> </xsl:text>
                                        <xsl:if test="@horizontalAngle">
                                            <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@horizontalAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 17)"/>
                                        </xsl:if>
                                        <xsl:text>&#xd;</xsl:text>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>BKA     </xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(inr:directionFormat(number(@backsightDirection), $xslDirectionFormat, $xslDirectionPrecision, $xslDirectionModeFormat, $xslAngularMethod)), 15)"/>
                                        <xsl:text>&#xd;</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:if>
                            <xsl:if test="@isValidPoint = 'true' or @isValidPoint != 0">
                                <xsl:if test="//@showCoordinates='true' or //@showCoordinates != 0 or @type=0">
                                    <xsl:if test="@northing or @easting or @elevation">
                                        <xsl:choose>
                                            <xsl:when test="@type=0">
                                                <xsl:text>FCRD    </xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:text>CCRD    </xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="inr:columnFormat(string(' '), 16)"/>
                                        <xsl:text> N:</xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(inr:northingFormat(number(@northing), $xslNorthingPrecision)),14)"/><xsl:text> </xsl:text>
                                        <xsl:text> E:</xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(inr:eastingFormat(number(@easting), $xslEastingPrecision)),14)"/><xsl:text> </xsl:text>
                                        <xsl:text> Z:</xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(inr:elevationFormat(number(@elevation), $xslElevationPrecision)),14)"/><xsl:text>&#xd;</xsl:text>
                                    </xsl:if>
                                </xsl:if>
                                <xsl:if test="@code">
                                    <xsl:text>CODE    </xsl:text>
                                    <xsl:value-of select="@code"/>
                                    <xsl:text>&#xd;</xsl:text>
                                </xsl:if>
                                <xsl:for-each select="Notes">
                                    <xsl:text>NOTES   </xsl:text>
                                    <xsl:value-of select="@note"/>
                                    <xsl:text>&#xd;</xsl:text>
                                </xsl:for-each>
                                <xsl:for-each select="SurveyAttribute">
                                    <xsl:text>ATTR    </xsl:text>
                                    <xsl:value-of select="inr:columnFormat(string(@name), 15)"/><xsl:text> </xsl:text>
                                    <xsl:value-of select="@value"/>
                                    <xsl:text>&#xd;</xsl:text>
                                </xsl:for-each>
                                <xsl:if test="@adjusted">
                                    <xsl:text>NOTE:   This is an Adjusted Record&#xd;</xsl:text>
                                </xsl:if>
                                <xsl:if test="@edited">
                                    <xsl:text>NOTE:   This is an Edited Record&#xd;</xsl:text>
                                </xsl:if>
                                <xsl:if test="@inserted">
                                    <xsl:text>NOTE:   This is an Inserted Record&#xd;</xsl:text>
                                </xsl:if>
                            </xsl:if>
                            <xsl:text>&#xd;</xsl:text>
                            <xsl:for-each select="SurveyObservation">
                                <xsl:choose>
                                    <xsl:when test="@horizontalObservation or @verticalObservation or @slopeDistance">
                                        <xsl:choose>
                                            <xsl:when test="@verticalObservation &lt;=3.14159265358979323846">
                                                <xsl:text>OBS  F1 </xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:text>OBS  F2 </xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="inr:columnFormat(string(@name), 15 )"/><xsl:text> </xsl:text>
                                        <xsl:text> H:</xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="@horizontalObservation ">
                                                <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(inr:faceFormat(number(@horizontalObservation), $xslFaceModeFormat)), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 14)"/><xsl:text> </xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:columnFormat(string(' '), 14)"/><xsl:text> </xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:text> V:</xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="@verticalObservation">
                                                <xsl:value-of select="inr:columnFormat(string(inr:angularFormat(number(inr:verticalObservationFormat(number(@verticalObservation), $xslVerticalObservationModeFormat)), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)), 14)"/><xsl:text> </xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:columnFormat(string(' '), 14)"/><xsl:text> </xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:text> D:</xsl:text>
                                        <xsl:choose>
                                            <xsl:when test="@slopeDistance">
                                                <xsl:value-of select="inr:columnFormat(string(inr:distanceFormat(number(@slopeDistance), $xslDistancePrecision)), 14)"/><xsl:text>&#xd;</xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="inr:columnFormat(string(' '), 14)"/><xsl:text> </xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:choose>
                                            <xsl:when test="@type = '0'">
                                                <xsl:text>POS     </xsl:text>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:text>OBS    </xsl:text>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="inr:columnFormat(string(@name), 15)"/><xsl:text>&#xd;</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:if test="@targetHeight">
                                    <xsl:text>TH      </xsl:text>
                                    <xsl:value-of select="inr:columnFormat(string(inr:distanceFormat(number(@targetHeight), $xslDistancePrecision)), 15)"/><xsl:text>&#xd;</xsl:text>
                                </xsl:if>
                                <xsl:if test="@isValidPoint = 'true' or @isValidPoint != 0">
                                    <xsl:if test="//@showCoordinates='true' or //@showCoordinates != 0 or @type=0">
                                        <xsl:if test="@northing or @easting or @elevation">
                                            <xsl:choose>
                                                <xsl:when test="@type=0">
                                                    <xsl:text>FCRD    </xsl:text>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:text>CCRD    </xsl:text>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <xsl:value-of select="inr:columnFormat(string(' '), 16)"/>
                                            <xsl:text> N:</xsl:text>
                                            <xsl:value-of select="inr:columnFormat(string(inr:northingFormat(number(@northing), $xslNorthingPrecision)),14)"/><xsl:text> </xsl:text>
                                            <xsl:text> E:</xsl:text>
                                            <xsl:value-of select="inr:columnFormat(string(inr:eastingFormat(number(@easting), $xslEastingPrecision)),14)"/><xsl:text> </xsl:text>
                                            <xsl:text> Z:</xsl:text>
                                            <xsl:value-of select="inr:columnFormat(string(inr:elevationFormat(number(@elevation), $xslElevationPrecision)),14)"/><xsl:text>&#xd;</xsl:text>
                                        </xsl:if>
                                    </xsl:if>
                                    <xsl:if test="@code">
                                        <xsl:text>CODE    </xsl:text>
                                        <xsl:value-of select="@code"/>
                                        <xsl:text>&#xd;</xsl:text>
                                    </xsl:if>
                                    <xsl:for-each select="Notes">
                                        <xsl:text>NOTES   </xsl:text>
                                        <xsl:value-of select="@note"/>
                                        <xsl:text>&#xd;</xsl:text>
                                    </xsl:for-each>
                                    <xsl:for-each select="SurveyAttribute">
                                        <xsl:text>ATTR    </xsl:text>
                                        <xsl:value-of select="inr:columnFormat(string(@name), 15)"/><xsl:text> </xsl:text>
                                        <xsl:value-of select="@value"/>
                                        <xsl:text>&#xd;</xsl:text>
                                    </xsl:for-each>
                                    <xsl:if test="@adjusted">
                                        <xsl:text>NOTE:   This is an Adjusted Record&#xd;</xsl:text>
                                    </xsl:if>
                                    <xsl:if test="@edited">
                                        <xsl:text>NOTE:   This is an Edited Record&#xd;</xsl:text>
                                    </xsl:if>
                                    <xsl:if test="@inserted">
                                        <xsl:text>NOTE:   This is an Inserted Record&#xd;</xsl:text>
                                    </xsl:if>
                                </xsl:if>
                                <xsl:text>&#xd;</xsl:text>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:for-each>
                </xsl:for-each>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <xsl:text>Notes&#xd;&#xd;</xsl:text>
        <xsl:text>    You must select at least one fieldbook in the Survey &gt;&#xd;</xsl:text>
        <xsl:text>    XML Report command to get results from this report.&#xd;&#xd;</xsl:text>
        <xsl:text>    Your fieldbook must contain data for a complete report.&#xd;&#xd;</xsl:text>
        <xsl:text>Copyright 2006 Bentley Systems, Inc&#xd;</xsl:text>
    </xsl:template>
</xsl:stylesheet>
