<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!--Survey Notes Report-->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title>Survey Notes Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!-- Report Title -->
                                <h2 lang="en">Survey Notes Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!-- Project Data -->
                            <xsl:for-each select="SurveyFieldbook">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Fieldbook:&#xa0; </th>
                                            <td colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:choose>
                                                    <xsl:when test="//@surveyLinearUnits = 'Metric'">meters</xsl:when>
                                                    <xsl:otherwise>feet</xsl:otherwise>
                                                </xsl:choose>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr/>
                                <!-- Survey Point Data -->
                                <table class="margin" cellpadding="2" cellspacing="2" width="75%">
                                    <colgroup span="3">
                                        <col width="18%"/>
                                        <col width="18%"/>
                                        <col width="64%"/>
                                    </colgroup>
                                    <thead style="display:table-header-group">
                                        <tr>
                                            <th class="underline" lang="en" valign="bottom">Point<br/>Name</th>
                                            <th class="underline" lang="en" valign="bottom">Status</th>
                                            <th class="underline" lang="en" valign="bottom">Notes</th>
                                        </tr>
                                        <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                    </thead>
                                    <tbody>
                                        <xsl:for-each select="SurveyStation[SurveyObservation/Notes]">
                                            <tr>
                                                <th align="left" colspan="3" lang="en" valign="top">
                                                    Station Name:&#xa0; <xsl:value-of select="@name"/><br/>&#xa0;
                                                </th>
                                            </tr>
                                            <xsl:for-each select="SurveyObservation[Notes]">
                                                <tr>
                                                    <td class="sidepad" valign="top"><xsl:value-of select="@name"/></td>
                                                    <td class="sidepad" valign="top">
                                                        <xsl:choose>
                                                            <xsl:when test="@type = '0'">Fixed</xsl:when>
                                                            <xsl:otherwise>Computed</xsl:otherwise>
                                                        </xsl:choose>
                                                    </td>
                                                    <td class="sidepad" valign="top">
                                                        <xsl:for-each select="Notes">
                                                            <xsl:value-of select="@note"/><br/>
                                                        </xsl:for-each>
                                                    </td>
                                                </tr>
                                            </xsl:for-each>
                                            <tr><td>&#xa0;</td></tr>
                                        </xsl:for-each>
                                    </tbody>
                                </table>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must select at least one fieldbook in the <em>Survey &gt; XML Report</em> command to 
                get results from this report.
            </p>
            <p class="normal1" lang="en">
                Your fieldbook must contain data with at least one Note for a complete report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
