<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!-- Adjustment Report -->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))"/>
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!-- Title displayed in browser Title Bar -->
                <title lang="en">Traverse Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <xsl:for-each select="AdjustmentNet">
                                <center>
                                    <!-- Report Title -->
                                    <h2 lang="en">Traverse Report</h2>
                                    <p lang="en">
                                        Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br/>
                                        Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                    </p>
                                </center>
                                <p lang="en" style="text-align:right;font-size:80%">
                                    <strong>Note:&#xa0; </strong>All units in this report are in 
                                    <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                    <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                    unless specified otherwise.
                                </p>
                                <hr/>
                                <xsl:choose>
                                    <xsl:when test="@isRoute = 'true'">
                                        <center><h4 lang="en">Overview</h4></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="1" cellspacing="1" width="70%">
                                            <colgroup span="2">
                                                <col width="50%"/>
                                                <col width="50%"/>
                                            </colgroup>
                                            <tbody>
                                                <tr>
                                                    <th align="left" lang="en">Traverse Points:</th>
                                                    <td>
                                                        <xsl:value-of select="(@numberFreePoints+@numberFixedPoints)"/> Total, 
                                                        <xsl:value-of select="@numberFixedPoints"/> Fixed, 
                                                        <xsl:value-of select="@numberFreePoints"/> Free
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Traverse Classification:</th>
                                                    <td><xsl:value-of select="@closureType"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Traverse Adjustments:</th>
                                                    <td lang="en">
                                                        <xsl:if test="//@reciprocalZenith='true'">Reciprocal Zenith</xsl:if>
                                                        <xsl:if test="//@horizontalZenith='true'">
                                                            <xsl:choose>
                                                                <xsl:when test="//@reciprocalZenith='true'">
                                                                     , Horizontal Angle
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    Horizontal Angle
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:if>
                                                        <xsl:if test="@elevationAdjustment = 'true'">
                                                            <xsl:choose>
                                                                <xsl:when test="//@reciprocalZenith = 'true' or //@horizontalZenith = 'true'">
                                                                     , Elevation Adjustment
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    Elevation Adjustment
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:if>
                                                        <xsl:if test="//@traverseAdjustment = 'true'">
                                                            <xsl:choose>
                                                                <xsl:when test="//@reciprocalZenith = 'true' or //@horizontalZenith = 'true' or @elevationAdjustment = 'true'">
                                                                     , <xsl:value-of select="@adjustmentType"/>
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    <xsl:value-of select="@adjustmentType"/>
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:if>
                                                        <xsl:if test="@verticalPosition = '1'">
                                                            <xsl:choose>
                                                                <xsl:when test="//@reciprocalZenith = 'true' or //@horizontalZenith = 'true' or //@traverseAdjustment = 'true'">
                                                                     , Vertical Position
                                                                </xsl:when>
                                                                <xsl:otherwise>
                                                                    Vertical Position
                                                                </xsl:otherwise>
                                                            </xsl:choose>
                                                        </xsl:if>
                                                        <xsl:if test="//@reciprocalZenith = '0' and //@horizontalZenith = '0' and //@traverseAdjustment = '0'">
                                                            None
                                                        </xsl:if>
                                                    </td>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en">Horizontal Angle Control:</th>
                                                    <td lang="en">
                                                        <xsl:choose>
                                                            <xsl:when test="@horizontalAngleControl = 'true'">Yes</xsl:when>
                                                            <xsl:otherwise>No</xsl:otherwise>
                                                        </xsl:choose>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en" nowrap="nowrap">Horizontal Position Control:</th>
                                                    <td lang="en">
                                                        <xsl:choose>
                                                            <xsl:when test="@horizontalPositionControl = 'true'">Yes</xsl:when>
                                                            <xsl:otherwise>No</xsl:otherwise>
                                                        </xsl:choose>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Vertical Position Control:</th>
                                                    <td lang="en">
                                                        <xsl:choose>
                                                            <xsl:when test="@verticalAngleControl = 'true'">Yes</xsl:when>
                                                            <xsl:otherwise>No</xsl:otherwise>
                                                        </xsl:choose>
                                                    </td>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                            </tbody>
                                        </table>
                                        <hr size="1px"/>
                                        <!-- Traverse Data -->
                                        <center><h4 lang="en">Traverse</h4></center>
                                        <hr size="1px"/>
                                        <xsl:if test="@areaDefined != 'false'">
                                            <table class="margin" cellpadding="1" cellspacing="1" width="70%">
                                                <colgroup span="2">
                                                    <col width="50%"/>
                                                    <col width="50%"/>
                                                </colgroup>
                                                <tbody>
                                                    <tr><td>&#xa0;</td></tr>
                                                    <tr>
                                                        <th align="left" lang="en" nowrap="nowrap">Unadjusted Area:</th>
                                                        <td lang="en">
                                                            <xsl:value-of select="inr:areaFormat(number(@area), $xslAreaPrecision)"/> (Sq 
                                                            <xsl:value-of select="//@linearUnits"/>)
                                                        </td>
                                                    </tr>
                                                    <tr>
                                                        <th align="left" lang="en">Adjusted Area:</th>
                                                        <td lang="en">
                                                            <xsl:choose>
                                                                <xsl:when test="@adjustedAreaDefined = 'true'">
                                                                    <xsl:value-of select="inr:areaFormat(number(@adjustedArea), $xslAreaPrecision)"/> (Sq 
                                                                    <xsl:value-of select="//@linearUnits"/>)
                                                                </xsl:when>
                                                                <xsl:otherwise/>
                                                            </xsl:choose>
                                                        </td>
                                                    </tr>
                                                    <tr><td>&#xa0;</td></tr>
                                                </tbody>
                                            </table>
                                        </xsl:if>
                                        <table border="1" class="margin" cellpadding="2" cellspacing="0" style="border-right-width:0px;border-left-width:0px;border-bottom-width:0px" width="95%">
                                            <thead>
                                                <tr>
                                                    <th lang="en" style="border-left-width:2px">Point</th>
                                                    <th lang="en">Azimuth</th>
                                                    <th lang="en">Length</th>
                                                    <th lang="en">Latitude</th>
                                                    <th lang="en">Departure</th>
                                                    <th lang="en">Northing</th>
                                                    <th lang="en">Easting</th>
                                                    <th lang="en" style="border-right-width:2px">Elevation</th>
                                                </tr>
                                                <tr/>
                                            </thead>
                                            <xsl:for-each select="Route/RoutePoint">
                                                <tbody>
                                                    <xsl:call-template name="displayBacksight"/>
                                                    <xsl:call-template name="displayTraverse">
                                                        <xsl:with-param name="traverseAdjustment" select="//@traverseAdjustment"/>
                                                        <xsl:with-param name="horizontalZenith" select="//@horizontalZenith"/>
                                                        <xsl:with-param name="reciprocalZenith" select="//@reciprocalZenith"/>
                                                    </xsl:call-template>
                                                    <xsl:call-template name="displayForesight"/>
                                                    <xsl:if test="position() = last()">
                                                        <xsl:call-template name="displayTraverseTotal">
                                                            <xsl:with-param name="traverseAdjustment" select="//@traverseAdjustment"/>
                                                            <xsl:with-param name="horizontalZenith" select="//@horizontalZenith"/>
                                                            <xsl:with-param name="reciprocalZenith" select="//@reciprocalZenith"/>
                                                        </xsl:call-template>
                                                    </xsl:if>
                                                </tbody>
                                            </xsl:for-each>
                                        </table>
                                        <br/>
                                        <hr size="1px"/>
                                        <!-- Error Anaysis Data -->
                                        <center><h4 lang="en">Error Analysis</h4></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="1" cellspacing="2" width="95%">
                                            <tbody>
                                                <!-- End Azimuth -->
                                                <tr><th align="left" colspan="7" lang="en">End Azimuth:</th></tr>
                                                <tr>
                                                    <th class="underline" colspan="2">&#xa0;</th>
                                                    <th class="underline" lang="en">Error</th>
                                                    <th class="underline" lang="en">Error Per Angle</th>
                                                    <th colspan="3">&#xa0;</th>
                                                </tr>
                                                <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <td lang="en">Fixed</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:angularFormat(number(@fixedEndAzimuth)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                    </td>
                                                    <td align="right">---</td>
                                                    <td align="right">---</td>
                                                    <td colspan="3">&#xa0;</td>
                                                </tr>
                                                <tr>
                                                    <td align="left" lang="en" nowrap="nowrap">Computed Original</td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:angularFormat(number(@computedOriginalEndAzimuth)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                    </td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:angularFormat(number(@differenceAzimuth)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                    </td>
                                                    <td align="right" nowrap="nowrap">
                                                        <xsl:value-of select="inr:angularFormat(number(@computedErrorPerAngle)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                    </td>
                                                    <td colspan="3">&#xa0;</td>
                                                </tr>
                                                <tr><td colspan="7">&#xa0;</td></tr>
                                                <!-- End Position -->
                                                <tr><th align="left" colspan="7" lang="en">End Position:</th></tr>
                                                <tr>
                                                    <th class="underline">&#xa0;</th>
                                                    <th class="underline" lang="en">Northing</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                    <th class="underline" lang="en">Easting</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                    <th class="underline" lang="en">Elevation</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                </tr>
                                                <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <td lang="en">Fixed</td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(@endPointNorthing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td align="right">---</td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(@endPointEasting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td align="right">---</td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@endPointElevation), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td align="right">---</td>
                                                </tr>
                                                <tr>
                                                    <td lang="en">Computed Original</td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(@endPointComputedNorthing), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:northingFormat(number(@endPointComputedNorthingDifference), $xslNorthingPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(@endPointComputedEasting), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:eastingFormat(number(@endPointComputedEastingDifference), $xslEastingPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@endPointComputedElevation), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@endPointComputedElevationDifference), $xslElevationPrecision)"/>
                                                    </td>
                                                </tr>
                                                <xsl:if test="//@reciprocalZenith = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Reciprocal</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@reciprocalEndPointComputedNorthing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@reciprocalEndPointComputedNorthingDifference), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@reciprocalEndPointComputedEasting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@reciprocalEndPointComputedEastingDifference), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@reciprocalEndPointComputedElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@reciprocalEndPointComputedElevationDifference), $xslElevationPrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="//@horizontalZenith = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Horizontal</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@horizontalEndPointComputedNorthing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@horizontalEndPointComputedNorthingDifference), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@horizontalEndPointComputedEasting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@horizontalEndPointComputedEastingDifference), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@horizontalEndPointComputedElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@horizontalEndPointComputedElevationDifference), $xslElevationPrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="//@traverseAdjustment = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Traverse</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@traverseEndPointComputedNorthing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@traverseEndPointComputedNorthingDifference), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@traverseEndPointComputedEasting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@traverseEndPointComputedEastingDifference), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@traverseEndPointComputedElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@traverseEndPointComputedElevationDifference), $xslElevationPrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="//@elevationAdjustment = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Elevation</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@elevationEndPointComputedNorthing), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:northingFormat(number(@elevationEndPointComputedNorthingDifference), $xslNorthingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@elevationEndPointComputedEasting), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:eastingFormat(number(@elevationEndPointComputedEastingDifference), $xslEastingPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevationEndPointComputedElevation), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevationEndPointComputedElevationDifference), $xslElevationPrecision)"/>
                                                        </td>
                                                    </tr>
                                                </xsl:if>
                                                <tr><td colspan="7">&#xa0;</td></tr>
                                                <!-- Horizontal/Vertical Error -->
                                                <tr>
                                                    <th align="left" colspan="7" lang="en" nowrap="nowrap">Horizontal / Vertical Error:</th>
                                                </tr>
                                                <tr>
                                                    <th class="underline">&#xa0;</th>
                                                    <th class="underline" lang="en">Horizontal<br/>Error</th>
                                                    <th class="underline" lang="en">Vertical<br/>Error</th>
                                                    <th colspan="4">&#xa0;</th>
                                                </tr>
                                                <tr style="line-height:20%"><td colspan="7">&#xa0;</td></tr>
                                                <tr>
                                                    <td lang="en" nowrap="nowrap">Computed Original</td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:distanceFormat(number(@computedHorizontalError), $xslDistancePrecision)"/>
                                                    </td>
                                                    <td align="right">
                                                        <xsl:value-of select="inr:elevationFormat(number(@computedVerticalError), $xslElevationPrecision)"/>
                                                    </td>
                                                    <td colspan="4">&#xa0;</td>
                                                </tr>
                                                <xsl:if test="//@reciprocalZenith = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Reciprocal</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@reciprocalHorizontalError), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@reciprocalVerticalError), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td colspan="4">&#xa0;</td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="//@horizontalZenith = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Horizontal</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@horizontalHorizontalError), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@horizontalVerticalError), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td colspan="4">&#xa0;</td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="//@traverseAdjustment = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Traverse</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@traverseHorizontalError), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@traverseVerticalError), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td colspan="4">&#xa0;</td>
                                                    </tr>
                                                </xsl:if>
                                                <xsl:if test="//@elevationAdjustment = 'true'">
                                                    <tr>
                                                        <td lang="en" nowrap="nowrap">Computed Elevation</td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:distanceFormat(number(@elevationHorizontalError), $xslDistancePrecision)"/>
                                                        </td>
                                                        <td align="right">
                                                            <xsl:value-of select="inr:elevationFormat(number(@elevationVerticalError), $xslElevationPrecision)"/>
                                                        </td>
                                                        <td colspan="4">&#xa0;</td>
                                                    </tr>
                                                </xsl:if>
                                                <tr><td colspan="7">&#xa0;</td></tr>
                                            </tbody>
                                        </table>
                                        <table class="margin" cellpadding="2" cellspacing="0" width="70%">
                                            <colgroup span="2">
                                                <col width="50%"/>
                                                <col width="50%"/>
                                            </colgroup>
                                            <tbody>
                                                <!-- Horizontal/Vertical Accuracy -->
                                                <tr>
                                                    <th align="left" lang="en">Horizontal Accuracy (Original): </th>
                                                    <td>1 : <xsl:value-of select="@computedHorizontalAccuracy"/></td>
                                                </tr>
                                    					<tr>
                                                    <th align="left" lang="en" nowrap="nowrap">Horizontal Accuracy (with Angular): </th>
                                                    <td>1 : <xsl:value-of select="@horizontalHorizontalAccuracy"/></td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Vertical Accuracy (Original): </th>
                                                    <td>1 : <xsl:value-of select="@computedVerticalAccuracy"/></td>
                                                </tr>
                                            </tbody>
                                        </table>
                                        <br/>
                                        <hr size="1px"/>
                                        <!-- Observation Data -->
                                        <center><h4 lang="en">Observations</h4></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="1" cellspacing="1" width="70%">
                                            <colgroup span="2">
                                                <col width="50%"/>
                                                <col width="50%"/>
                                            </colgroup>
                                            <tbody>
                                                <tr>
                                                    <th align="left" lang="en">Azimuths:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberAzimuthObservations"/>
                                                        <xsl:if test="@numberAzimuthObservationsIgnored!='0'"> (<xsl:value-of select="@numberAzimuthObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Direction:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberDirectionObservations"/>
                                                        <xsl:if test="@numberDirectionObservationsIgnored!='0'"> (<xsl:value-of select="@numberDirectionObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Horizontal Angles:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberHorizontalAngleObservations"/>
                                                        <xsl:if test="@numberHorizontalAngleObservationsIgnored!='0'"> (<xsl:value-of select="@numberHorizontalAngleObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en" nowrap="nowrap">Horizontal Distances:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberHorizontalDistanceObservations"/>
                                                        <xsl:if test="@numberHorizontalDistanceObservationsIgnored!='0'"> (<xsl:value-of select="@numberHorizontalDistanceObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Slope Distances:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberSlopeDistanceObservations"/>
                                                        <xsl:if test="@numberSlopeDistanceObservationsIgnored!='0'"> (<xsl:value-of select="@numberSlopeDistanceObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en">Vertical Angles:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberVerticalAngleObservations"/>
                                                        <xsl:if test="@numberVerticalAngleObservationsIgnored!='0'"> (<xsl:value-of select="@numberVerticalAngleObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr>
                                                    <th align="left" lang="en">Zenith Angles:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberZenithAngleObservations"/>
                                                        <xsl:if test="@numberZenithAngleObservationsIgnored!='0'"> (<xsl:value-of select="@numberZenithAngleObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en">Height Differences:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@numberHeightDifferenceObservations"/>
                                                        <xsl:if test="@numberHeightDifferenceObservationsIgnored!='0'"> (<xsl:value-of select="@numberHeightDifferenceObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                <tr>
                                                    <th align="left" lang="en">Total:&#xa0;</th>
                                                    <td>
                                                        <xsl:value-of select="@totalNumberObservations"/>
                                                        <xsl:if test="@totalNumberObservationsIgnored!='0'"> (<xsl:value-of select="@totalNumberObservationsIgnored"/>)</xsl:if>
                                                    </td>
                                                </tr>
                                                <tr><td>&#xa0;</td></tr>
                                            </tbody>
                                        </table>
                                        <hr size="1px"/>
                                        <!-- Observation Points -->
                                        <table cellpadding="1" cellspacing="2" width="100%">
                                            <colgroup span="8">
                                                <col width="14%"/>
                                                <col width="12%"/>
                                                <col width="12%"/>
                                                <col width="12%"/>
                                                <col width="12%"/>
                                                <col width="13%"/>
                                                <col width="13%"/>
                                                <col width="12%"/>
                                            </colgroup>
                                            <thead style="display:table-header-group">
                                                <tr>
                                                    <th class="underline" lang="en">Type</th>
                                                    <th class="underline" lang="en">Backsight</th>
                                                    <th class="underline" lang="en">Occupied</th>
                                                    <th class="underline" lang="en">Foresight</th>
                                                    <th class="underline" lang="en">Observation</th>
                                                    <th class="underline">&#xa0;</th>
                                                    <th class="underline" lang="en">Observation</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                </tr>
                                                <tr style="line-height:20%"><td colspan="8">&#xa0;</td></tr>
                                            </thead>
                                            <tbody>
                                                <xsl:for-each select="Observations/Observation">
                                                    <tr valign="top">
                                                        <td align="center"><xsl:value-of select="@type"/></td>
                                                        <th><xsl:value-of select="@backsightPointName"/></th>
                                                        <th><xsl:value-of select="@occupiedPointName"/></th>
                                                        <th><xsl:value-of select="@foresightPointName"/></th>
                                                        <xsl:choose>
                                                            <xsl:when test="@type != 'Slope Distance' and @type != 'Horizontal Distance' and @type != 'Height Difference'">
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@averageObservedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                            </xsl:when>
                                                            <xsl:otherwise>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@averageObservedValue), $xslDistancePrecision)"/>
                                                                </td>
                                                            </xsl:otherwise>
                                                        </xsl:choose>
                                                        <xsl:if test="//@reciprocalZenith = 'true' or //@horizontalZenith = 'true' or //@traverseAdjustment = 'true' or //@elevationAdjustment = 'true'">
                                                            <xsl:if test="//@reciprocalZenith = 'true'">
                                                                <td class="sidepad" lang="en">Reciprocal</td>
                                                                <xsl:choose>
                                                                    <xsl:when test="@type != 'Slope Distance' and @type != 'Horizontal Distance' and @type != 'Height Difference'">
                                                                        <td align="right" nowrap="nowrap">
                                                                            <xsl:value-of select="inr:angularFormat(number(@averageReciprocalZenith), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                        </td>
                                                                        <td align="right" nowrap="nowrap">
                                                                            <xsl:value-of select="inr:angularFormat(number(@differenceAverageReciprocalZenith), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                        </td>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <td align="right">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@averageReciprocalZenith), $xslDistancePrecision)"/>
                                                                        </td>
                                                                        <td align="right">
                                                                            <xsl:value-of select="inr:distanceFormat(number(@differenceAverageReciprocalZenith), $xslDistancePrecision)"/>
                                                                        </td>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </xsl:if>
                                                            <td colspan="3">
                                                                <table width="100%">
                                                                    <xsl:if test="//@horizontalZenith = 'true'">
                                                                        <tr>
                                                                            <td class="sidepad" lang="en">Horizontal</td>
                                                                            <xsl:choose>
                                                                                <xsl:when test="@type != 'Slope Distance' and @type != 'Horizontal Distance' and @type != 'Height Difference'">
                                                                                    <td align="right" nowrap="nowrap">
                                                                                        <xsl:value-of select="inr:angularFormat(number(@averageHorizontalZenith), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                                    </td>
                                                                                    <td align="right" nowrap="nowrap">
                                                                                        <xsl:value-of select="inr:angularFormat(number(@differenceAverageHorizontalValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                                    </td>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <td align="right">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@averageHorizontalZenith), $xslDistancePrecision)"/>
                                                                                    </td>
                                                                                    <td align="right">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@differenceAverageHorizontalValue), $xslDistancePrecision)"/>
                                                                                    </td>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </tr>
                                                                    </xsl:if>
                                                                    <xsl:if test="//@traverseAdjustment = 'true'">
                                                                        <tr>
                                                                            <td class="sidepad"><xsl:value-of select="//@adjustmentType"/></td>
                                                                            <xsl:choose>
                                                                                <xsl:when test="@type != 'Slope Distance' and @type != 'Horizontal Distance' and @type != 'Height Difference'">
                                                                                    <td align="right" nowrap="nowrap">
                                                                                        <xsl:value-of select="inr:angularFormat(number(@averageAdjustedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                                    </td>
                                                                                    <td align="right" nowrap="nowrap">
                                                                                        <xsl:value-of select="inr:angularFormat(number(@differenceAverageAdjustedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                                    </td>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <td align="right">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@averageAdjustedValue), $xslDistancePrecision)"/>
                                                                                    </td>
                                                                                    <td align="right">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@differenceAverageAdjustedValue), $xslDistancePrecision)"/>
                                                                                    </td>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </tr>
                                                                    </xsl:if>
                                                                    <xsl:if test="//@elevationAdjustment = 'true'">
                                                                        <tr>
                                                                            <td class="sidepad" lang="en">Elevation</td>
                                                                            <xsl:choose>
                                                                                <xsl:when test="@type != 'Slope Distance' and @type != 'Horizontal Distance' and @type != 'Height Difference'">
                                                                                    <td align="right" nowrap="nowrap">
                                                                                        <xsl:value-of select="inr:angularFormat(number(@averageElevationValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                                    </td>
                                                                                    <td align="right" nowrap="nowrap">
                                                                                        <xsl:value-of select="inr:angularFormat(number(@differenceAverageElevationValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                                    </td>
                                                                                </xsl:when>
                                                                                <xsl:otherwise>
                                                                                    <td align="right">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@averageElevationValue), $xslDistancePrecision)"/>
                                                                                    </td>
                                                                                    <td align="right">
                                                                                        <xsl:value-of select="inr:distanceFormat(number(@differenceAverageElevationValue), $xslDistancePrecision)"/>
                                                                                    </td>
                                                                                </xsl:otherwise>
                                                                            </xsl:choose>
                                                                        </tr>
                                                                    </xsl:if>
                                                                </table>
                                                            </td>
                                                        </xsl:if>
                                                    </tr>
                                                    <xsl:for-each select="ObservationData">
                                                        <tr>
                                                            <th>&#xa0;</th>
                                                            <td align="right">
                                                                <xsl:choose>
                                                                    <xsl:when test="@type = 'Horizontal Distance'">
                                                                        <xsl:value-of select="inr:distanceFormat(number(@backsightHeight), $xslDistancePrecision)"/>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>&#xa0;</xsl:otherwise>
                                                                </xsl:choose>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@instrumentHeight), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="right">
                                                                <xsl:value-of select="inr:distanceFormat(number(@foresightHeight), $xslDistancePrecision)"/>
                                                            </td>
                                                            <td align="right" nowrap="nowrap">
                                                                <xsl:choose>
                                                                    <xsl:when test="@type != 'Slope Distance' and @type != 'Horizontal Distance' and @type != 'Height Difference'">
                                                                        <xsl:value-of select="inr:angularFormat(number(@observedValue), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                    </xsl:when>
                                                                    <xsl:otherwise>
                                                                        <xsl:value-of select="inr:distanceFormat(number(@observedValue), $xslDistancePrecision)"/>
                                                                    </xsl:otherwise>
                                                                </xsl:choose>
                                                            </td>
                                                        </tr>
                                                    </xsl:for-each>
                                                    <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                </xsl:for-each>
                                                <tr><td>&#xa0;</td></tr>
                                            </tbody>
                                        </table>
                                        <hr size="1px"/>
                                        <!-- Reciprocal Zenith Data -->
                                        <xsl:if test="//@reciprocalZenith = 'true'">
                                            <center><h4 lang="en">Reciprocal Zenith</h4></center>
                                            <hr size="1px"/>
                                            <table class="margin" cellpadding="1" cellspacing="2" width="85%">
                                                <thead style="display:table-header-group">
                                                    <tr>
                                                        <th class="underline" valign="bottom">&#xa0;</th>
                                                        <th class="underline" lang="en" valign="bottom">Occupied</th>
                                                        <th class="underline" lang="en" valign="bottom">Observed</th>
                                                        <th class="underline" lang="en" valign="bottom">Slope<br/>Distance</th>
                                                        <th class="underline" lang="en" valign="bottom">Zenith Angle</th>
                                                        <th class="underline" lang="en" valign="bottom">Delta Z</th>
                                                    </tr>
                                                    <tr style="line-height:20%"><th>&#xa0;</th></tr>
                                                </thead>
                                                <tbody>
                                                    <xsl:for-each select="ReciprocalZeniths/ReciprocalZenith">
                                                        <xsl:if test="@isForward = 'true'">
                                                            <tr>
                                                                <td lang="en">Forward</td>
                                                                <th><xsl:value-of select="@reciprocalOccupiedPointName"/></th>
                                                                <th><xsl:value-of select="@reciprocalForesightPointName"/></th>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@forwardSlopeDistance), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@forwardZenithAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@forwardDeltaZ), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                            <tr>
                                                                <td lang="en" nowrap="nowrap">Reciprocal</td>
                                                                <th><xsl:value-of select="@reciprocalOccupiedPointName"/></th>
                                                                <th><xsl:value-of select="@reciprocalForesightPointName"/></th>
                                                                <td align="right">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@reciprocalSlopeDistance), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@reciprocalZenithAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                                <td align="right" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@reciprocalDeltaZ), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <xsl:if test="@isReverse = 'true'">
                                                            <tr>
                                                                <td nowrap="nowrap">Reverse</td>
                                                                <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                                    <xsl:value-of select="@reciprocalForesightPointName"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap" style="font-weight:bold">
                                                                    <xsl:value-of select="@reciprocalOccupiedPointName"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@reverseSlopeDistance), $xslDistancePrecision)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:angularFormat(number(@reverseZenithAngle), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                                                                </td>
                                                                <td align="center" nowrap="nowrap">
                                                                    <xsl:value-of select="inr:distanceFormat(number(@reverseDeltaZ), $xslDistancePrecision)"/>
                                                                </td>
                                                            </tr>
                                                        </xsl:if>
                                                        <tr style="line-height:50%"><td>&#xa0;</td></tr>
                                                    </xsl:for-each>
                                                    <tr><td>&#xa0;</td></tr>
                                                </tbody>
                                            </table>
                                            <hr size="1px"/>
                                        </xsl:if>
                                        <!-- Point Data -->
                                        <center><h4 lang="en">Points</h4></center>
                                        <hr size="1px"/>
                                        <table class="margin" cellpadding="1" cellspacing="2" width="90%">
                                            <colgroup span="7">
                                                <col width="10%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                                <col width="15%"/>
                                            </colgroup>
                                            <thead style="display:table-header-group">
                                                <tr>
                                                    <th class="underline">&#xa0;</th>
                                                    <th class="underline" lang="en">Northing</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                    <th class="underline" lang="en">Easting</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                    <th class="underline" lang="en">Elevation</th>
                                                    <th class="underline" lang="en">Difference</th>
                                                </tr>
                                                <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                            </thead>
                                            <tbody>
                                                <xsl:for-each select="Route/RoutePoint">
                                                    <xsl:if test="position() = 1">
                                                        <tr>
                                                            <xsl:call-template name="displayPointName">
                                                                <xsl:with-param name="name" select="@backsightPointName"/>
                                                                <xsl:with-param name="type" select="@backsightType"/>
                                                            </xsl:call-template>
                                                        </tr>
                                                        <xsl:call-template name="displayPointsBacksight"/>
                                                        <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                    </xsl:if>
                                                    <tr>
                                                        <xsl:call-template name="displayPointName">
                                                            <xsl:with-param name="name" select="@occupiedPointName"/>
                                                            <xsl:with-param name="type" select="@type"/>
                                                        </xsl:call-template>
                                                    </tr>
                                                    <xsl:call-template name="displayPoints">
                                                        <xsl:with-param name="traverseAdjustment" select="//@traverseAdjustment"/>
                                                        <xsl:with-param name="horizontalZenith" select="//@horizontalZenith"/>
                                                        <xsl:with-param name="reciprocalZenith" select="//@reciprocalZenith"/>
                                                    </xsl:call-template>
                                                    <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                    <xsl:if test="position() = last()">
                                                        <tr>
                                                            <xsl:call-template name="displayPointName">
                                                                <xsl:with-param name="name" select="@foresightPointName"/>
                                                                <xsl:with-param name="type" select="@foresightType"/>
                                                            </xsl:call-template>
                                                        </tr>
                                                        <xsl:call-template name="displayPointsForesight"/>
                                                    </xsl:if>
                                                    <tr style="line-height:20%"><td>&#xa0;</td></tr>
                                                </xsl:for-each>
                                                <tr><td>&#xa0;</td></tr>
                                            </tbody>
                                        </table>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <p lang="en">
                                            The active network is not a single route traverse.&#xa0; Please 
                                            use another report.
                                        </p>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!--Start Templates-->
    <xsl:template name="displayTraverse">
        <xsl:param name="traverseAdjustment"/>
        <xsl:param name="horizontalZenith"/>
        <xsl:param name="reciprocalZenith"/>
        <xsl:variable name="red" select="'FF0000'"/>
        <!-- Traverse Row 1 -->
        <tr>
            <xsl:call-template name="displayPointName">
                <xsl:with-param name="name" select="@occupiedPointName"/>
                <xsl:with-param name="type" select="@type"/>
                <xsl:with-param name="style" select="'border-left-width:2px'"/>
            </xsl:call-template>
            <xsl:call-template name="fourBlankColumns"/>
            <!-- Display Unadjusted Coordinates -->
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedNorthing"/>
                <xsl:with-param name="displayType" select="'northing'"/>
            </xsl:call-template>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedEasting"/>
                <xsl:with-param name="displayType" select="'easting'"/>
            </xsl:call-template>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedElevation"/>
                <xsl:with-param name="displayType" select="'elevation'"/>
                <xsl:with-param name="style" select="'border-right-width:2px'"/>
            </xsl:call-template>
        </tr>
        <!-- Traverse Row 2 -->
        <tr>
            <td style="border-left-width:2px">&#xa0;</td>
            <xsl:choose>
                <xsl:when test="@mode = 'BothFixed'">
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@unadjustedAzimuth"/>
                        <xsl:with-param name="displayType" select="'angular'"/>
                    </xsl:call-template>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@unadjustedAzimuth"/>
                        <xsl:with-param name="displayType" select="'angular'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@unadjustedLength"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@unadjustedLatitude"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@unadjustedDeparture"/>
                    </xsl:call-template>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:choose>
                <!-- Display Elevation Corrected Coordinates -->
                <xsl:when test="//@elevationAdjustment = 'true' and @type != 'Fixed'">
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@elevationCorrectionNorthing"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@elevationCorrectionEasting"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@elevationCorrectionElevation"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                        <xsl:with-param name="style" select="'border-right-width:2px'"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- Display Traverse Corrected Coordinates -->
                <xsl:when test="//@traverseAdjustment = 'true' and @type != 'Fixed'">
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@traverseCorrectionNorthing"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@traverseCorrectionEasting"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@traverseCorrectionElevation"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                        <xsl:with-param name="style" select="'border-right-width:2px'"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- Display Horizontal Corrected Coordinates -->
                <xsl:when test="//@horizontalZenith = 'true' and @type != 'Fixed'">
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@horizontalCorrectionNorthing"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@horizontalCorrectionEasting"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@horizontalCorrectionElevation"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                        <xsl:with-param name="style" select="'border-right-width:2px'"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- Display reciprocal Corrected Coordinates -->
                <xsl:when test="//@reciprocalZenith = 'true' and @type != 'Fixed'">
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@reciprocalCorrectionNorthing"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@reciprocalCorrectionEasting"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                    </xsl:call-template>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@reciprocalCorrectionElevation"/>
                        <xsl:with-param name="color" select="$red"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                        <xsl:with-param name="style" select="'border-right-width:2px'"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="threeBlankColumns"/>
                </xsl:otherwise>
            </xsl:choose>
        </tr>
        <!-- Traverse Row 3 -->
        <xsl:if test="//@reciprocalZenith = 'true' or //@horizontalZenith = 'true' or //@traverseAdjustment = 'true' or //@elevationAdjustment = 'true'">
            <xsl:choose>
                <xsl:when test="@mode = 'BothFixed'"/>
                <xsl:otherwise>
                    <tr>
                        <xsl:choose>
                            <xsl:when test="//@elevationAdjustment = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <xsl:choose>
                                    <xsl:when test="//@horizontalZenith = 'true'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@horizontalCorrectedAzimuth"/>
                                            <xsl:with-param name="color" select="$red"/>
                                            <xsl:with-param name="displayType" select="'angular'"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <td>&#xa0;</td>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@elevationCorrectedLength"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@elevationCorrectedLatitude"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@elevationCorrectedDeparture"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                            </xsl:when>
                            <xsl:when test="//@traverseAdjustment = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <xsl:choose>
                                    <xsl:when test="//@horizontalZenith = 'true'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@horizontalCorrectedAzimuth"/>
                                            <xsl:with-param name="color" select="$red"/>
                                            <xsl:with-param name="displayType" select="'angular'"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <td>&#xa0;</td>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@traverseCorrectedLength"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@traverseCorrectedLatitude"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@traverseCorrectedDeparture"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                            </xsl:when>
                            <xsl:when test="//@horizontalZenith = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@horizontalCorrectedAzimuth"/>
                                    <xsl:with-param name="color" select="$red"/>
                                    <xsl:with-param name="displayType" select="'angular'"/>
                                </xsl:call-template>
                                <xsl:choose>
                                    <xsl:when test="//@traverseAdjustment = 'true'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@traverseCorrectedLength"/>
                                            <xsl:with-param name="color" select="$red"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <td>&#xa0;</td>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@horizontalCorrectedLatitude"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@horizontalCorrectedDeparture"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                            </xsl:when>
                            <xsl:when test="//@reciprocalZenith = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <td>&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@reciprocalCorrectedLength"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@reciprocalCorrectedLatitude"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@reciprocalCorrectedDeparture"/>
                                    <xsl:with-param name="color" select="$red"/>
                                </xsl:call-template>
                            </xsl:when>
                        </xsl:choose>
                        <xsl:choose>
                            <!-- Display Elevation Difference Coordinates -->
                            <xsl:when test="//@elevationAdjustment = 'true'">
                                <xsl:choose>
                                    <xsl:when test="@type != 'Fixed'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@elevationDifferenceNorthing"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'northing'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@elevationDifferenceEasting"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'easting'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@elevationDifferenceElevation"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'elevation'"/>
                                            <xsl:with-param name="style" select="'border-right-width:2px'"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="threeBlankColumns"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Display Traverse Difference Coordinates -->
                            <xsl:when test="//@traverseAdjustment='true'">
                                <xsl:choose>
                                    <xsl:when test="@type != 'Fixed'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@traverseDifferenceNorthing"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'northing'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@traverseDifferenceEasting"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'easting'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@traverseDifferenceElevation"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'elevation'"/>
                                            <xsl:with-param name="style" select="'border-right-width:2px'"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="threeBlankColumns"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Display Horizontal Difference Coordinates -->
                            <xsl:when test="//@horizontalZenith = 'true'">
                                <xsl:choose>
                                    <xsl:when test="@type != 'Fixed'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@horizontalDifferenceNorthing"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'northing'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@horizontalDifferenceEasting"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'easting'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@horizontalDifferenceElevation"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'elevation'"/>
                                            <xsl:with-param name="style" select="'border-right-width:2px'"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="threeBlankColumns"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <!-- Display reciprocal Difference Coordinates -->
                            <xsl:when test="//@reciprocalZenith = 'true'">
                                <xsl:choose>
                                    <xsl:when test="@type != 'Fixed'">
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@reciprocalDifferenceNorthing"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'northing'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@reciprocalDifferenceEasting"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'easting'"/>
                                        </xsl:call-template>
                                        <xsl:call-template name="displayColumn">
                                            <xsl:with-param name="value" select="@reciprocalDifferenceElevation"/>
                                            <xsl:with-param name="error" select="'true'"/>
                                            <xsl:with-param name="displayType" select="'elevation'"/>
                                            <xsl:with-param name="style" select="'border-right-width:2px'"/>
                                        </xsl:call-template>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:call-template name="threeBlankColumns"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                        </xsl:choose>
                    </tr>
                </xsl:otherwise>
            </xsl:choose>
            <!-- Traverse Row 4 -->
            <xsl:choose>
                <xsl:when test="@mode = 'BothFixed'"/>
                <xsl:otherwise>
                    <tr>
                        <xsl:choose>
                            <xsl:when test="//@elevationAdjustment = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <td>&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@elevationDifferenceLength"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@elevationDifferenceLatitude"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@elevationDifferenceDeparture"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="threeBlankColumns"/>
                            </xsl:when>
                            <xsl:when test="//@traverseAdjustment = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <td>&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@traverseDifferenceLength"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@traverseDifferenceLatitude"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@traverseDifferenceDeparture"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="threeBlankColumns"/>
                            </xsl:when>
                            <xsl:when test="//@horizontalZenith = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@horizontalDifferenceAzimuth"/>
                                    <xsl:with-param name="displayType" select="'angular'"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <td>&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@horizontalDifferenceLatitude"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@horizontalDifferenceDeparture"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="threeBlankColumns"/>
                            </xsl:when>
                            <xsl:when test="//@reciprocalZenith = 'true'">
                                <td style="border-left-width:2px">&#xa0;</td>
                                <td>&#xa0;</td>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@reciprocalDifferenceLength"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@reciprocalDifferenceLatitude"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="displayColumn">
                                    <xsl:with-param name="value" select="@reciprocalDifferenceDeparture"/>
                                    <xsl:with-param name="error" select="'true'"/>
                                </xsl:call-template>
                                <xsl:call-template name="threeBlankColumns"/>
                            </xsl:when>
                        </xsl:choose>
                    </tr>
                    <tr/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    <xsl:template name="displayTraverseTotal">
        <xsl:param name="traverseAdjustment"/>
        <xsl:param name="horizontalZenith"/>
        <xsl:param name="reciprocalZenith"/>
        <!-- Traverse Total Row 1 -->
        <tr>
            <td/>
            <td align="center" style="border-left-width:2px;border-bottom-width:2px">Total</td>
            <td align="center">
                <xsl:value-of select="inr:distanceFormat(number(//@totalTraverseLength), $xslDistancePrecision)"/>
            </td>
            <td align="center">
                <xsl:value-of select="inr:distanceFormat(number(//@totalLatitudeLength), $xslDistancePrecision)"/>
            </td>
            <td align="center" style="border-right-width:2px">
                <xsl:value-of select="inr:distanceFormat(number(//@totalDepartureLength), $xslDistancePrecision)"/>
            </td>
            <td/>
            <td/>
            <td/>
        </tr>
        <!-- Traverse Total Row 2 -->
        <xsl:if test="//@horizontalZenith = 'true' or //@traverseAdjustment = 'true' or //@reciprocalZenith = 'true' or //@elevationAdjustment = 'true'">
            <tr>
                <td/>
                <td/>
                <xsl:choose>
                    <xsl:when test="//@elevationAdjustment = 'true'">
                        <td align="center" style="border-left-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@elevationAdjustmentTotalTraverseLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@elevationAdjustmentTotalLatitudeLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="border-right-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@elevationAdjustmentTotalDepartureLength), $xslDistancePrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="//@traverseAdjustment = 'true'">
                        <td align="center" style="border-left-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@traverseAdjustmentTotalTraverseLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@traverseAdjustmentTotalLatitudeLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="border-right-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@traverseAdjustmentTotalDepartureLength), $xslDistancePrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="//@horizontalZenith = 'true'">
                        <td/>
                        <td align="center" style="border-left-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@horizontalTotalLatitudeLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="border-right-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@horizontalTotalDepartureLength), $xslDistancePrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="//@reciprocalZenith = 'true'">
                        <td align="center" style="border-left-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@reciprocalTotalTraverseLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@reciprocalTotalLatitudeLength), $xslDistancePrecision)"/>
                        </td>
                        <td align="center" style="border-right-width:2px;color:#FF0000">
                            <xsl:value-of select="inr:distanceFormat(number(//@reciprocalTotalDepartureLength), $xslDistancePrecision)"/>
                        </td>
                    </xsl:when>
                </xsl:choose>
                <td/>
                <td/>
                <td/>
            </tr>
        </xsl:if>
        <!-- Traverse Total Row 3 -->
        <xsl:if test="//@reciprocalZenith = 'true' or //@horizontalZenith = 'true' or //@traverseAdjustment = 'true'">
            <tr>
                <td/>
                <td/>
                <xsl:choose>
                    <xsl:when test="//@elevationAdjustment = 'true'">
                        <td align="center" style="border-bottom-width:2px;border-left-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@elevationTotalTraverseLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@elevationTotalLatitudeLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-right-width:2px;border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@elevationTotalDepartureLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="//@traverseAdjustment = 'true'">
                        <td align="center" style="border-bottom-width:2px;border-left-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@traverseTotalTraverseLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@traverseTotalLatitudeLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-right-width:2px;border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@traverseTotalDepartureLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="//@horizontalZenith = 'true'">
                        <td/>
                        <td align="center" style="border-bottom-width:2px;border-left-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@horizontalTotalLatitudeLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-right-width:2px;border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@horizontalTotalDepartureLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="//@reciprocalZenith = 'true'">
                        <td align="center" style="border-bottom-width:2px;border-left-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@reciprocalTotalTraverseLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@reciprocalTotalLatitudeLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                        <td align="center" style="border-right-width:2px;border-bottom-width:2px;white-space:nowrap">
                            [<xsl:value-of select="inr:distanceFormat(number(//@reciprocalTotalDepartureLengthDifference), $xslDistancePrecision)"/>]
                        </td>
                    </xsl:when>
                </xsl:choose>
                <td/>
                <td/>
                <td/>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="displayBacksight">
        <xsl:if test="position() = 1">
            <tr>
                <xsl:call-template name="displayPointName">
                    <xsl:with-param name="name" select="@backsightPointName"/>
                    <xsl:with-param name="type" select="@backsightType"/>
                    <xsl:with-param name="style" select="'border-left-width:2px'"/>
                </xsl:call-template>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <xsl:choose>
                    <xsl:when test="@backsightType = 'AZ'">
                        <xsl:call-template name="threeBlankColumns"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <td align="right">
                            <xsl:value-of select="inr:northingFormat(number(@backsightNorthing), $xslNorthingPrecision)"/>
                        </td>
                        <td align="right">
                            <xsl:value-of select="inr:eastingFormat(number(@backsightEasting), $xslEastingPrecision)"/>
                        </td>
                        <td align="right" style="border-right-width:2px">
                            <xsl:value-of select="inr:elevationFormat(number(@backsightElevation), $xslElevationPrecision)"/>
                        </td>
                    </xsl:otherwise>
                </xsl:choose>
            </tr>
            <tr>
                <td style="border-left-width:2px">&#xa0;</td>
                <td align="right" nowrap="nowrap">
                    <xsl:value-of select="inr:angularFormat(number(//@beginningAzimuth)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                </td>
                <td align="right"><xsl:value-of select="@backsightLength"/></td>
                <td align="right"><xsl:value-of select="@backsightLatitude"/></td>
                <td align="right"><xsl:value-of select="@backsightDeparture"/></td>
                <td>&#xa0;</td>
                <td>&#xa0;</td>
                <td style="border-right-width:2px">&#xa0;</td>
            </tr>
            <tr/>
        </xsl:if>
    </xsl:template>
    <xsl:template name="displayForesight">
        <xsl:if test="position() = last()">
            <tr>
                <xsl:call-template name="displayPointName">
                    <xsl:with-param name="name" select="@foresightPointName"/>
                    <xsl:with-param name="type" select="@foresightType"/>
                    <xsl:with-param name="style" select="'border-bottom-width:2px;border-left-width:2px'"/>
                </xsl:call-template>
                <td align="right">&#xa0;</td>
                <td align="right">---</td>
                <td align="right">---</td>
                <td align="right">---</td>
                <xsl:choose>
                    <xsl:when test="@foresightType='AZ'">
                        <xsl:call-template name="threeBlankColumns"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <td align="right" style="border-bottom-width:2px">
                            <xsl:value-of select="inr:northingFormat(number(@foresightNorthing), $xslNorthingPrecision)"/>
                        </td>
                        <td align="right" style="border-bottom-width:2px">
                            <xsl:value-of select="inr:eastingFormat(number(@foresightEasting), $xslEastingPrecision)"/>
                        </td>
                        <td align="right" style="border-right-width:2px;border-bottom-width:2px">
                            <xsl:value-of select="inr:elevationFormat(number(@foresightElevation), $xslElevationPrecision)"/>
                        </td>
                    </xsl:otherwise>
                </xsl:choose>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="displayPointName">
        <xsl:param name="name"/>
        <xsl:param name="type" select="'Fixed'"/>
        <xsl:param name="style" select="''"/>
        <th align="left" nowrap="nowrap" style="{$style}">
            <xsl:choose>
                <xsl:when test="$type='Fixed'">
                    <img src="{$xslRootDirectory}/Images/SrvFixed.png" alt="Fixed"/>&#xa0;
                </xsl:when>
                <xsl:when test="$type='Free'">
                    <img src="{$xslRootDirectory}/Images/SrvFree.png" alt="Free"/>&#xa0;
                </xsl:when>
                <xsl:otherwise>
                    <img src="{$xslRootDirectory}/Images/SrvAzimuth.png" alt="Azimuth"/>&#xa0;
                </xsl:otherwise>
            </xsl:choose>
            <xsl:value-of select="$name"/>
        </th>
    </xsl:template>
    <xsl:template name="displayColumn">
        <xsl:param name="value"/>
        <xsl:param name="color" select="'000000'"/>
        <xsl:param name="displayType" select="'distance'"/>
        <xsl:param name="error" select="'false'"/>
        <xsl:param name="style" select="''"/>
        <xsl:choose>
            <xsl:when test="$error = 'false'">
                <xsl:choose>
                    <xsl:when test="$displayType='angular'">
                        <td align="right" nowrap="nowrap" style="color:{$color};{$style}">
                            &#xa0;<xsl:value-of select="inr:angularFormat(number($value)$xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='distance'">
                        <td align="right" style="color:{$color};{$style}">
                            &#xa0;<xsl:value-of select="inr:distanceFormat(number($value), $xslDistancePrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='northing'">
                        <td align="right" style="color:{$color};{$style}">
                            &#xa0;<xsl:value-of select="inr:northingFormat(number($value), $xslNorthingPrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='easting'">
                        <td align="right" style="color:{$color};{$style}">
                            &#xa0;<xsl:value-of select="inr:eastingFormat(number($value), $xslEastingPrecision)"/>
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='elevation'">
                        <td align="right" style="color:{$color};{$style}">
                            &#xa0;<xsl:value-of select="inr:elevationFormat(number($value), $xslElevationPrecision)"/>
                        </td>
                    </xsl:when>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="$displayType='angular'">
                        <td align="right" nowrap="nowrap" style="{$style}">
                            [<xsl:value-of select="inr:angularFormat(number($value), $xslAngularFormat, $xslAngularPrecision, $xslAngularMethod)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='distance'">
                        <td align="right" style="{$style}">
                            [<xsl:value-of select="inr:distanceFormat(number($value), $xslDistancePrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='northing'">
                        <td align="right" style="{$style}">
                            [<xsl:value-of select="inr:northingFormat(number($value), $xslNorthingPrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='easting'">
                        <td align="right" style="{$style}">
                            [<xsl:value-of select="inr:eastingFormat(number($value), $xslEastingPrecision)"/>]
                        </td>
                    </xsl:when>
                    <xsl:when test="$displayType='elevation'">
                        <td align="right" style="{$style}">
                            [<xsl:value-of select="inr:elevationFormat(number($value), $xslElevationPrecision)"/>]
                        </td>
                    </xsl:when>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="fourBlankColumns">
        <td>&#xa0;</td>
        <td>&#xa0;</td>
        <td>&#xa0;</td>
        <td>&#xa0;</td>
    </xsl:template>
    <xsl:template name="threeBlankColumns">
        <td>&#xa0;</td>
        <td>&#xa0;</td>
        <td style="border-right-width:2px">&#xa0;</td>
    </xsl:template>
    <xsl:template name="displayPointsBacksight">
        <xsl:variable name="style"/>
        <tr>
            <td align="left" lang="en" nowrap="nowrap" style="border-left-width:2px">Original</td>
            <xsl:choose>
                <xsl:when test="//@backsightType = 'AZ'">
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right" style="border-right-width:2px;$style">---</td>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@backsightNorthing"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:call-template>
                    <td align="right">---</td>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@backsightEasting"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:call-template>
                    <td align="right">---</td>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@backsightElevation"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:call-template>
                    <td align="right" style="border-right-width:2px;$style">---</td>
                </xsl:otherwise>
            </xsl:choose>
        </tr>
        <tr/>
    </xsl:template>
    <xsl:template name="displayPointsForesight">
        <xsl:variable name="style"/>
        <tr>
            <td align="left" nowrap="nowrap" style="border-left-width:2px">Original</td>
            <xsl:choose>
                <xsl:when test="//@foresightType='AZ'">
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right">---</td>
                    <td align="right" style="border-right-width:2px;$style">---</td>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@foresightNorthing"/>
                        <xsl:with-param name="displayType" select="'northing'"/>
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:call-template>
                    <td align="right">---</td>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@foresightEasting"/>
                        <xsl:with-param name="displayType" select="'easting'"/>
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:call-template>
                    <td align="right">---</td>
                    <xsl:call-template name="displayColumn">
                        <xsl:with-param name="value" select="@foresightElevation"/>
                        <xsl:with-param name="displayType" select="'elevation'"/>
                        <xsl:with-param name="style" select="$style"/>
                    </xsl:call-template>
                    <td align="right" style="border-right-width:2px;$style">---</td>
                </xsl:otherwise>
            </xsl:choose>
        </tr>
    </xsl:template>
    <xsl:template name="displayPoints">
        <xsl:param name="traverseAdjustment"/>
        <xsl:param name="horizontalZenith"/>
        <xsl:param name="reciprocalZenith"/>
        <xsl:variable name="style1">
            <xsl:if test="position() = last() and //@reciprocalZenith != 'true' and //@horizontalZenith != 'true' and //@traverseAdjustment != 'true'">
                border-bottom-width:2px
            </xsl:if>
        </xsl:variable>
        <xsl:variable name="style2">
            <xsl:if test="position() = last() and //@horizontalZenith != 'true' and //@traverseAdjustment != 'true'">
                border-bottom-width:2px
            </xsl:if>
        </xsl:variable>
        <xsl:variable name="style3">
            <xsl:if test="position() = last() and //@traverseAdjustment != 'true'">
                border-bottom-width:2px
            </xsl:if>
        </xsl:variable>
        <xsl:variable name="style4">
            <xsl:if test="position() = last()">border-bottom-width:2px</xsl:if>
        </xsl:variable>
        <!-- Points Row 1 -->
        <tr>
            <td align="left" lang="en" nowrap="nowrap" style="border-left-width:2px">Original</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedNorthing"/>
                <xsl:with-param name="displayType" select="'northing'"/>
                <xsl:with-param name="style" select="$style1"/>
            </xsl:call-template>
            <td align="right">---</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedEasting"/>
                <xsl:with-param name="displayType" select="'easting'"/>
                <xsl:with-param name="style" select="$style1"/>
            </xsl:call-template>
            <td align="right">---</td>
            <xsl:call-template name="displayColumn">
                <xsl:with-param name="value" select="@unadjustedElevation"/>
                <xsl:with-param name="displayType" select="'elevation'"/>
                <xsl:with-param name="style" select="$style1"/>
            </xsl:call-template>
            <td align="right" style="border-right-width:2px;$style1">---</td>
        </tr>
        <!-- Points Row 2 -->
        <xsl:if test="//@reciprocalZenith = 'true' and @type != 'Fixed'">
            <tr>
                <td align="left" lang="en" nowrap="nowrap" style="border-left-width:2px">Reciprocal</td>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@reciprocalCorrectionNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                    <xsl:with-param name="style" select="$style2"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@reciprocalDifferenceNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                    <xsl:with-param name="style" select="$style2"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@reciprocalCorrectionEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                    <xsl:with-param name="style" select="$style2"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@reciprocalDifferenceEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                    <xsl:with-param name="style" select="$style2"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@reciprocalCorrectionElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style" select="$style2"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@reciprocalDifferenceElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style">
                        border-right-width:2px;<xsl:value-of select="$style2"/>
                    </xsl:with-param>
                </xsl:call-template>
            </tr>
        </xsl:if>
        <!-- Points Row 3 -->
        <xsl:if test="//@horizontalZenith = 'true' and @type != 'Fixed'">
            <tr>
                <td align="left" lang="en" nowrap="nowrap" style="border-left-width:2px">Horizontal</td>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@horizontalCorrectionNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                    <xsl:with-param name="style" select="$style3"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@horizontalDifferenceNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                    <xsl:with-param name="style" select="$style3"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@horizontalCorrectionEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                    <xsl:with-param name="style" select="$style3"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@horizontalDifferenceEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                    <xsl:with-param name="style" select="$style3"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@horizontalCorrectionElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style" select="$style3"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@horizontalDifferenceElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style">
                        border-right-width:2px;<xsl:value-of select="$style3"/>
                    </xsl:with-param>
                </xsl:call-template>
            </tr>
        </xsl:if>
        <!-- Points Row 4 -->
        <xsl:if test="//@traverseAdjustment = 'true' and @type != 'Fixed'">
            <tr>
                <td align="left" nowrap="nowrap" style="border-left-width:2px;border-bottom-width:2px">
                    <xsl:value-of select="//@adjustmentType"/>
                </td>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@traverseCorrectionNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                    <xsl:with-param name="style" select="$style4"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@traverseDifferenceNorthing"/>
                    <xsl:with-param name="displayType" select="'northing'"/>
                    <xsl:with-param name="style" select="$style4"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@traverseCorrectionEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                    <xsl:with-param name="style" select="$style4"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@traverseDifferenceEasting"/>
                    <xsl:with-param name="displayType" select="'easting'"/>
                    <xsl:with-param name="style" select="$style4"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@traverseCorrectionElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style" select="$style4"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@traverseDifferenceElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style">
                        border-right-width:2px;<xsl:value-of select="$style4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </tr>
        </xsl:if>
        <xsl:if test="//@elevationAdjustment = 'true' and @type != 'Fixed'">
            <tr>
                <td align="left" nowrap="nowrap" style="border-left-width:2px">Elevation</td>
                <td align="right">---</td>
                <td align="right">---</td>
                <td align="right">---</td>
                <td align="right">---</td>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@elevationCorrectionElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style" select="$style4"/>
                </xsl:call-template>
                <xsl:call-template name="displayColumn">
                    <xsl:with-param name="value" select="@elevationDifferenceElevation"/>
                    <xsl:with-param name="displayType" select="'elevation'"/>
                    <xsl:with-param name="style">
                        border-right-width:2px;<xsl:value-of select="$style4"/>
                    </xsl:with-param>
                </xsl:call-template>
            </tr>
        </xsl:if>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                You must have a survey network and you must also have run the <em>Survey &gt; Network &gt; 
                Traverse Adjustment</em> command to get results from this report.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
