<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.1" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:inr="http://mycompany.com/mynamespace">
    <xsl:include href="../format.xsl"/>
    <xsl:param name="xslRootDirectory" select="inr:xslRootDirectory"/>
    <!--Turnout Report-->
    <xsl:template match="/">
        <xsl:variable name="gridOut" select="inr:SetGridOut(number(InRoads/@outputGridScaleFactor))" />
        <html>
            <head>
                <link rel="stylesheet" type="text/css" href="{$xslRootDirectory}/_Themes/engineer/theme.css"/>
                <!--Title displayed in browser Title Bar-->
                <title lang="en">Turnout Report</title>
            </head>
            <body>
                <xsl:choose>
                    <xsl:when test="$xslShowHelp = 'true'">
                        <xsl:call-template name="StyleSheetHelp"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:for-each select="InRoads">
                            <center>
                                <!--Report Title-->
                                <h2 lang="en">Turnout Report</h2>
                                <p lang="en">
                                    Report Created:&#xa0; <xsl:value-of select="inr:date()"/><br />
                                    Time:&#xa0; <xsl:value-of select="inr:time()"/>
                                </p>
                            </center>
                            <!--Project Data-->
                            <xsl:for-each select="GeometryProject">
                                <table class="margin" cellpadding="2" width="90%">
                                    <tbody>
                                        <tr>
                                            <th align="right" lang="en">Project:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@name"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en">Description:&#xa0; </th>
                                            <td align="left" colspan="2"><xsl:value-of select="@description"/></td>
                                        </tr>
                                        <tr>
                                            <th align="right" lang="en" style="font-size: 80%">Input Grid Factor:&#xa0; </th>
                                            <td align="left" style="font-size: 80%"><xsl:value-of select="../@inputGridScaleFactor" /></td>
                                            <td align="right" lang="en" style="font-size: 80%">
                                                <strong>Note:&#xa0; </strong>All units in this report are in
                                                <xsl:if test="//@linearUnits = 'Imperial'">feet</xsl:if>
                                                <xsl:if test="//@linearUnits = 'Metric'">meters</xsl:if>
                                                unless specified otherwise.
                                            </td>
                                        </tr>
                                    </tbody>
                                </table>
                                <hr />
                                <xsl:for-each select="Turnout">
                                    <table class="margin" cellpadding="2" cellspacing="1" width="90%">
                                        <thead>
                                            <colgroup span="6">
                                                <col width="20%"/>
                                                <col width="16%"/>
                                                <col width="16%"/>
                                                <col width="16%"/>
                                                <col width="16%"/>
                                                <col width="16%"/>
                                            </colgroup>
                                        </thead>
                                        <tbody>
                                            <tr>
                                                <td align="left" colspan="6" lang="en"><strong>Turnout:&#xa0; </strong>
                                                    <xsl:value-of select="@name"/>
                                                    <xsl:text>&#xa0;</xsl:text>
                                                    <xsl:value-of select="@description"/>
                                                    (<xsl:value-of select="@style"/>)
                                                </td>
                                            </tr>
                                            <xsl:apply-templates />
                                        </tbody>
                                    </table>
                                    <hr />
                                </xsl:for-each>
                            </xsl:for-each>
                        </xsl:for-each>
                    </xsl:otherwise>
                </xsl:choose>
            </body>
        </html>
    </xsl:template>
    <!-- Turnout Horizontal Line Data -->
    <xsl:template match="HorizontalLine">
        <xsl:if test="position() = 1 or preceding-sibling::*[1][name() = 'TurnoutPoint']">
            <tr>
                <th align="left"  lang="en">Element Type</th>
                <th align="right" lang="en">Start Northing</th>
                <th align="right" lang="en">Start Easting</th>
                <th align="right" lang="en">Length</th>
                <th align="right" lang="en">Start Radius</th>
                <th align="right" lang="en">End Radius</th>
            </tr>
        </xsl:if>
        <tr>
            <td align="left" lang="en">Linear</td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>   
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(0.), $xslDistancePrecision)"/>
            </td>   
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(0.), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Turnout Horizontal Circle Data -->
    <xsl:template match="HorizontalCircle">
        <xsl:if test="position() = 1 or preceding-sibling::*[1][name() = 'TurnoutPoint']">
            <tr>
                <th align="left"  lang="en">Element Type</th>
                <th align="right" lang="en">Start Northing</th>
                <th align="right" lang="en">Start Easting</th>
                <th align="right" lang="en">Length</th>
                <th align="right" lang="en">Start Radius</th>
                <th align="right" lang="en">End Radius</th>
            </tr>
        </xsl:if>
        <tr>
            <td align="left" lang="en">Circular</td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td>  
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>  
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@radius), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Turnout Horizontal Spiral Data -->
    <xsl:template match="HorizontalSpiral">
        <xsl:if test="position() = 1 or preceding-sibling::*[1][name() = 'TurnoutPoint']">
            <tr>
                <th align="left"  lang="en">Element Type</th>
                <th align="right" lang="en">Start Northing</th>
                <th align="right" lang="en">Start Easting</th>
                <th align="right" lang="en">Length</th>
                <th align="right" lang="en">Start Radius</th>
                <th align="right" lang="en">End Radius</th>
            </tr>
        </xsl:if>
        <tr>
            <td align="left" lang="en">Clothoid</td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(Start/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(Start/@easting), $xslEastingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@length), $xslDistancePrecision)"/>
            </td> 
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
            </td> 
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </td>
        </tr>
    </xsl:template>
    <!-- Turnout Points -->
    <xsl:template match="TurnoutPoint">
        <xsl:if test="preceding-sibling::*[1][name() != 'TurnoutPoint']">
            <tr>
                <td></td>
            </tr>
            <tr>
                <th align="left"  lang="en">Point Name</th>
                <th align="right" lang="en">Northing</th>
                <th align="right" lang="en">Easting</th>
                <th align="right" lang="en">Elevation</th>
                <th align="right" lang="en">Radius</th>
                <th align="right" lang="en">Offset</th>
            </tr>
        </xsl:if>
        <tr>
            <td align="left"><xsl:value-of select="GeometryPoint/@name"/></td>
            <td align="right">
                <xsl:value-of select="inr:northingFormat(number(GeometryPoint/@northing), $xslNorthingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:eastingFormat(number(GeometryPoint/@easting), $xslEastingPrecision)"/>
            </td>
            <td align="right">
                <xsl:value-of select="inr:elevationFormat(number(GeometryPoint/@elevation), $xslElevationPrecision)"/>
            </td>  
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@startRadius), $xslDistancePrecision)"/>
            </td>  
            <td align="right">
                <xsl:value-of select="inr:distanceFormat(number(@endRadius), $xslDistancePrecision)"/>
            </td>
            <td />
        </tr>
    </xsl:template>
    <xsl:template name="StyleSheetHelp">
        <div class="section1">
            <h4 lang="en">Notes</h4>
            <p class="normal1" lang="en">
                Your active geometry project must have at least one turnout definition.
            </p>
            <p class="normal1">
                You must select at least one turnout in the <em>Geometry &gt; Turnouts &gt; Reports</em> 
                command.
            </p>
            <h4 lang="en">Tips</h4>
            <p class="normal1" lang="en">
                To access the <em>Turnouts</em> commands, select the <em>Tools &gt; Application 
                Add-Ins</em> command and toggle on the <em>Turnouts Add-In</em>.
            </p>
            <p class="small" lang="en">
                <em>&#xa9; 2006 Bentley Systems, Inc</em>
            </p>
        </div>
    </xsl:template>
</xsl:stylesheet>
